<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/" 
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/" 
	xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/" 
	xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Adkomst.xslt 153610 2019-05-29 12:22:27Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende Adkomster -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	

	<!--*****************************************************************************************************************-->
	<!--*********************************  msg:AdkomstKombinationPaategn *************************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="msg:AdkomstKombinationPaategn">
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<xsl:variable name="doc_id" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
		<xsl:call-template name="dokument_som_paategnes">
			<xsl:with-param name="doc_id" select="$doc_id" />
		</xsl:call-template>

		<!-- Udskriv de enkelte påtegninger  -->
		<xsl:for-each select="node()">
		    <!-- Namespace fjernes inden sammenligning med nodenavn -->
		    <xsl:choose>
				<xsl:when test="starts-with( substring-after( string(name()), ':' ), 'Ekspeditionstype') != ''">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="starts-with(string(name()), 'Ekspeditionstype')">
						<xsl:apply-templates select="."/>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>

		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<!-- Rollesamling -->
		<xsl:apply-templates select="//anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt - bagudkompatibelt-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>

		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*****************************************************************************************************************-->
	<!--****************** 51 - EkspeditionstypeNyPaataleberettigetFastEjendom *****************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypeEndeligIndfoerselAdkomstFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="model:EkspeditionstypeIdentifikator"/>
		</xsl:call-template>
	</xsl:template>

	
	
	<!--*****************************************************************************************************************-->
	<!--******************************  52 - RespektAdkomstFastEjendom  ***************************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypeRespektAdkomstFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="text2" select="$opslag//PaategningHjaelpetekst[@id = $doctypeid]" />
		</xsl:call-template>
		
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivServitutter">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
	</xsl:template>

	<!--*****************************************************************************************************************-->
	<!--*********************  248 - EkspeditionstypePaategningVaerdierklaeringFastEjendom  *****************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypePaategningVaerdierklaeringFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="text2" select="$opslag//PaategningHjaelpetekst[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:if test="model:VaerdierklaeringPant">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Værdierklæring pant'" />
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="model:VaerdierklaeringAdkomst">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Værdierklæring adkomst'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />

		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Delareal (nummer, størrelse)'" />
			<xsl:with-param name="text" select="concat(string(model:DelarealNummer), ', ', string(model:DelarealStoerrelse), ' kvm')" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />

		<xsl:call-template name="column1">
			<xsl:with-param name="text" select="'Overføres til ejendommen'" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />

		<xsl:apply-templates select="model:EjendomIdentifikator"/>
	</xsl:template>

	<!--*****************************************************************************************************************-->
	<!--********************************  54 - PaategningAdkomstFastEjendom **********************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypePaategningAdkomstFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="model:EkspeditionstypeIdentifikator"/>
		</xsl:call-template>

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'PÅTEGNINGSTEKST'"/>
		</xsl:call-template>
		<xsl:for-each select="model:TekstPaategningSamling/model:TekstAngivelse">
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
		</xsl:for-each>
		
		<xsl:if test="model:NyKoebesum">
			<xsl:call-template name="Hovedstol">
				<xsl:with-param name="node" select="model:NyKoebesum"/>
				<xsl:with-param name="header" select="'Ny købesum'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
		<xsl:if test="model:Dato">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Ny overtagelsesdato'" />
				<xsl:with-param name="text">
					<xsl:call-template name="formatdato">
						<xsl:with-param name="dato" select="model:Dato"/>
					</xsl:call-template >
				</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
		
	</xsl:template>

</xsl:stylesheet>
