<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-2="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/10/31/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:dkcc-2="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/05/19/"
    xmlns:itst-1="http://rep.oio.dk/itst.dk/xml/schemas/2005/01/10/"
    xmlns:itst-2="http://rep.oio.dk/itst.dk/xml/schemas/2006/01/17/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>

<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Adresser.xslt 113923 2017-03-07 07:21:29Z cander28@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<xsl:key name="AdresseStruktur" match="//snapshot:AdresseStruktur" use="concat(xkom:AddressSpecific/xkom-1:AddressAccess/cpr:MunicipalityCode, '_', xkom:AddressSpecific/xkom-1:AddressAccess/cpr:StreetCode, '_', xkom:AddressSpecific/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier)"/>
	<xsl:key name="Rolle" match="//model:RolleSamling/model:Rolle" use="@id"/>
					
	<!-- ***********************************   VisRolleAdresse   ********************************** -->	
	<xsl:template name="model:VisRolleAdresse"> 
		<xsl:param name="adr_id"/> 

		<xsl:variable name="rolle" select="key('Rolle', $adr_id)"/>
		<xsl:choose>
			<!-- Er der angivet en adresse direkte i rollen (bruges kun RolleType, når der ikke er et CPR/CVR nummer, og ved KreditorType -->
			<xsl:when test="$rolle/xkom:AddressSpecific">
				<xsl:call-template name="model:VisSpecifikAdresse">
				<xsl:with-param name="root" select="$rolle/xkom:AddressSpecific"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$rolle/cpr-2:SecondaryPostalLabel">
				<xsl:call-template name="SecondaryPostalLabel">
				<xsl:with-param name="adr_id" select="$adr_id"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="model:VisSpecifikAdresse">
				<xsl:with-param name="root" select="key('RolleStruktur', $adr_id)/xkom:AddressSpecific"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

    <!-- ***********************************   VisSpecifikAdresse   ********************************** --> 
	<xsl:template name="model:VisSpecifikAdresse"> 
		<xsl:param name="root"/> 
		
		<xsl:variable name="MunicipalityCode" select="$root/xkom-1:AddressAccess/cpr:MunicipalityCode"/> 
		<xsl:variable name="StreetCode" select="$root/xkom-1:AddressAccess/cpr:StreetCode"/> 
		<xsl:variable name="StreetBuildingIdentifier" select="$root/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier"/>
		<xsl:variable name="FloorIdentifier" select="$root/dkcc-1:FloorIdentifier"/>
		<xsl:variable name="SuiteIdentifier" select="$root/dkcc-1:SuiteIdentifier"/>
		<xsl:call-template name="model:VisAdresse"> 
			<xsl:with-param name="MunicipalityCode" select="$MunicipalityCode"/> 
			<xsl:with-param name="StreetCode" select="$StreetCode"/> 
			<xsl:with-param name="StreetBuildingIdentifier" select="$StreetBuildingIdentifier"/> 
			<xsl:with-param name="FloorIdentifier" select="$FloorIdentifier"/> 
			<xsl:with-param name="SuiteIdentifier" select="$SuiteIdentifier"/> 
		</xsl:call-template> 
	</xsl:template>


	<!-- ***********************************   VisAdresse   ********************************** -->	
	<xsl:template name="model:VisAdresse"> 
		<xsl:param name="MunicipalityCode"/> 
		<xsl:param name="StreetCode"/> 
		<xsl:param name="StreetBuildingIdentifier"/> 
		<xsl:param name="FloorIdentifier"/> 
		<xsl:param name="SuiteIdentifier"/> 

		<!-- Vejnavn og husnr -->
		<xsl:variable name="Streetname" select="key('AdresseStruktur', concat($MunicipalityCode,'_',$StreetCode,'_',$StreetBuildingIdentifier))/dkcc:StreetName"/>
		<xsl:variable name="Postcode" select="key('AdresseStruktur', concat($MunicipalityCode,'_',$StreetCode,'_',$StreetBuildingIdentifier))/dkcc:PostCodeIdentifier"/>
		<xsl:variable name="District" select="key('AdresseStruktur', concat($MunicipalityCode,'_',$StreetCode,'_',$StreetBuildingIdentifier))/dkcc:DistrictName"/>
		<!-- Udskriv info fra snapshot -->
		<xsl:if test="$Streetname">
			<xsl:choose>
				<xsl:when test="$FloorIdentifier != '' and $SuiteIdentifier != ''">
					<xsl:call-template name="column2">
							<xsl:with-param name="text" select="$Streetname" /> 
							<xsl:with-param name="text2" select="concat(string($StreetBuildingIdentifier),', ',string($FloorIdentifier),'. ',string($SuiteIdentifier),'.')" /> 
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$FloorIdentifier != '' and $SuiteIdentifier = ''">
					<xsl:call-template name="column2">
							<xsl:with-param name="text" select="$Streetname" /> 
							<xsl:with-param name="text2" select="concat(string($StreetBuildingIdentifier),', ',string($FloorIdentifier),'. ')" /> 
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="column2">
							<xsl:with-param name="text" select="$Streetname" /> 
							<xsl:with-param name="text2" select="$StreetBuildingIdentifier" /> 
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		
		<xsl:if test="$Postcode and $District">
			<xsl:call-template name="column2">
					<xsl:with-param name="text" select="$Postcode" /> 
					<xsl:with-param name="text2" select="$District" /> 
			</xsl:call-template>
		</xsl:if>
	
	</xsl:template>
	
	<!-- ***********************************  cpr-2:SecondaryPostalLabel  ********************** -->
	<xsl:template name="SecondaryPostalLabel">
		<xsl:param name="adr_id"/>
		
		<xsl:variable name="Root" select="//model:RolleSamling/model:Rolle[@id = $adr_id]/cpr-2:SecondaryPostalLabel"/>
		
		<!-- namespace n3 hedder i xsd'en dkcc. Dette skal muligvis laves om -->
		<xsl:if test="$Root/dkcc-2:PostalAddressFirstLineText!='' and $Root/dkcc-2:PostalAddressFirstLineText!='ingen adresselinje'and $Root/dkcc-2:PostalAddressFirstLineText!='-'">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressFirstLineText" />
		</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Root/dkcc-2:PostalAddressSecondLineText!='' and $Root/dkcc-2:PostalAddressSecondLineText!='ingen adresselinje'and $Root/dkcc-2:PostalAddressSecondLineText!='-'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressSecondLineText" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Root/dkcc-2:PostalAddressThirdLineText!='' and $Root/dkcc-2:PostalAddressThirdLineText!='ingen adresselinje' and $Root/dkcc-2:PostalAddressThirdLineText!='-'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressThirdLineText" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Root/dkcc-2:PostalAddressFourthLineText!='' and $Root/dkcc-2:PostalAddressFourthLineText!='ingen adresselinje'and $Root/dkcc-2:PostalAddressFourthLineText!='-'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressFourthLineText" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Root/dkcc-2:PostalAddressFifthLineText!='' and $Root/dkcc-2:PostalAddressFifthLineText!='ingen adresselinje'and $Root/dkcc-2:PostalAddressFifthLineText!='-'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressFifthLineText" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$Root/dkcc-2:PostalAddressSixthLineText!='' and $Root/dkcc-2:PostalAddressSixthLineText!='ingen adresselinje'and $Root/dkcc-2:PostalAddressSixthLineText!='-'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$Root/dkcc-2:PostalAddressSixthLineText" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- ***********************************   xkom-1:AddressAccess   ********************************** -->
	<xsl:template match="xkom-1:AddressAccess"> 
                
		<xsl:variable name="Adresser" select="//snapshot:SnapshotSamling/snapshot:AdresseSamling"/>

		<xsl:variable name="Ejendom_MunicipalityCode" select="./cpr:MunicipalityCode"/>
		<xsl:variable name="Ejendom_StreetCode" select="./cpr:StreetCode"/>

		<xsl:variable name="Ejendom_AdresseStruktur" select="$Adresser/snapshot:AdresseStruktur[xkom:AddressSpecific/xkom-1:AddressAccess/cpr:MunicipalityCode=number($Ejendom_MunicipalityCode) and xkom:AddressSpecific/xkom-1:AddressAccess/cpr:StreetCode=number($Ejendom_StreetCode)]"/>
		
		<!-- Vejnavn og husnr -->
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Adresse'" />
			<xsl:with-param name="text" select="$Ejendom_AdresseStruktur/dkcc:StreetName" />
			<xsl:with-param name="text2" select="$Adresser/snapshot:AdresseStruktur/xkom:AddressSpecific/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier" />
		</xsl:call-template>

		<!-- Postnummer og by -->
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$Ejendom_AdresseStruktur/dkcc:PostCodeIdentifier" />
			<xsl:with-param name="text2" select="$Ejendom_AdresseStruktur/dkcc:DistrictName" />
		</xsl:call-template>

		<xsl:call-template name="linefeed" />

		<!-- Matrikler ELLER umatrikuleret areal -->
		<xsl:for-each select="model:EjendomIdentifikator/model:Matrikel">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
		
		<xsl:apply-templates select="model:EjendomIdentifikator/model:Umatrikuleretareal"/>

		<!-- EjendomsType -->
		<xsl:apply-templates select="model:EjendomIdentifikator/model:EjendomType"/>

		<xsl:call-template name="linefeed" />
	</xsl:template>

</xsl:stylesheet>
