<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
	xmlns:xkom-2="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:itst-2="http://rep.oio.dk/itst.dk/xml/schemas/2006/01/17/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:ois="http://rep.oio.dk/ois.dk/xml/schemas/2006/04/25/"
	xmlns:osak="http://rep.oio.dk/osak.dk/xml/schemas/2006/04/25/"     
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Andel.xslt 79229 2014-07-31 07:25:09Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<xsl:key name="AndelStruktur" match="//snapshot:AndelSnapshotStruktur" use="concat(model:AndelAdresse/model:AndelIdentifikator/cpr-1:MunicipalityCode, '_',model:AndelAdresse/model:AndelIdentifikator/cpr-1:StreetCode, '_',model:AndelAdresse/model:AndelIdentifikator/dkcc-1:StreetBuildingIdentifier, '_',model:AndelAdresse/model:AndelIdentifikator/dkcc-1:FloorIdentifier, '_',model:AndelAdresse/model:AndelIdentifikator/model:SideDoerTekst)"/>

	
	<!-- ***********************************   AndelSamling  ********************************** -->
	
	<xsl:template match="model:AndelSamling | model:RespektAndelSamling">
	
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ANDEL'" />
		</xsl:call-template>
		
		<xsl:for-each select="model:Andel | model:RespektAndel">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	
	</xsl:template>

	<!-- ***********************************  model:Andel  ********************************** -->
	<xsl:template match="model:Andel | model:RespektAndel">
		<xsl:apply-templates select="model:AndelIdentifikator"/>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!-- **************************  model:AndelIdentifikator   **************************** -->
	<xsl:template match="model:AndelIdentifikator">
		<xsl:call-template name="FindAndelAdresse">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Kommunekode'" />
			<xsl:with-param name="text" select="cpr-1:MunicipalityCode" />
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Vejkode'" />
			<xsl:with-param name="text" select="cpr-1:StreetCode" />
		</xsl:call-template>
	</xsl:template>

	<!-- ***********************************   model:VisAndel   ********************************** -->
	<xsl:template name="model:VisAndel"> 
		<xsl:param name="node"/> 
		<xsl:call-template name="FindAndelAdresse">
			<xsl:with-param name="node" select="$node"/>
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Kommunekode'" />
			<xsl:with-param name="text" select="$node//cpr-1:MunicipalityCode" />
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Vejkode'" />
			<xsl:with-param name="text" select="$node//cpr-1:StreetCode" />
		</xsl:call-template>
	</xsl:template>


	<!-- **************************  FindAndelAdresse   **************************** -->
	<xsl:template name="FindAndelAdresse"> 
		<xsl:param name="node"/> 


		<xsl:variable name="AndelAdresseKey" select="concat($node//cpr-1:MunicipalityCode, '_',$node//cpr-1:StreetCode, '_',$node//dkcc-1:StreetBuildingIdentifier, '_', $node//dkcc-1:FloorIdentifier, '_', $node//model:SideDoerTekst)"/>
		<xsl:variable name="AndelAdresseStruktur" select="key('AndelStruktur', $AndelAdresseKey)"/>
		<xsl:choose>
			<xsl:when test="$AndelAdresseStruktur//dkcc:StreetName !=''">
				<!-- Vejnavn og husnr -->
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Adresse'"/>
					<xsl:with-param name="text">
						<xsl:value-of select="concat(string($AndelAdresseStruktur//dkcc:StreetName),' ',string($AndelAdresseStruktur//dkcc-1:StreetBuildingIdentifier))" />
						<xsl:if test="count($AndelAdresseStruktur//dkcc-1:FloorIdentifier)>0">
							<xsl:value-of select="concat(', ',string($AndelAdresseStruktur//dkcc-1:FloorIdentifier),'.')" />
						</xsl:if>
						<xsl:if test="count($AndelAdresseStruktur//model:SideDoerTekst)>0">
							<xsl:value-of select="concat(', ',string($AndelAdresseStruktur//model:SideDoerTekst),'.')" />
						</xsl:if>
					</xsl:with-param>
				</xsl:call-template>
				<!-- Postnummer og by -->
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="$AndelAdresseStruktur//dkcc:PostCodeIdentifier" />
					<xsl:with-param name="text2" select="$AndelAdresseStruktur//dkcc:DistrictName" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Adresse'"/>
					<xsl:with-param name="text">
						<xsl:value-of select="concat(string($node/..//dkcc:StreetName),' ',string($node/..//dkcc-1:StreetBuildingIdentifier))" />
						<xsl:if test="count($node/..//dkcc-1:FloorIdentifier)>0">
							<xsl:value-of select="concat(', ',string($node/..//dkcc-1:FloorIdentifier),'.')" />
						</xsl:if>
						<xsl:if test="count($node/..//model:SideDoerTekst)>0">
							<xsl:value-of select="concat(', ',string($node/..//model:SideDoerTekst),'.')" />
						</xsl:if>
					</xsl:with-param>
				</xsl:call-template>
				<!-- Postnummer og by -->
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="$node/..//dkcc:PostCodeIdentifier" />
					<xsl:with-param name="text2" select="$node/..//dkcc:DistrictName" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>


	<!-- *********************************  UdskrivAndelHaeftelser  ******************************** -->
	<xsl:template name="UdskrivAndelHaeftelser">
		<xsl:param name="Root" select=".//model:AndelSamling"/>
		<xsl:variable name="AntalAndeler" select="count($Root/*)"/>
		<xsl:variable name="AntalAndelerSnapshot" select="count(//snapshot:AndelSnapshotStruktur)"/>
		<xsl:variable name="haeftelser">
			<xsl:if test="$AntalAndelerSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RettighedIdentifikator) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="AndelRespekt" select="."/>
					<xsl:variable name="PantRettigheder" select="key('PantRettigheder', $AndelRespekt//model:Respekt/model:RettighedIdentifikator)"/>
					<xsl:variable name="rettigheder">
						<xsl:for-each select="$PantRettigheder">
							<xsl:sort select="model:Rettighed/model:Pantrettighed/model:PrioritetNummer" />
							<!-- Hvis hæftelsen hører til dette dokument, så udskriv den -->
							<xsl:variable name="rettighedIdentifikator" select="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator" />
							<!-- Hæftelsen findes i RespektSamling -->
							<xsl:variable name="dokumentIdentifikator" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
							<xsl:variable name="revisionNummer" select="model:DokumentRevisionIdentifikator/model:RevisionNummer" />
							<xsl:variable name="Struktur" select="key('DokumentStruktur', concat($dokumentIdentifikator,'_',$revisionNummer))"/>
							<xsl:if test="$AndelRespekt//model:Respekt[model:RettighedIdentifikator = $rettighedIdentifikator] and $Struktur">
								<!-- Vis den dokumentstruktur, som matcher -->
								<xsl:call-template name="DokumentStruktur_Haeftelse">
									<xsl:with-param name="dokumentStruktur" select="$Struktur" />
									<xsl:with-param name="doc_id" select="$dokumentIdentifikator" />
								</xsl:call-template>
								<xsl:call-template name="linefeed" />
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>
					<xsl:if test="$AntalAndelerSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="model:VisAndel">
							<xsl:with-param name="node" select="$AndelRespekt"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($haeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$haeftelser"/>
		</xsl:if>
	</xsl:template>
  
	<!-- *********************************  Udskriv FremtidigeAndelHaeftelser   ******************************** -->
	<xsl:template name="UdskrivFremtidigeAndelHaeftelser">
		<xsl:param name="Root" select=".//model:AndelSamling"/>

		<xsl:variable name="AntalAndeler" select="count($Root/*)" />
		<xsl:variable name="AntalAndelerSnapshot" select="count(//snapshot:AndelSnapshotStruktur)"/>
		
		<xsl:variable name="fremtidigehaeftelser">
			<xsl:if test="$AntalAndelerSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RespektHaeftelseFremtidig) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="Andele" select="."/>
					<xsl:variable name="rettigheder">
						<xsl:variable name="antalRHF" select="count(.//model:Respekt/model:RespektHaeftelseFremtidig)" />
						<xsl:for-each select=".//model:Respekt/model:RespektHaeftelseFremtidig">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() &lt; $antalRHF">
								<xsl:call-template name="linefeed" />
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>	
					<xsl:if test="$AntalAndelerSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="model:VisAndel">
							<xsl:with-param name="node" select="$Andele"/>
						</xsl:call-template>
						<xsl:call-template name="linefeed" />
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
				<xsl:call-template name="linefeed" />
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($fremtidigehaeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE FREMTIDIGE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$fremtidigehaeftelser"/>
		</xsl:if>
	</xsl:template> 
	
	<!-- ***********************************   AndelBemaerkningTekstSamling   ********************************** -->
	<xsl:template match="model:AndelBemaerkningTekstSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'BEMÆRKNING'"/>
		</xsl:call-template>
		<xsl:for-each select="model:AndelBemaerkningTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="."/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	
</xsl:stylesheet>
