<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc-2="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/05/19/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:xkom-2="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:eamsg="http://rep.oio.dk/tinglysning.dk/service/message/elektroniskakt/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
	>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: AndelsbogDokumentAktuelHent.xslt 139622 2018-09-28 07:33:06Z pnicolaj@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	
	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   MAIN   ********************************** -->
	<xsl:template match="eamsg:AndelsbogDokumentAktuelHentResultat">
		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'AKTUELT TINGLYST DOKUMENT'" />
		</xsl:call-template>
	
		<xsl:apply-templates select="eakt:DokumentAlias"/>

		<xsl:if test="model:MeddelelseOffentligAndel/model:MeddelelseOffentligTypeTekst">
			<xsl:call-template name="MeddelelseOffentligTypeHeading">
				<xsl:with-param name="MeddelelseType" select="model:MeddelelseOffentligAndel/model:MeddelelseOffentligTypeTekst"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:call-template name="AndelHaeftelseStrukturHeader">
			<xsl:with-param name="node" select="eakt:AndelHaeftelseStruktur"/>
		</xsl:call-template>
		
		<xsl:call-template name="TinglysningsDato">
			<xsl:with-param name="dato" select="model:TinglysningsDato"/>
			<xsl:with-param name="alias" select="eakt:DokumentAlias"/>
		</xsl:call-template>

		<xsl:apply-templates select="eakt:AndelMedRettighederSamling"/>

		<xsl:apply-templates select="model:MeddelelseOffentligAndel"/>
		
		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:AndelHaeftelseStruktur/eakt:AndelHaeftelseTypeTekst='privatPantebrev' or eakt:AndelHaeftelseStruktur/eakt:AndelHaeftelseTypeTekst='privatIndekspantebrev' or eakt:AndelHaeftelseStruktur/eakt:AndelHaeftelseTypeTekst='realkreditpantebrev'">
						<xsl:value-of select="'yes'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'no'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>		
		
		<xsl:apply-templates select="eakt:AndelHaeftelseStruktur"/>
		
		<!-- Hæftelser og fremtidige hæftelser -->
		<xsl:call-template name="UdskrivAndelHaeftelser">
			<xsl:with-param name="Root" select="eakt:AndelMedRettighederSamling" />
		</xsl:call-template>
		<xsl:call-template name="UdskrivFremtidigeAndelHaeftelser">
			<xsl:with-param name="Root" select="eakt:AndelMedRettighederSamling" />
		</xsl:call-template>

		<xsl:apply-templates select="eakt:AndelHaeftelseStruktur//model:HaeftelsePantebrevFormularLovpligtigKode"/>
		
		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:AndelHaeftelseStruktur/eakt:AndelHaeftelseTypeTekst='privatPantebrev'"><xsl:value-of select="'yes'"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="'no'"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			
			
			
		</xsl:apply-templates>
		<xsl:apply-templates select="eakt:AnmaerkningSamling"/>
		<xsl:apply-templates select="eakt:FristInformationSamling"/>
		<xsl:apply-templates select="eamsg:TillaegstekstSamling"/>
		<xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'true'">
			<xsl:call-template name="linefeed" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TINGLYSNINGSAFGIFT OVERFØRSEL'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Der findes en erklæring om, at hæftelsen alene indestår med henblik på overførsel af tinglysningsafgift.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="eakt:AndelAendringspaategningSamling"/>
		<xsl:apply-templates select="eakt:SenesteAnmeldelseSvar/anm:TinglysningspaategningElementSamling">
			<xsl:with-param name="vis_eksptype" select="'true'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="eakt:AndelHaeftelseStruktur">
		<xsl:apply-templates select="model:ArrestAndel"/>
		<xsl:apply-templates select="model:EjerpantebrevAndel"/>
		<xsl:apply-templates select="model:PantebrevAndel"/>
		<xsl:apply-templates select="model:SkadesloesbrevAndel"/>
		<xsl:apply-templates select="model:UdlaegAndel"/>
		<xsl:if test="model:UnderpantrettighedSamling">
			<xsl:call-template name="linefeed" />
			<xsl:apply-templates select="model:UnderpantrettighedSamling"/>
		</xsl:if>
	</xsl:template>
	
	<!-- ***********************************   AndelMedRettighederSamling   ********************************** -->
	<xsl:template match="eakt:AndelMedRettighederSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ANDEL'" />
		</xsl:call-template>
		<xsl:for-each select="eakt:AndelMedRettigheder">
			<xsl:apply-templates select="model:Andel"/>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
</xsl:stylesheet>
