<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: AndelsbogPantebrev.xslt 157192 2019-09-06 11:16:33Z cander28@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

		
	<!--*********************************************************************************************************************-->
	<!--************************************ 10 - PantebrevAndel ******************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:PantebrevAndelOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Andelsbemærkninger -->
		<xsl:apply-templates select="model:PantebrevAndel/model:AndelBemaerkningTekstSamling"/>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseSaerligLovgivning"/>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:AndelSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivAndelHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeAndelHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:PantebrevAndel/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse Anden tekst -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt - bagudkompatibelt-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>  <!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:PantebrevAndel/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:PantebrevAndel">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:AndelHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->		
		<xsl:apply-templates select="model:AndelBemaerkningTekstSamling"/>
		<xsl:if test="count(model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count(model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>


	<!--*********************************************************************************************************************-->
	<!--************************************ 14 - EjerpantebrevAndel *************************************-->
	<!--*********************************************************************************************************************-->

	<xsl:template match="msg:EjerpantebrevAndelOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:AndelSamling"/>
		<!-- Andelsbemærkninger -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:AndelBemaerkningTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseBeloeb"/>
		<!-- Underpant -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:UnderpantIndikator"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseVilkaarRente"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseVilkaarOpsigelseSamling"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivAndelHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeAndelHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt - bagudkompatibelt-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:EjerpantebrevAndel/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template match="model:EjerpantebrevAndel">
		<xsl:apply-templates select="model:AndelBemaerkningTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:if test="count(../model:UnderpantrettighedSamling) =0">
			<xsl:apply-templates select="model:UnderpantIndikator"/>
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>
	
	
	
	
	<!--*********************************************************************************************************************-->
	<!--************************************* 28 - SkadesloesbrevAndel *********************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:SkadesloesbrevAndelOpret">
		
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
	
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseSaerligLovgivning"/>

		<!-- Ejendomme -->
		<xsl:apply-templates select="model:AndelSamling"/>
		<!-- Andelsbemærkninger -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:AndelBemaerkningTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseBeloeb"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseOprykningsretIndikator"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:FuldmagtAnmeldtSamling"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivAndelHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeAndelHaeftelser"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt - bagudkompatibelt-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:SkadesloesbrevAndel/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:SkadesloesbrevAndel">
		<xsl:variable name="haeftelsestypeid" select="../eakt:AndelHaeftelseTypeTekst" />
		<xsl:if test="count(model:AndelBemaerkningTekstSamling) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:AndelBemaerkningTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarSamling"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>

	<xsl:template name="AndelHaeftelseStrukturHeader">
		<xsl:param name="node"/>

		<xsl:variable name="haeftelsestypeid" select="$node/eakt:AndelHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
		<xsl:apply-templates select="$node//model:HaeftelseLaan"/>
		<xsl:apply-templates select="$node//model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="$node//model:HaeftelseSaerligLovgivning"/>
        <xsl:call-template name="linefeed" />
	</xsl:template>



</xsl:stylesheet>
