<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:msgbil="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
    xmlns:msgandel="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>

<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: ArrestOpret.xslt 190138 2020-11-05 18:30:18Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende ArrestFastEjendomOpret -->
	<!-- 07-11-08 hpi - Rettet iht. Word eksempel - TG_ArrestFastejendom (35).doc -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	
	<!-- ***********************************   ArrestFastEjendomOpret  ********************************** -->
	<xsl:template match="msg:ArrestFastEjendomOpret">
		<xsl:call-template name="ArrestOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msg:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>
	

	<!-- ***********************************   ArrestBilOpret  ********************************** -->
	<xsl:template match="msgbil:ArrestBilOpret">
		<xsl:call-template name="ArrestOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgbil:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!-- ***********************************   ArrestAndelOpret  ********************************** -->
	<xsl:template match="msgandel:ArrestAndelOpret">
		<xsl:call-template name="ArrestOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgandel:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>
	
	<!-- ***********************************   ArrestOpret  ********************************** -->
	<xsl:template name="ArrestOpret">
		<xsl:param name="node"/>
		<xsl:param name="eksptype"/>

		<xsl:variable name="doctypeid" select="$eksptype" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
				<xsl:with-param name="proevetinglysning" select="$node/anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<!-- EjendomSamling -->
		<xsl:apply-templates select="$node/model:FastEjendomSamling"/>
		<xsl:apply-templates select="$node/model:BilSamling"/>
		<xsl:apply-templates select="$node/model:AndelSamling"/>

		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:ErklaeringSamling"/>

		<!-- Ekspeditionstype Ledetekst -->
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="$eksptype"/>
		</xsl:call-template>
		
		<!-- ArrestFastEjendom -->
		<xsl:apply-templates select="$node/model:ArrestFastEjendom"/>
		<xsl:apply-templates select="$node/model:ArrestBil"/>
		<xsl:apply-templates select="$node/model:ArrestAndel"/>
		
		<!-- AndenTekst (fraser, overskrifter og tekstafsnit) -->
		<xsl:call-template name="VisAndenTekst"> <!-- bagudkompatibel -->
			<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekst" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
		
		<xsl:call-template name="VisAndenTekstSamling">
			<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekstSamling" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
		
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	
<!--****************************************** model:ArrestDato template *************************************-->
	<xsl:template match="model:ArrestDato">
		<xsl:variable name="arrestdato">
			<xsl:call-template name="formatdato">
				<xsl:with-param name="dato" select="."/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ARRESTDATO'" />
		</xsl:call-template>
		
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="string($arrestdato)"/>
		</xsl:call-template>

		<xsl:call-template name="linefeed" />
	</xsl:template>
		
		<!--****************************************** model:ArrestBeloeb template *************************************-->		
	<xsl:template match="model:ArrestBeloeb">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ARRESTBELØB'"/>
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="format-number(floor(.//model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')" />
			<xsl:with-param name="text2" select=".//model:ValutaKode" />
		</xsl:call-template>
	</xsl:template>			
	
<!--****************************************** model:ArrestFastEjendom template *************************************-->
	<xsl:template match="model:ArrestFastEjendom | model:ArrestBil | model:ArrestAndel">
		<xsl:apply-templates select="model:ArrestBeloeb"/>
		<xsl:apply-templates select="model:ArrestDato"/>
	</xsl:template>

</xsl:stylesheet>
