<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:itst-2="http://rep.oio.dk/itst.dk/xml/schemas/2006/01/17/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:ois="http://rep.oio.dk/ois.dk/xml/schemas/2006/04/25/"
	xmlns:osak="http://rep.oio.dk/osak.dk/xml/schemas/2006/04/25/"     
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Bil.xslt 105769 2016-09-13 13:45:24Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<xsl:key name="BilStruktur" match="//snapshot:BilSnapshotStruktur" use="concat(model:BilIdentifikator/model:Stelnummer, '_',model:BilIdentifikator/model:KortStelnummer)"/>

	<!-- ***********************************   BilSamling  ********************************** -->
	
	<xsl:template match="model:BilSamling | model:RespektBilSamling">
	
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'BIL'" />
		</xsl:call-template>
		
		<xsl:for-each select="model:Bil | model:RespektBil">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	
	</xsl:template>

	<!-- ***********************************  model:Bil  ********************************** -->
	<xsl:template match="model:Bil | model:RespektBil">
		<xsl:call-template name="model:VisBil">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>

	<!-- **************************  model:BilIdentifikator   **************************** -->
	<xsl:template match="model:BilIdentifikator">
		<xsl:choose>
			<xsl:when test="./model:Stelnummer">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Stelnummer'" />
					<xsl:with-param name="text" select="./model:Stelnummer" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="./model:KortStelnummer">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Stelnummer'" />
					<xsl:with-param name="text" select="./model:KortStelnummer" />
				</xsl:call-template>
				<xsl:if test="./model:StelnummerLbnr">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Stelløbenummer'" />
						<xsl:with-param name="text" select="./model:StelnummerLbnr" />
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!-- ***********************************   model:VisBil   ********************************** -->
	<xsl:template name="model:VisBil"> 
		<xsl:param name="node"/> 
		<xsl:variable name="bilKey" select="concat($node//model:Stelnummer, '_', $node//model:KortStelnummer)"/>
		<xsl:call-template name="VisBil">
			<xsl:with-param name="bilStelnummer" select="$node"/>
			<xsl:with-param name="bilStruktur" select="key('BilStruktur', $bilKey)"/>
		</xsl:call-template>
	</xsl:template>
		
	<!-- ***********************************   VisBil   ********************************** -->
	<xsl:template name="VisBil"> 
		<xsl:param name="bilStelnummer" select="''"/> 
		<xsl:param name="bilStruktur"/> 
		<xsl:if test="$bilStelnummer!=''">
			<xsl:apply-templates select="$bilStelnummer//model:BilIdentifikator"/>
		</xsl:if>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Mærke'" />
			<xsl:with-param name="text" select="concat($bilStruktur/model:BilMaerke/model:BilFabrikatTekst,' ',$bilStruktur/model:BilMaerke/model:BilModelTekst,' ',$bilStruktur/model:BilMaerke/model:BilVariantTekst)" />
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Årgang'" />
			<xsl:with-param name="text" select="$bilStruktur/model:FoersteRegistreringsAar" />
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Registreringsnummer'" />
			<xsl:with-param name="text" select="$bilStruktur/model:RegistreringsnummerTekst" />
		</xsl:call-template>
		<!-- Bemærkning -->
		<xsl:choose>
			<xsl:when test="$bilStruktur/model:BilBemaerkningTekstSamling">
				<xsl:apply-templates select="$bilStruktur/model:BilBemaerkningTekstSamling"/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="linefeed" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ***********************************   BemaerkningSamling   ********************************** -->
	<xsl:template match="model:BilBemaerkningTekstSamling">
		<xsl:for-each select="model:BilBemaerkningTekst">
			<xsl:choose>
				<xsl:when test="position()=1">
					<xsl:call-template name="VisFraser">
						<xsl:with-param name="node" select="."/>
						<xsl:with-param name="indent_1st_line" select="'off'"/>
						<xsl:with-param name="linefeed" select="'off'"/>
						<xsl:with-param name="text" select="'Bemærkning'" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="VisFraser">
						<xsl:with-param name="node" select="."/>
						<xsl:with-param name="linefeed" select="'off'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- *********************************  UdskrivBilHaeftelser  ******************************** -->
	<xsl:template name="UdskrivBilHaeftelser">
		<xsl:param name="Root" select=".//model:BilSamling"/>
		<xsl:variable name="AntalBiler" select="count($Root/*)"/>
		<xsl:variable name="AntalBilerSnapshot" select="count(//snapshot:BilSnapshotStruktur)"/>
		<xsl:variable name="haeftelser">
			<xsl:if test="$AntalBilerSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RettighedIdentifikator) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="BilRespekt" select="."/>
					<xsl:variable name="PantRettigheder" select="key('PantRettigheder', $BilRespekt//model:Respekt/model:RettighedIdentifikator)"/>
					<xsl:variable name="rettigheder">
						<xsl:for-each select="$PantRettigheder">
							<xsl:sort select="model:Rettighed/model:Pantrettighed/model:PrioritetNummer" />
							<!-- Hvis hæftelsen hører til dette dokument, så udskriv den -->
							<xsl:variable name="rettighedIdentifikator" select="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator" />
							<!-- Hæftelsen findes i RespektSamling -->
							<xsl:variable name="dokumentIdentifikator" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
							<xsl:variable name="revisionNummer" select="model:DokumentRevisionIdentifikator/model:RevisionNummer" />
							<xsl:variable name="Struktur" select="key('DokumentStruktur', concat($dokumentIdentifikator,'_',$revisionNummer))"/>
							<xsl:if test="$BilRespekt//model:Respekt[model:RettighedIdentifikator = $rettighedIdentifikator] and $Struktur">
								<!-- Vis den dokumentstruktur, som matcher -->
								<xsl:call-template name="DokumentStruktur_Haeftelse">
									<xsl:with-param name="dokumentStruktur" select="$Struktur" />
									<xsl:with-param name="doc_id" select="$dokumentIdentifikator" />
								</xsl:call-template>
								<xsl:call-template name="linefeed" />
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>
					<xsl:if test="$AntalBilerSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="model:VisBil">
							<xsl:with-param name="node" select="$BilRespekt"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($haeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$haeftelser"/>
		</xsl:if>
	</xsl:template>
  
	<!-- *********************************  Udskriv FremtidigeBilHaeftelser   ******************************** -->
	<xsl:template name="UdskrivFremtidigeBilHaeftelser">
		<xsl:param name="Root" select=".//model:BilSamling"/>

		<xsl:variable name="AntalBiler" select="count($Root/*)" />
		<xsl:variable name="AntalBilerSnapshot" select="count(//snapshot:BilSnapshotStruktur)"/>
		
		<xsl:variable name="fremtidigehaeftelser">
			<xsl:if test="$AntalBilerSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RespektHaeftelseFremtidig) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="Koeretoej" select="."/>
					<xsl:variable name="rettigheder">
						<xsl:variable name="antalRHF" select="count(.//model:Respekt/model:RespektHaeftelseFremtidig)" />
						<xsl:for-each select=".//model:Respekt/model:RespektHaeftelseFremtidig">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() &lt; $antalRHF">
								<xsl:call-template name="linefeed" />
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>	
					<xsl:if test="$AntalBilerSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="model:VisBil">
							<xsl:with-param name="node" select="$Koeretoej"/>
						</xsl:call-template>
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
				<xsl:call-template name="linefeed" />
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($fremtidigehaeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE FREMTIDIGE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$fremtidigehaeftelser"/>
		</xsl:if>
	</xsl:template> 
	
</xsl:stylesheet>
