<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc-2="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/05/19/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:xkom-2="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:eamsg="http://rep.oio.dk/tinglysning.dk/service/message/elektroniskakt/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:msgadm="http://rep.oio.dk/tinglysning.dk/service/message/administration/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
	>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: BilbogDokumentAktuelHent.xslt 139622 2018-09-28 07:33:06Z pnicolaj@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	
	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   MAIN   ********************************** -->
	<xsl:template match="eamsg:BilbogDokumentAktuelHentResultat">
		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'AKTUELT TINGLYST DOKUMENT'" />
		</xsl:call-template>
	
		<xsl:apply-templates select="eakt:DokumentAlias"/>

		<xsl:if test="model:MeddelelseOffentligBil/model:MeddelelseOffentligTypeTekst">
			<xsl:call-template name="MeddelelseOffentligTypeHeading">
				<xsl:with-param name="MeddelelseType" select="model:MeddelelseOffentligBil/model:MeddelelseOffentligTypeTekst"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:call-template name="BilHaeftelseStrukturHeader">
			<xsl:with-param name="node" select="eakt:BilHaeftelseStruktur"/>
		</xsl:call-template>
		
		<xsl:call-template name="TinglysningsDato">
			<xsl:with-param name="dato" select="model:TinglysningsDato"/>
			<xsl:with-param name="alias" select="eakt:DokumentAlias"/>
		</xsl:call-template>

		<xsl:apply-templates select="eakt:BilMedRettighederSamling"/>

		<xsl:apply-templates select="model:MeddelelseOffentligBil"/>

		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:BilHaeftelseStruktur/eakt:BilHaeftelseTypeTekst='privatPantebrev' or eakt:BilHaeftelseStruktur/eakt:BilHaeftelseTypeTekst='privatIndekspantebrev' or eakt:BilHaeftelseStruktur/eakt:BilHaeftelseTypeTekst='realkreditpantebrev'">
						<xsl:value-of select="'yes'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'no'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>

		<xsl:apply-templates select="eakt:BilHaeftelseStruktur"/>

		<!-- Hæftelser og fremtidige hæftelser -->
		<xsl:call-template name="UdskrivBilHaeftelser">
			<xsl:with-param name="Root" select="eakt:BilMedRettighederSamling" />
		</xsl:call-template>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser">
			<xsl:with-param name="Root" select="eakt:BilMedRettighederSamling" />
		</xsl:call-template>

		<xsl:apply-templates select="eakt:BilHaeftelseStruktur//model:HaeftelsePantebrevFormularLovpligtigKode"/>
		
		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:BilHaeftelseStruktur/eakt:BilHaeftelseTypeTekst='ejendomsforbehold' or eakt:BilHaeftelseStruktur/eakt:BilHaeftelseTypeTekst='privatPantebrev'"><xsl:value-of select="'yes'"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="'no'"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>
		<xsl:apply-templates select="eakt:AnmaerkningSamling"/>
		<xsl:apply-templates select="eakt:FristInformationSamling"/>
		<xsl:apply-templates select="eamsg:TillaegstekstSamling"/>
		<xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'true'">
			<xsl:call-template name="linefeed" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TINGLYSNINGSAFGIFT OVERFØRSEL'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Der findes en erklæring om, at hæftelsen alene indestår med henblik på overførsel af tinglysningsafgift.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="eakt:BilAendringspaategningSamling"/>
		<xsl:apply-templates select="eakt:SenesteAnmeldelseSvar/anm:TinglysningspaategningElementSamling">
			<xsl:with-param name="vis_eksptype" select="'true'"/>
		</xsl:apply-templates>
	</xsl:template>
	
<!-- ***********************************   BilHaeftelseStruktur   ********************************** -->
	<xsl:template match="eakt:BilHaeftelseStruktur">
		<xsl:apply-templates select="model:ArrestBil"/> 
		<xsl:apply-templates select="model:EjendomsforbeholdBil"/>
		<xsl:apply-templates select="model:EjerpantebrevBil"/>
		<xsl:apply-templates select="model:PantebrevBil"/>
		<xsl:apply-templates select="model:SkadesloesbrevBil"/>
		<xsl:apply-templates select="model:UdlaegBil"/>
			<xsl:if test="model:UnderpantrettighedSamling">
			<xsl:call-template name="linefeed" />
			<xsl:apply-templates select="model:UnderpantrettighedSamling"/>
		</xsl:if>
</xsl:template>
	
	<!-- ***********************************   BilMedRettighederSamling   ********************************** -->
	<xsl:template match="eakt:BilMedRettighederSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'BIL'" />
		</xsl:call-template>
		<xsl:for-each select="eakt:BilMedRettigheder">
			<xsl:apply-templates select="model:Bil"/>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
</xsl:stylesheet>
