<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: BilbogPantebrev.xslt 157192 2019-09-06 11:16:33Z cander28@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

		
	<!--*********************************************************************************************************************-->
	<!--************************************ 8 - PantebrevBil ******************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:PantebrevBilOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseSaerligLovgivning"/>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:BilSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivBilHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:PantebrevBil/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:PantebrevBil/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:PantebrevBil">
	<!--
		<xsl:variable name="haeftelsestypeid" select="../eakt:BilHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
   -->
		<xsl:if test="count(model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count(model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>


	<!--*********************************************************************************************************************-->
	<!--************************************ 12 - EjerpantebrevBil *************************************-->
	<!--*********************************************************************************************************************-->

	<xsl:template match="msg:EjerpantebrevBilOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:BilSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseBeloeb"/>
		<!-- Underpant -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:UnderpantIndikator"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseVilkaarRente"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseVilkaarOpsigelseSamling"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivBilHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftlese anden tekst -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:EjerpantebrevBil/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template match="model:EjerpantebrevBil">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:BilHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->		
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:if test="count(../model:UnderpantrettighedSamling) =0">
			<xsl:apply-templates select="model:UnderpantIndikator"/>
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>
	
	
	
	
	<!--*********************************************************************************************************************-->
	<!--************************************* 25 - SkadesloesbrevBil *********************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:SkadesloesbrevBilOpret">
		
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
	
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseSaerligLovgivning"/>

		<!-- Ejendomme -->
		<xsl:apply-templates select="model:BilSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseBeloeb"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseOprykningsretIndikator"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:FuldmagtAnmeldtSamling"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivBilHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:SkadesloesbrevBil/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:SkadesloesbrevBil">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:BilHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->		
		<xsl:if test="count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarSamling"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<!--<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>-->
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--************************************ 39 - EjendomsforbeholdBil ******************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:EjendomsforbeholdBilOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<!-- Bil -->
		<xsl:apply-templates select="model:BilSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:if test="model:EjendomsforbeholdBil/model:HaeftelseLoebetid">
			<xsl:call-template name="HaeftelseLoebetid">
				<xsl:with-param name="node" select="model:EjendomsforbeholdBil/model:HaeftelseLoebetid"/>
				<xsl:with-param name="fastIndikatorTekst" select="'Løbetiden er anslået.'" />
			</xsl:call-template>
		</xsl:if>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseVilkaarRente"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivBilHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:EjendomsforbeholdBil/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:EjendomsforbeholdBil">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:BilHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->
		<xsl:if test="count(model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count(model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:if test="model:HaeftelseLoebetid">
			<xsl:call-template name="HaeftelseLoebetid">
				<xsl:with-param name="node" select="model:HaeftelseLoebetid"/>
				<xsl:with-param name="fastIndikatorTekst" select="'Løbetiden er anslået.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
	</xsl:template>
	
	<xsl:template name="BilHaeftelseStrukturHeader">
		<xsl:param name="node"/>

		<xsl:variable name="haeftelsestypeid" select="$node/eakt:BilHaeftelseTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
		<xsl:apply-templates select="$node//model:HaeftelseLaan"/>
		<xsl:apply-templates select="$node//model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="$node//model:HaeftelseSaerligLovgivning"/>
        <xsl:call-template name="linefeed" />
	</xsl:template>
	
</xsl:stylesheet>
