<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:itst-2="http://rep.oio.dk/itst.dk/xml/schemas/2006/01/17/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:ois="http://rep.oio.dk/ois.dk/xml/schemas/2006/04/25/" 
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Dokument.xslt 158162 2019-09-24 11:31:09Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende Dokumenter  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<!-- ***************************************************************************************** -->
  
	<xsl:template name="DokumentStruktur_Haeftelse">
		<xsl:param name="dokumentStruktur"/>
		<xsl:param name="doc_id"/>
		<xsl:param name="visAliasLink" select="'true'"/>

		<!-- Dato/løbenummer -->
		<xsl:call-template name="eakt:DokumentAliasIdentifikator">
			<xsl:with-param name="node" select="$dokumentStruktur"/>
			<xsl:with-param name="visAliasLink" select="$visAliasLink"/>
		</xsl:call-template>
		<!-- Dokumenttype -->
		<xsl:variable name="doctypeid" select="concat($dokumentStruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseFastEjendomIdentifikator, $dokumentStruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseBilIdentifikator, $dokumentStruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseAndelIdentifikator, $dokumentStruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseLoesoereIdentifikator)"/> 
		<xsl:if test="$doctypeid != ''">
			<xsl:variable name="eksptypenavn" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Dokumenttype'"/>
				<xsl:with-param name="text">
					<xsl:choose>
						<xsl:when test="$eksptypenavn = 'SDRO-PANTEBREV'">
							<xsl:value-of select="'SDRO-Pantebrev'" />
						</xsl:when>
						<xsl:when test="$eksptypenavn = 'SDO-PANTEBREV'">
							<xsl:value-of select="'SDO-Pantebrev'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="concat(substring($eksptypenavn,1,1),translate(substring($eksptypenavn,2),'ABCDEFGHIJKLMNOPQRSTUVWXYZÆØÅ','abcdefghijklmnopqrstuvwxyzæøå'))" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param> 
			</xsl:call-template>
		</xsl:if>
		<!-- Hovedstol -->
		<xsl:call-template name="Hovedstol">
			<xsl:with-param name="node" select="$dokumentStruktur"/>
		</xsl:call-template>
		<!-- Rentesats -->
		<xsl:call-template name="model:HaeftelseRenteSats_sub">
			<xsl:with-param name="node" select="$dokumentStruktur/model:HaeftelseInformation/model:HaeftelseRenteSats"/>
		</xsl:call-template>
		<!-- Lånetype -->
		<xsl:call-template name="model:HaeftelseLaantypeKode_sub">
			<xsl:with-param name="node" select="$dokumentStruktur/model:HaeftelseInformation/model:HaeftelseLaantypeKode"/>
		</xsl:call-template>
		<!-- Særligevilkår -->
		<xsl:apply-templates select="$dokumentStruktur/model:HaeftelseInformation/model:HaeftelseSaerligeLaanevilkaarstypeSamling"/>
		<!-- Kreditor -->
		<xsl:apply-templates select="$dokumentStruktur/model:HaeftelseInformation/model:KreditorInformationSamling"/>	
	</xsl:template>
  
	<!-- ***********************************   KreditorSamling   ********************************** -->
	<xsl:template match="model:KreditorSamling">
		<xsl:for-each select="model:Kreditor">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:template>

	<!-- ***********************************   KreditorInformationSamling   ********************************** -->
	<xsl:template match="model:KreditorInformationSamling"> 
		<xsl:for-each select="model:RolleInformation">
			<xsl:if test="./model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Kreditor'"/>
					<xsl:with-param name="text" select="./model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="./model:PersonSimpelIdentifikator/itst-2:PersonName">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Kreditor'"/>
					<xsl:with-param name="text" select="./model:PersonSimpelIdentifikator/itst-2:PersonName"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- ***********************************   Kreditor   ********************************** -->
	<xsl:template match="model:Kreditor">
		<!-- Kreditor -->
		<xsl:variable name="kreditorId" select="./@id"/>
		
		<xsl:choose>
			<xsl:when test="key('RolleStruktur', $kreditorId)">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Kreditor'"/>
					<!--<xsl:with-param name="text" select="//snapshot:SnapshotSamling/snapshot:RolleSamling/snapshot:RolleStruktur[snapshot:RolleReference = $kreditorId]/snapshot:Navn"/>-->
					<xsl:with-param name="text" select="key('RolleStruktur', $kreditorId)/snapshot:Navn"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Kreditor'"/>
					<xsl:with-param name="text" select="itst-2:PersonName"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>	
  
  
	<!-- ***********************************   Kreditor   ********************************** -->
	<xsl:template name="Kreditor">
		<xsl:param name="node" select="."/>
		<xsl:variable name="kreditorId" select="$node/@id"/>

		<xsl:if test="//snapshot:SnapshotSamling/snapshot:RolleSamling/snapshot:RolleStruktur[snapshot:RolleReference = $kreditorId]">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Kreditor'"/>
				<xsl:with-param name="text" select="//snapshot:SnapshotSamling/snapshot:RolleSamling/snapshot:RolleStruktur[snapshot:RolleReference = $kreditorId]/snapshot:Navn"/>
			</xsl:call-template>
		</xsl:if>

	</xsl:template>	
  
  
	<!-- ***************************************************************************************** -->
	<xsl:template name="DokumentStruktur_Servitut">
		<xsl:param name="dokumentStruktur"/>
		<xsl:param name="doc_id"/>
		<xsl:param name="visAliasLink" select="'true'"/>
		
		<!-- Dato/løbenummer -->
		<xsl:call-template name="eakt:DokumentAliasIdentifikator">
			<xsl:with-param name="node" select="$dokumentStruktur"/>
			<xsl:with-param name="visAliasLink" select="$visAliasLink"/>
		</xsl:call-template>
		<!-- Dokumenttype -->
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Dokumenttype'"/>
			<xsl:with-param name="text" select="$opslag//ServitutType[@id = $dokumentStruktur/model:ServitutType]"/>
		</xsl:call-template>
		<xsl:if test="$dokumentStruktur/model:ServitutInformationType">
		<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Servitut'"/>
				<xsl:with-param name="text" select="$opslag//ServitutInformationType[@id = $dokumentStruktur/model:ServitutInformationType]"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$dokumentStruktur/eakt:ServitutTekstSummarisk">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$dokumentStruktur/eakt:ServitutTekstSummarisk"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
  
	<!-- ***************************************************************************************** -->
  	<xsl:template name="DokumentStruktur_Adkomst">
		<xsl:param name="dokumentStruktur"/>
		<xsl:param name="doc_id"/>
		<xsl:param name="visAliasLink" select="'true'"/>
		
		<!-- Dato/løbenummer -->
		<xsl:call-template name="eakt:DokumentAliasIdentifikator">
			<xsl:with-param name="node" select="$dokumentStruktur"/>
			<xsl:with-param name="visAliasLink" select="$visAliasLink"/>
		</xsl:call-template>
		<!-- Dokumenttype -->
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Dokumenttype'"/>
			<xsl:with-param name="text" select="$opslag//AdkomstType[@id = $dokumentStruktur/eakt:AdkomstSummarisk/eakt:AdkomstType]"/>
		</xsl:call-template>
		<!-- Adkomsthavere -->
		<xsl:call-template name="eakt:AdkomsthaverSamling">
			<xsl:with-param name="node" select="$dokumentStruktur/eakt:AdkomstSummarisk/eakt:AdkomsthaverSamling"/>
		</xsl:call-template>
	</xsl:template>
  
	<!-- ***************************************************************************************** -->
	<xsl:template name="eakt:AdkomsthaverSamling">
		<xsl:param name="node"/>
		<xsl:variable name="Root" select="$node/eakt:Adkomsthaver"/>
		
		<xsl:for-each select="$node/eakt:Adkomsthaver">
			<xsl:variable name="Adk" select="."/>
			<xsl:choose>
				<xsl:when test="$Adk = $Root[position()=1]">
					<xsl:choose>
						<xsl:when test="model:PersonSimpelIdentifikator/itst-2:PersonName">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Adkomsthavere'"/>
								<xsl:with-param name="text" select="model:PersonSimpelIdentifikator/itst-2:PersonName"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Adkomsthavere'"/>
								<xsl:with-param name="text" select="model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="model:PersonSimpelIdentifikator/itst-2:PersonName">
							<xsl:call-template name="column2">
								<xsl:with-param name="text" select="model:PersonSimpelIdentifikator/itst-2:PersonName"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="column2">
								<xsl:with-param name="text" select="model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>

			<!-- AdresseStruktur fra snapshot. 
				 Findes ud fra MunicipalityCode og StreetCode fra EjendomStrukturen i snapshot -->
			<xsl:variable name="municipalityCode" select="xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:MunicipalityCode"/>
			<xsl:variable name="streetCode"       select="xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:StreetCode"/>
			<xsl:variable name="streetBuildingIdentifier" select="xkom:AddressSpecific/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier"/>
			<xsl:variable name="floorIdentifier" select="xkom:AddressSpecific/dkcc-1:FloorIdentifier"/>
			<xsl:variable name="suiteIdentifier" select="xkom:AddressSpecific/dkcc-1:SuiteIdentifier"/>
			<xsl:call-template name="model:VisAdresse"> 
				<xsl:with-param name="MunicipalityCode" select="$municipalityCode"/> 
				<xsl:with-param name="StreetCode" select="$streetCode"/> 
				<xsl:with-param name="StreetBuildingIdentifier" select="$streetBuildingIdentifier"/> 
				<xsl:with-param name="FloorIdentifier" select="$floorIdentifier"/> 
				<xsl:with-param name="SuiteIdentifier" select="$suiteIdentifier"/> 
			</xsl:call-template> 
			<xsl:if test="model:VirksomhedSimpelIdentifikator/cvr:CVRnumberIdentifier">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="model:VirksomhedSimpelIdentifikator/cvr:CVRnumberIdentifier"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:PersonSimpelIdentifikator/dkcc:BirthDate">
				<xsl:variable name="birthdate" select="model:PersonSimpelIdentifikator/dkcc:BirthDate"/>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat(substring($birthdate,9,2),substring($birthdate,6,2),substring($birthdate,3,2),'-****')"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
		
  	</xsl:template>
 
	<!-- ***************************************************************************************** -->
  	<xsl:template name="DokumentStruktur_Meddelelse">
			<xsl:param name="dokumentStruktur"/>
			<xsl:param name="doc_id"/>
			<xsl:param name="visAliasLink" select="'true'"/>
		
			<xsl:call-template name="eakt:DokumentAliasIdentifikator">
				<xsl:with-param name="node" select="$dokumentStruktur"/>
				<xsl:with-param name="visAliasLink" select="$visAliasLink"/>
			</xsl:call-template>
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Dokumenttype'"/>
				<xsl:with-param name="text" select="$opslag//MeddelelseTekstType[@id = $dokumentStruktur/eakt:MeddelelseSummarisk/model:MeddelelseOffentligTypeTekst]"/>
			</xsl:call-template>
			<xsl:apply-templates select="$dokumentStruktur/eakt:MeddelelseSummarisk/eakt:DisponentInformationSamling"/>
		</xsl:template>

	<!-- ***********************************   DisponentInformationSamling   ********************************** -->
	<xsl:template match="eakt:DisponentInformationSamling">
		<xsl:for-each select="model:RolleInformation">
			<xsl:if test="./model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Disponent'"/>
					<xsl:with-param name="text" select="./model:VirksomhedSimpelIdentifikator/cvr:LegalUnitName"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="./model:PersonSimpelIdentifikator/itst-2:PersonName">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Disponent'"/>
					<xsl:with-param name="text" select="./model:PersonSimpelIdentifikator/itst-2:PersonName"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

  <!-- ****************   EkspeditionstypeHaeftelseIdentifikator   ****************** -->
    <xsl:template match="model:EkspeditionstypeHaeftelseAndelIdentifikator | model:EkspeditionstypeHaeftelseBilIdentifikator | model:EkspeditionstypeHaeftelseFastEjendomIdentifikator | model:EkspeditionstypeHaeftelseLoesoereIdentifikator">
			<xsl:variable name="eksptype" select="." />
			<xsl:variable name="eksptypenavn" select="$opslag//Ekspeditionstype[@id = $eksptype]" />
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Dokumenttype'"/>
				<xsl:with-param name="text">
					<xsl:choose>
						<xsl:when test="$eksptypenavn = 'SDRO-PANTEBREV'">
							<xsl:value-of select="'SDRO-Pantebrev'" />
						</xsl:when>
						<xsl:when test="$eksptypenavn = 'SDO-PANTEBREV'">
							<xsl:value-of select="'SDO-Pantebrev'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="concat(substring($eksptypenavn,1,1),translate(substring($eksptypenavn,2),'ABCDEFGHIJKLMNOPQRSTUVWXYZÆØÅ','abcdefghijklmnopqrstuvwxyzæøå'))" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>				
    </xsl:template> 
 
</xsl:stylesheet>
