<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc-2="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/05/19/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:xkom-2="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:eamsg="http://rep.oio.dk/tinglysning.dk/service/message/elektroniskakt/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"	
	>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DokumentAktuelHent.xslt 190533 2020-11-17 12:39:16Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	
	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   MAIN   ********************************** -->
	<xsl:template match="eamsg:DokumentAktuelHentResultat">
		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'AKTUELT TINGLYST DOKUMENT'" />
		</xsl:call-template>
	
		<xsl:apply-templates select="eakt:DokumentAlias"/>
		
		<xsl:if test="eakt:AdkomstStruktur">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'ADKOMSTTYPE'"/>
			</xsl:call-template>
			<xsl:variable name="AdkomstType" select="eakt:AdkomstStruktur/eakt:AdkomstType" />
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//AdkomstType[@id = $AdkomstType]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>		

        <xsl:if test="model:Servitut">        
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'SERVITUT'"/>
			</xsl:call-template>
			<xsl:variable name="ServitutType" select="model:Servitut/model:ServitutType"/>
			<xsl:if test="$opslag//ServitutType[@id = $ServitutType] != 'Servitut'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Dokumenttype'"/>
					<xsl:with-param name="text" select="$opslag//ServitutType[@id = $ServitutType]"/>
				</xsl:call-template>
				
			</xsl:if>
        </xsl:if>

		<xsl:call-template name="HaeftelseStrukturHeader">
			<xsl:with-param name="node" select="eakt:HaeftelseStruktur"/>
		</xsl:call-template>
		
		<xsl:call-template name="TinglysningsDato">
			<xsl:with-param name="dato" select="model:TinglysningsDato"/>
			<xsl:with-param name="alias" select="eakt:DokumentAlias"/>
		</xsl:call-template>

		<xsl:apply-templates select="eakt:FastEjendomMedRettighederSamling"/>
        
        <xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'false'">
			<xsl:apply-templates select="model:Servitut"/>
		</xsl:if>

		<!--<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation/model:RolleSamling"/>-->
		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:HaeftelseStruktur/eakt:HaeftelseType='privatPantebrev' or eakt:HaeftelseStruktur/eakt:HaeftelseType='privatIndekspantebrev' or eakt:HaeftelseStruktur/eakt:HaeftelseType='realkreditpantebrev'">
						<xsl:value-of select="'yes'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'no'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="skoedetekst">
				<xsl:choose>
					<xsl:when test="eakt:AdkomstStruktur/eakt:AdkomstType='skoede'">
						<xsl:value-of select="'true'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'false'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
			<xsl:with-param name="skoedevirksomhedoverdragelse">
				<xsl:choose>
					<xsl:when test="eakt:AdkomstStruktur/eakt:AdkomstType='skoede' and eakt:AdkomstStruktur/model:Skoede/model:VirksomhedOverdragelseIndikator='true'">
						<xsl:value-of select="'true'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'false'"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>

		<xsl:variable name="dokid" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator"/>
		<!-- Tag landsejerlavnavn fra snapshot -->
		<xsl:variable name="dokstruktur" select="//snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $dokid]"/>
		<!--<xsl:value-of select="$dokstruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseFastEjendomIdentifikator"/>-->
		<xsl:call-template name="OversaetOgUdskrivSkylnderErklaering">
		<xsl:with-param name="ekstype" select="$dokstruktur/model:HaeftelseInformation/model:EkspeditionstypeHaeftelseFastEjendomIdentifikator" />
		</xsl:call-template>
          	
		<xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'true'">
			<xsl:apply-templates select="eakt:HaeftelseStruktur//model:HaeftelseBeloeb"/>
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TINGLYSNINGSAFGIFT OVERFØRSEL'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Der findes en erklæring om, at hæftelsen alene indestår med henblik på overførsel af tinglysningsafgift.'" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	
		<xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'false'">
			<xsl:apply-templates select="eakt:AdkomstStruktur"/>
			<xsl:apply-templates select="eakt:HaeftelseStruktur"/>
		
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
			<xsl:call-template name="UdskrivHaeftelser">
				<xsl:with-param name="Root" select="eakt:FastEjendomMedRettighederSamling" />
			</xsl:call-template>
			<xsl:call-template name="UdskrivFremtidigeHaeftelser">
				<xsl:with-param name="Root" select="eakt:FastEjendomMedRettighederSamling" />
			</xsl:call-template>
			<xsl:call-template name="UdskrivServitutter">
				<xsl:with-param name="Root" select="eakt:FastEjendomMedRettighederSamling" />
			</xsl:call-template>		
			
			<xsl:apply-templates select="eakt:HaeftelseStruktur//model:HaeftelsePantebrevFormularLovpligtigKode"/>
			
			<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation">
				<!--<xsl:with-param name="gaeldsansvar">
					<xsl:choose>
						<xsl:when test="eakt:HaeftelseStruktur/eakt:HaeftelseType='privatPantebrev' or eakt:HaeftelseStruktur/eakt:HaeftelseType='privatIndekspantebrev' or eakt:HaeftelseStruktur/eakt:HaeftelseType='realkreditpantebrev'">
							<xsl:value-of select="'yes'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="'no'"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>-->
			</xsl:apply-templates>
			<xsl:apply-templates select="eakt:AnmaerkningSamling"/>
			<xsl:apply-templates select="eakt:FristInformationSamling"/>
			<xsl:apply-templates select="eamsg:TillaegstekstSamling"/>
			<xsl:apply-templates select="eakt:AendringspaategningSamling"/>
			<xsl:apply-templates select="eakt:SenesteAnmeldelseSvar/anm:TinglysningspaategningElementSamling">
				<xsl:with-param name="vis_eksptype" select="'true'"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="eakt:AdkomstStruktur">
		<xsl:variable name="AdkomstType" select="eakt:AdkomstType" />
		<xsl:choose>
			<xsl:when test="$AdkomstType ='skifteretsattest'">
				<xsl:apply-templates select="model:SkifteretsAttest"/>
			</xsl:when>
			<xsl:when test="$AdkomstType ='skoede'">
				<xsl:apply-templates select="model:Skoede"/>
			</xsl:when>
			<xsl:when test="$AdkomstType ='skoedeBetinget'">
				<xsl:apply-templates select="model:Skoede"/>
			</xsl:when>
			<xsl:when test="$AdkomstType ='auktionsskoede'">
				<xsl:apply-templates select="model:SkoedeAuktion"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="model:MeddelelseOffentlig"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="eakt:HaeftelseStruktur">
		<xsl:apply-templates select="model:AndenHaeftelseFastEjendom"/>
		<xsl:apply-templates select="model:ArrestFastEjendom"/>
		<xsl:if test="count(model:EjerpantebrevFastEjendom) > 0">
			<xsl:call-template name="EjerpantebrevFastEjendom">
				<xsl:with-param name="node" select="model:EjerpantebrevFastEjendom"/>
				<xsl:with-param name="visType" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="count(model:IndekspantebrevFastEjendom) > 0">
			<xsl:call-template name="IndekspantebrevFastEjendom">
				<xsl:with-param name="node" select="model:IndekspantebrevFastEjendom"/>
				<xsl:with-param name="visType" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="count(model:PantebrevFastEjendom) > 0">
			<xsl:call-template name="PantebrevFastEjendom">
				<xsl:with-param name="node" select="model:PantebrevFastEjendom"/>
				<xsl:with-param name="visType" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="model:Realkreditpantebrev"/> 
		<xsl:if test="count(model:SkadesloesbrevFastEjendom) > 0">
			<xsl:call-template name="PantebrevFastEjendom">
				<xsl:with-param name="node" select="model:SkadesloesbrevFastEjendom"/>
				<xsl:with-param name="visType" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="model:UdlaegFastEjendom"/>
		<xsl:if test="model:UnderpantrettighedSamling">
			<xsl:call-template name="linefeed" />
			<xsl:apply-templates select="model:UnderpantrettighedSamling"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="model:Servitut">
		<!-- ServitutInformation -->
		<xsl:apply-templates select="model:ServitutInformation"/>
		<!-- ServitutTekst -->
		<xsl:apply-templates select="model:ServitutTekstSamling"/>
		<!-- Forrang -->
		<xsl:call-template name="VisServitutInformationForrang">
			<xsl:with-param name="node" select="model:ServitutInformation"/>
			<xsl:with-param name="overskrift" select="'OPLYSNINGER OM SERVITUTTEN'"/>
		</xsl:call-template>
		
		<!-- Servitut Tidsbegrænsning -->
		<xsl:apply-templates select="model:ServitutInformation/model:Tidsbegraensning">
			<xsl:with-param name="overskrift" select="'TIDSBEGRÆNSNING'"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="eakt:ElektroniskaktAnmeldelseInformation">
		<xsl:param name="gaeldsansvar" select="'no'" />
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ELEKTRONISK AKT ANMELDELSE INFORMATION'"/>
		</xsl:call-template>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmelderInformation">
			<xsl:with-param name="include_adskiller" select="'false'"/>
		</xsl:apply-templates>

		<!-- Bilag -->
		<xsl:apply-templates select="model:BilagReferenceSamling"/>
		<xsl:apply-templates select="model:ErklaeringSamling"/>
		
		<!-- Betalt tinglysningsafgift -->
		<xsl:variable name="ffmLDTT" select="..//eakt:LoesoereDokumentTypeTekst"/>
		<xsl:if test="not($ffmLDTT = 'fremtidsfuldmagt')"> 
 		  <xsl:if test="model:TinglysningAfgift/model:Afgiftsbeloeb">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'BETALT TINGLYSNINGSAFGIFT'"/>
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="format-number(floor(model:TinglysningAfgift/model:Afgiftsbeloeb), '###.###.###.###.##0', 'currency-format')"/>
				<xsl:with-param name="text2" select="'DKK'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed"/>
		  </xsl:if>
		</xsl:if>
	</xsl:template>

    <xsl:template match="eamsg:TillaegstekstSamling">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TILLÆGSTEKST'"/>
			</xsl:call-template>
			<xsl:for-each select="model:TekstAngivelse">
				<xsl:call-template name="VisFraser">
					<xsl:with-param name="node" select="."/>
				</xsl:call-template>
			</xsl:for-each>
    </xsl:template>

</xsl:stylesheet>
