<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"

    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    >
    
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DokumentAlias.xslt 63505 2020-11-13 cander28@dxc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   DokumentAlias   ********************************** -->
	<!-- Viser Dato/løbenr med ledetekst og overskift DOKUMENTALIAS -->
	<xsl:template match="eakt:DokumentAlias">
		<xsl:variable name="AktHistoriskIdentifikator" select="eakt:AktHistoriskIdentifikator"/>
		<xsl:variable name="DokumentAliasIdentifikator" select="eakt:DokumentAliasIdentifikator"/>
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'DOKUMENT'" />
		</xsl:call-template>
		
		<xsl:choose>
			<xsl:when test="$AktHistoriskIdentifikator!=''">
				<xsl:call-template name="DokumentAlias">
					<xsl:with-param name="Identifikator" select="$AktHistoriskIdentifikator"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="DokumentAlias">
					<xsl:with-param name="Identifikator" select="$DokumentAliasIdentifikator"/>
					<xsl:with-param name="indent" select="'false'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
		
		<xsl:if test="../eakt:RelateredeDokumenter">
			<xsl:apply-templates select="../eakt:RelateredeDokumenter"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>

	<!-- ***********************************   DokumentAlias   ********************************** -->
	<xsl:template name="DokumentAlias">
		<xsl:param name="prompt" select="'Dato/løbenummer'"/>
		<xsl:param name="Identifikator"/>
		<xsl:param name="indent" select="'true'"/>

		<xsl:variable name="new_identifikator" select="concat(substring($Identifikator,7,2),'.',substring($Identifikator,5,2),'.',substring($Identifikator,1,4),substring($Identifikator, 9))"/>
		<xsl:choose>
			<xsl:when test="string-length($prompt) = 0">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="$new_identifikator"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$indent='true'">
						<xsl:call-template name="two_columns_sub">
							<xsl:with-param name="prompt" select="$prompt" />
							<xsl:with-param name="text" select="$new_identifikator"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="two_columns">
							<xsl:with-param name="prompt" select="$prompt" />
							<xsl:with-param name="text" select="$new_identifikator"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- *********************************   DokumentAliasLink   ******************************** -->
	<xsl:template name="DokumentAliasLink">
		<xsl:param name="prompt" select="'Dato/løbenummer'"/>
		<xsl:param name="Identifikator"/>
		<xsl:param name="indent" select="'true'"/>

		<xsl:variable name="new_identifikator" select="concat(substring($Identifikator,7,2),'.',substring($Identifikator,5,2),'.',substring($Identifikator,1,4),substring($Identifikator, 9))"/>
		<xsl:choose>
			<xsl:when test="string-length($prompt) = 0">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="$new_identifikator"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$indent='true'">
						<xsl:call-template name="two_columns_link">
							<xsl:with-param name="prompt" select="$prompt" />
							<xsl:with-param name="text" select="$new_identifikator"/>
							<xsl:with-param name="link" select="concat('VISTINGLYSTDOKUMENT#', $new_identifikator,'#')"/>
							<xsl:with-param name="target" select="'_blank'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="two_columns_link">
							<xsl:with-param name="prompt" select="$prompt" />
							<xsl:with-param name="text" select="$new_identifikator"/>
							<xsl:with-param name="link" select="concat('VISTINGLYSTDOKUMENT#', $new_identifikator,'#')"/>
							<xsl:with-param name="target" select="'_blank'"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ************************   eakt:RelateredeDokumenter   **************************** -->
	<xsl:template match="eakt:RelateredeDokumenter">
		<xsl:variable name="Alias1" select="substring-after(../eakt:RelateredeDokumenter, 'Alias:')"/>
		<xsl:variable name="Alias2" select="substring-after($Alias1, 'Alias:')"/>
		<xsl:variable name="Alias3" select="substring-before($Alias1, '.')"/>
		
		<xsl:variable name="RelateredeDokumenter">
			<xsl:choose>
				<xsl:when test="$Alias3 != ''">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Relaterede dokumenter'" />
						<xsl:with-param name="text" select="$Alias2"/>
					</xsl:call-template>
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$Alias3"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Relaterede dokumenter'" />
						<xsl:with-param name="text" select="$Alias1"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:value-of select="$RelateredeDokumenter"/>
	</xsl:template>


</xsl:stylesheet>


