<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/">

<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DokumentFastEjendomOpret.xslt 186814 2020-10-07 11:16:15Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende DokumentFastEjendomOpret -->
	<!-- 06-11-08 hpi - Ændret i  forhold til Word eksempel - TG_Uskadelighedsattest (183).doc -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	
	<!-- ***********************************   DokumentFastEjendomOpret  ********************************** -->
	<xsl:template match="msg:DokumentFastEjendomOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<!-- FastEjendomSamling -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>

		<!-- RolleSamling  -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>

		<!-- DokumentFastEjendom -->
		<xsl:apply-templates select="model:DokumentFastEjendom"/>
		
		<!-- NavneaendringAdkomstFastEjendomTekst -->
		<xsl:apply-templates select="anm:NavneaendringAdkomstFastEjendomTekst"/>
		
		<!-- AndenTekst (fraser, overskrifter og tekstafsnit) -->
		<xsl:variable name="overskrift">
			<xsl:choose>
				<xsl:when test="$doctypeid='6'"><xsl:value-of select="'DOKUMENTTEKST'"/></xsl:when>
				<xsl:when test="$doctypeid='115'"><xsl:value-of select="'DOKUMENTTEKST'"/></xsl:when>
				<xsl:when test="$doctypeid='116'"><xsl:value-of select="'DOM TEKST'"/></xsl:when>
				<xsl:when test="$doctypeid='183'"><xsl:value-of select="'ANMODNING'"/></xsl:when>
				<xsl:when test="$doctypeid='203'"><xsl:value-of select="'HÆVD TEKST'"/></xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'FEJL: Overskrift til AndenTekst mangler'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:call-template name="VisAndenTekst"> <!-- bagudkompatibel -->
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekst" />
			<xsl:with-param name="overskrift" select="$overskrift" />
		</xsl:call-template>
		<xsl:call-template name="VisAndenTekstSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekstSamling" />
			<xsl:with-param name="overskrift" select="$overskrift" />
		</xsl:call-template>

		<xsl:if test="$doctypeid='6' or $doctypeid='115' or $doctypeid='203'">
			<!-- Hæftelser, fremtidige hæftelser og servitutter -->
			<xsl:call-template name="UdskrivHaeftelser"/>
			<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
			<xsl:call-template name="UdskrivServitutter"/>
		</xsl:if>

		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- BilagReferenceSamling -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling"/>

		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		
		<xsl:if test="$doctypeid!='183'"> <!-- QC8243 -->
			<!-- Tinglysningsafgift -->
			<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
			<!-- Beregningsgrundlaget er et andet -->
			<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
			<!-- Erklæring vedr. tinglysningsafgift: -->
			<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
				<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>

	<!--*************************** Anm:AndenTekst ****************************-->
	<xsl:template match="anm:NavneaendringAdkomstFastEjendomTekst">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'NAVNEÆNDRING'"/>
		</xsl:call-template>
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- ********************************   DokumentFastEjendom   *************************************** -->
	<!-- ************************************************************************************************ -->
	<!-- Håndterer rendering af DokumentFastEjendom                                                                    -->
	<xsl:template match="model:DokumentFastEjendom">
		<xsl:apply-templates select="model:EjendomKategori"/>
	
	    <xsl:apply-templates select="model:BygningsforholdKode"/>
	    
	    <xsl:if test="model:AdkomstInformation/model:EjendomstypeSub">
			<xsl:choose>
				<xsl:when test="model:ValutaKode">
					<xsl:call-template name="model:EjendomstypeSub">
						<xsl:with-param name="node" select="model:AdkomstInformation/model:EjendomstypeSub"/>
						<xsl:with-param name="valuta" select="model:ValutaKode"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="model:EjendomstypeSub">
						<xsl:with-param name="node" select="model:AdkomstInformation/model:EjendomstypeSub"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	
	    <xsl:choose>
	    	<xsl:when test="model:AdkomstInformation/model:AdkomstHandelKodeSub != ''">
				<xsl:apply-templates select="model:AdkomstInformation/model:AdkomstHandelKodeSub"/>
		    </xsl:when>
	    	<xsl:otherwise>
	        	<xsl:apply-templates select="model:AdkomstHandelKode"/>
	    	</xsl:otherwise>
		</xsl:choose>
	
		<xsl:if test="model:AdkomstInformation//model:AdkomstHandelBeskrivelseSub">
		    <xsl:apply-templates select="model:AdkomstInformation//model:AdkomstHandelBeskrivelseSub"/>
		</xsl:if>
	
		<!-- xsl:if test="$node/model:AdkomstHandelBeskrivelse & $adkomstHandelKode == 'andenOverdragelse'" -->
		<xsl:if test="model:AdkomstInformation/model:AdkomstHandelBeskrivelse">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:AdkomstInformation/model:AdkomstHandelBeskrivelse"/>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="model:AdkomstInformation/model:ArealDerAfhaendes">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'AREAL DER OVERDRAGES'" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:AdkomstInformation/model:ArealDerAfhaendes"/>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:apply-templates select="model:AdkomstInformation/model:MedtagneEjendomme"/>
	
	    <xsl:apply-templates select="model:AuktionDato"/>
	       
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   EjendomsKategori   ********************************** -->
	<xsl:template match="model:EjendomKategori">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'EJENDOMSKATEGORI'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="model:EjendomKategoriUbebyggetgrund">
			  <xsl:apply-templates select="model:EjendomKategoriUbebyggetgrund"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriUbebyggetgrund">
			  <xsl:apply-templates select="model:EjendomKategoriUbebyggetgrund"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriErhvervsejendom">
			  <xsl:apply-templates select="model:EjendomKategoriErhvervsejendom"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriFlerfamiliesejendom">
			  <xsl:apply-templates select="model:EjendomKategoriFlerfamiliesejendom"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriEnfamiliesejendom">
			  <xsl:apply-templates select="model:EjendomKategoriEnfamiliesejendom"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriFritidsejendom">
			  <xsl:apply-templates select="model:EjendomKategoriFritidsejendom"/>
			</xsl:when>
			<xsl:when test="model:EjendomKategoriLandbrug">
			  <xsl:apply-templates select="model:EjendomKategoriLandbrug"/>
			</xsl:when>
	        <xsl:when test="model:EjendomKategoriAnden">
	          <xsl:apply-templates select="model:EjendomKategoriAnden"/>
	        </xsl:when>
	    
		</xsl:choose>
	
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriUbebyggetgrund">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Ubebygget grund'"/>
	</xsl:call-template>
	<xsl:if test="model:ByggemodningsomkostningIndikator = 'true'">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Købesummen omfatter alle omkostninger til byggemodning.'" />
		</xsl:call-template>
	</xsl:if>
</xsl:template>

	<xsl:template match="model:EjendomKategoriErhvervsejendom">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Erhvervsejendom'"/>
		</xsl:call-template>
			<xsl:if test="model:UdlejningsgradIndikator = 'true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Mere end 50% af erhvervs- og boligarealerne har været udlejet i seneste kalenderår.'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:UdlejningsgradIndikator = 'false'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'50% eller mindre af erhvervs- og boligarealerne har været udlejet i seneste kalenderår.'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:MomspligtigeformaalIndikator = 'true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Ejendommen har været anvendt til momspligtige formål.'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:MomspligtigeformaalIndikator = 'false'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Ejendommen har ikke været anvendt til momspligtige formål.'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:UdlejningsejendomIndikator = 'true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Ejendommen er en udlejningsejendom.'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:AntalBeboelseslejemaal != ''">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Antal beboelseslejemål'" />
					<xsl:with-param name="text" select="model:AntalBeboelseslejemaal" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="model:AntalErhvervslejemaal != ''">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Antal erhvervslejemål'" />
					<xsl:with-param name="text" select="model:AntalErhvervslejemaal" />
				</xsl:call-template>
			</xsl:if>
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriFlerfamiliesejendom">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Flerfamiliesejendom'" />
		</xsl:call-template>
		<xsl:if test="model:AntalBeboelseslejligheder != ''">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Antal beboelseslejligheder'" />
					<xsl:with-param name="text" select="model:AntalBeboelseslejligheder" />
				</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriEnfamiliesejendom">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Enfamiliesejendom'" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriFritidsejendom">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Fritidsejendom'" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriLandbrug">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Landbrug'" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:EjendomKategoriAnden">
	  <xsl:call-template name="column2">
	    <xsl:with-param name="text" select="'Anden ejendom'"/>
	  </xsl:call-template>
	  <xsl:if test="model:EjendomKategoriTekst != ''">
	    <xsl:call-template name="column2">
	      <xsl:with-param name="text" select="model:EjendomKategoriTekst" />
	    </xsl:call-template>
	  </xsl:if>
	</xsl:template> 
	<!--   EjendomsKategori  -->
	
	<!-- ***********************************   MedtagneEjendomme   ********************************** -->
	<xsl:template match="model:MedtagneEjendomme">
		<xsl:param name="node" select="."/>
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'FLERE EJENDOMME'" />
		</xsl:call-template>
		
		<xsl:if test="$node/model:AlleEjdMedtagetIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Alle de ejendomme, der er indeholdt i købesummen, er medtaget i anmeldelsen'" />
			</xsl:call-template>
			
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
		<xsl:if test="$node/model:BfeIkkeKendtIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'BFE-numre ikke kendt'" />
			</xsl:call-template>
			
			<xsl:call-template name="linefeed" />
		</xsl:if>	
		
		<xsl:if test="$node/model:BfeNummerSamling">
			<xsl:for-each select="$node/model:BfeNummerSamling/model:BfeNummer">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="." />
				</xsl:call-template>
			</xsl:for-each>
	
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
	</xsl:template>
	
	<!-- ***********************************   BygningsforholdKode   ********************************** -->
	<xsl:template match="model:BygningsforholdKode">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Afgivne oplysninger om bygninger'" />
			<xsl:with-param name="text">
				<xsl:choose>
					<xsl:when test=".='omfatterBygningerPlanlagtNedrevet'">
						<xsl:value-of select="'Handelen omfatter bygning(er), der er planlagt nedrevet.'"/>
					</xsl:when>
					<xsl:when test=".='omfatterBygningerUnderOpfoerelse'">
						<xsl:value-of select="'Handelen omfatter bygning(er) under opførsel.'"/>
					</xsl:when>
					<xsl:when test=".='omfatterPlanlagteBygninger'">
						<xsl:value-of select="'Forventet eller planlagt ombygning/ændret anvendelse.'"/>
					</xsl:when>
				</xsl:choose>
			</xsl:with-param>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   AdkomstHandelKode   ********************************** -->
	<xsl:template match="model:AdkomstHandelKode">
		<xsl:variable name="rtypeid" select="." />
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'TYPE AF HANDEL'" />
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$opslag//AdkomstHandelKode[@id = $rtypeid]" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   AdkomstHandelKodeSub  ********************************** -->
	<xsl:template match="model:AdkomstHandelKodeSub">
		<xsl:variable name="rtypeid" select="." />
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'TYPE AF HANDEL'" />
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$opslag//AdkomstHandelKodeSub[@id = $rtypeid]" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   AdkomstHandelBeskrivelseSub  ********************************** -->
	<xsl:template match="model:AdkomstHandelBeskrivelseSub">
		<xsl:variable name="rtypeid" select="." />	
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$opslag//AdkomstHandelBeskrivelseSub[@id = $rtypeid]" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
</xsl:stylesheet>