<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:msgbil="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
	xmlns:msgandel="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
	xmlns:msgperson="http://rep.oio.dk/tinglysning.dk/service/message/personbog/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
	xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
	xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    >

<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DokumentSamlingAflys.xslt 136061 2018-08-03 08:53:44Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende DokumentSamlingAflys-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	
	<!-- ***********************************   DokumentSamlingAflys Tingbog  ********************************** -->
	<xsl:template match="msg:DokumentSamlingAflys">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<xsl:variable name="doc_no" select="number(count(model:DokumentIdentifikatorSamling/model:DokumentIdentifikator))" />
		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" /> 
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		
		<xsl:if test="$doc_no = 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENT SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$doc_no > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENTER SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="model:DokumentIdentifikatorSamling/model:DokumentIdentifikator">
			<xsl:call-template name="dokument_som_paategnes">
				<xsl:with-param name="doc_id" select="." />
				<xsl:with-param name="include_header" select="'false'"/>
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:for-each>

		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:choose>
			<xsl:when test="$doctypeid != 168">
				<xsl:if test="$doc_no = 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumentet aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$doc_no > 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumenterne aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$opslag//EkspeditionstypeLedetekst[@id = $doctypeid]"/>
					</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />

<!-- ***************************************************************************************-->
<!-- ** Aflysning I Bero begrundelse ifm 100   ****************************************-->
<!-- ***************************************************************************************-->
        <xsl:if test="//model:AflysningIBeroIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Aflysningen effektueres om 1 år.'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
        </xsl:if>
		<xsl:if test="//model:AflysningsbegrundelseTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="//model:AflysningsbegrundelseTekst"/>
			</xsl:call-template>					
			<xsl:call-template name="linefeed" />
		</xsl:if>

		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />

		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
				
		<!-- Rollesamlingen skal stå til sidst efter en skillelinie -->
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>

		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- ***********************************   DokumentSamlingAflys Bilbog  ********************************** -->
	<xsl:template match="msgbil:DokumentSamlingAflys">
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		
		<xsl:variable name="doc_no" select="number(count(model:DokumentIdentifikatorSamling/model:DokumentIdentifikator))" />
		<xsl:if test="$doc_no = 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENT SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$doc_no > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENTER SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="model:DokumentIdentifikatorSamling/model:DokumentIdentifikator">
			<xsl:call-template name="dokument_som_paategnes">
				<xsl:with-param name="doc_id" select="." />
				<xsl:with-param name="include_header" select="'false'"/>
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:for-each>

		<xsl:variable name="doctypeid" select="msgbil:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:choose>
			<xsl:when test="$doctypeid != 169">
				<xsl:if test="$doc_no = 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumentet aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$doc_no > 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumenterne aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$opslag//EkspeditionstypeLedetekst[@id = $doctypeid]"/>
					</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
		<xsl:if test="//model:AflysningsbegrundelseTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="//model:AflysningsbegrundelseTekst"/>
			</xsl:call-template>					
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />

		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
				
		<!-- Rollesamlingen skal stå til sidst efter en skillelinie -->
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>

		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- ***********************************   DokumentSamlingAflys Andelsboligbog  ********************************** -->
	<xsl:template match="msgandel:DokumentSamlingAflys">
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<xsl:variable name="doc_no" select="number(count(model:DokumentIdentifikatorSamling/model:DokumentIdentifikator))" />
		<xsl:if test="$doc_no = 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENT SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$doc_no > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENTER SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="model:DokumentIdentifikatorSamling/model:DokumentIdentifikator">
			<xsl:call-template name="dokument_som_paategnes">
				<xsl:with-param name="doc_id" select="." />
				<xsl:with-param name="include_header" select="'false'"/>
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:variable name="doctypeid" select="msgandel:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="$doctypeid != 171">
				<xsl:if test="$doc_no = 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumentet aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$doc_no > 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumenterne aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$opslag//EkspeditionstypeLedetekst[@id = $doctypeid]"/>
					</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
		<xsl:if test="//model:AflysningsbegrundelseTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="//model:AflysningsbegrundelseTekst"/>
			</xsl:call-template>					
			<xsl:call-template name="linefeed" />
		</xsl:if>		
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Rollesamlingen skal stå til sidst efter en skillelinie -->
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- ***********************************   DokumentSamlingAflys Personbog  ********************************** -->
	<xsl:template match="msgperson:DokumentSamlingAflys">
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<xsl:variable name="doc_no" select="number(count(model:DokumentIdentifikatorSamling/model:DokumentIdentifikator))" />
		<xsl:if test="$doc_no = 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENT SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$doc_no > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENTER SOM PÅTEGNES'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:for-each select="model:DokumentIdentifikatorSamling/model:DokumentIdentifikator">
			<xsl:call-template name="dokument_som_paategnes">
				<xsl:with-param name="doc_id" select="." />
				<xsl:with-param name="include_header" select="'false'"/>
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="$doctypeid != 170">
				<xsl:if test="$doc_no = 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumentet aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="$doc_no > 1">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Dokumenterne aflyses i sin helhed.'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$opslag//EkspeditionstypeLedetekst[@id = $doctypeid]"/>
					</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
			<xsl:if test="//model:AflysningsbegrundelseTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="//model:AflysningsbegrundelseTekst"/>
			</xsl:call-template>					
			<xsl:call-template name="linefeed" />
		</xsl:if>				
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Rollesamlingen skal stå til sidst efter en skillelinie -->
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
</xsl:stylesheet>
