<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:itst-2="http://rep.oio.dk/itst.dk/xml/schemas/2006/01/17/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:ois="http://rep.oio.dk/ois.dk/xml/schemas/2006/04/25/"
	xmlns:osak="http://rep.oio.dk/osak.dk/xml/schemas/2006/04/25/"     
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Ejendom.xslt 190138 2020-11-05 18:30:18Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<xsl:key name="hoestEjendomInfo" match="//model:HoestPantebrev//model:Matrikel" use="concat(kms:CadastralDistrictIdentifier, '_', model:Matrikelnummer)"/>
	<xsl:key name="ejendomInfo" match="//snapshot:EjendomStruktur//model:Matrikel" use="concat(kms:CadastralDistrictIdentifier, '_', model:Matrikelnummer)"/>
	<xsl:key name="EjendomStruktur" match="//snapshot:EjendomStruktur" use="concat(local-name(model:EjendomIdentifikator/model:EjendomType/*), '_', model:EjendomIdentifikator//model:Anpartsnummer, '_', model:EjendomIdentifikator//model:Ejerlejlighedsnummer, '_', model:EjendomIdentifikator//model:Bygningsnummer, '_', model:EjendomIdentifikator//model:Timesharenummer, '_', model:EjendomIdentifikator//model:Ugenummer, '_', model:EjendomIdentifikator//kms:CadastralDistrictIdentifier, '_', model:EjendomIdentifikator//model:Matrikelnummer)"/>
	<xsl:key name="AdresseStruktur" match="//snapshot:AdresseStruktur" use="concat(xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:MunicipalityCode, '_', xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:StreetCode, '_', xkom:AddressSpecific/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier, '_', xkom:AddressSpecific/dkcc-1:FloorIdentifier, '_', xkom:AddressSpecific/dkcc-1:SuiteIdentifier)"/>
	<xsl:key name="PantRettigheder" match="//snapshot:SnapshotSamling/snapshot:RettighedIdentifikatorSamling/snapshot:RettighedIdentifikatorStruktur" use="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator"/>
	<xsl:key name="ServitutRettigheder" match="//snapshot:SnapshotSamling/snapshot:RettighedIdentifikatorSamling/snapshot:RettighedIdentifikatorStruktur" use="model:Rettighed/model:Servitutrettighed/model:RettighedIdentifikator"/>
	<xsl:key name="DokumentStruktur" match="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur" use="concat(model:DokumentRevisionIdentifikator/model:DokumentIdentifikator,'_',model:DokumentRevisionIdentifikator/model:RevisionNummer)"/>

	<!-- ***********************************   FastEjendomMedRettighederSamling  ********************************** -->
	<xsl:template match="eakt:FastEjendomMedRettighederSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'EJENDOM'" />
		</xsl:call-template>
		<xsl:for-each select="eakt:FastEjendomMedRettigheder">
			<xsl:apply-templates select="model:FastEjendom"/>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!-- ***********************************   FastEjendomSamling  ********************************** -->
	<xsl:template match="model:FastEjendomSamling | model:RespektFastEjendomSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'EJENDOM'" />
		</xsl:call-template>
		<xsl:for-each select="model:FastEjendom | model:RespektFastEjendom">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:template>

	<!-- ***********************************   FastEjendom   ********************************** -->
	<xsl:template match="model:FastEjendom | model:RespektFastEjendom">
		<xsl:apply-templates select="model:EjendomIdentifikator"/>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!-- ***********************************   EjendomIdentifikator   ********************************** -->
	<xsl:template match="model:EjendomIdentifikator">

		<xsl:call-template name="model:FindAdresse">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>

		<xsl:apply-templates select="model:EjendomType"/>
		<xsl:for-each select="model:Matrikel">
			<!--<xsl:sort select="kms:CadastralDistrictIdentifier" data-type="number" order="ascending" />
			<xsl:sort select="model:Matrikelnummer" />-->
			<xsl:apply-templates select="."/>
		</xsl:for-each>
		<xsl:if test="model:Umatrikuleretareal">
			<xsl:apply-templates select="model:Umatrikuleretareal"/>	
		</xsl:if>
		<!-- EjendomsType -->
	
	</xsl:template>

	<!-- ***********************************   EjendomIdentifikator   ********************************** -->
	<xsl:template name="EjendomIdentifikator">
		<xsl:param name="node"/>

		<xsl:call-template name="model:FindAdresse">
			<xsl:with-param name="node" select="$node"/>
		</xsl:call-template>

		<xsl:apply-templates select="$node/model:EjendomType"/>
		<xsl:for-each select="$node/model:Matrikel">
			<!--<xsl:sort select="kms:CadastralDistrictIdentifier" data-type="number" order="ascending" />
			<xsl:sort select="model:Matrikelnummer" />-->
			<xsl:apply-templates select="."/>
		</xsl:for-each>
		<xsl:if test="$node/model:Umatrikuleretareal">
			<xsl:apply-templates select="$node/model:Umatrikuleretareal"/>	
		</xsl:if>
	</xsl:template>

	<!-- ***************************   Matrikel  ************************* -->	
	<xsl:template match="model:Matrikel">

		<!-- Ejerlav -->
		<xsl:variable name="cadastralDistrictIdentifier" select="number(kms:CadastralDistrictIdentifier)"/>
		<!-- Matrikelnr. -->
		<xsl:variable name="landParcelIdentifier" select="model:Matrikelnummer"/>

		<!-- Ejerlav og matrikelnummer -->		
		<xsl:call-template name="UdskrivEjerlavMatrikelnr">
			<xsl:with-param name="MatrikelNr" select="$landParcelIdentifier"/>
			<xsl:with-param name="Ejerlav" select="$cadastralDistrictIdentifier"/>
		</xsl:call-template>

		<!-- Del areal -->
		<xsl:if test="count(model:Delareal)>0">
			<xsl:if test="count(model:Delareal/model:DelarealStoerrelseVej)>0">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Delareal (nummer, størrelse, vej)'" />
					<xsl:with-param name="text" select="concat(string(model:Delareal/model:DelarealNummer), ', ', string(model:Delareal/model:DelarealStoerrelse), ' kvm, ', string(model:Delareal/model:DelarealStoerrelseVej), ' kvm')" />
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="count(model:Delareal/model:DelarealStoerrelseVej)=0">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Delareal (nummer, størrelse)'" />
					<xsl:with-param name="text" select="concat(string(model:Delareal/model:DelarealNummer), ', ', string(model:Delareal/model:DelarealStoerrelse), ' kvm')" />
				</xsl:call-template>
			</xsl:if>
		</xsl:if>

		<!-- Fælleslod brøk -->
		<xsl:if test="count(model:FaelleslodBroek)>0">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Fælleslod (brøk)'" />
				<xsl:with-param name="text" select="concat(string(model:FaelleslodBroek/model:Taeller), '/', string(model:FaelleslodBroek/model:Naevner))" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!-- ************************************model:Umatrikuleretareal*************************-->
	<xsl:template match="model:Umatrikuleretareal">

		<xsl:variable name="typeid" select="model:UmatrikuleretType" />
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Type'"/>
			<xsl:with-param name="text" select="$opslag//UmatrikuleretType[@id = $typeid]"/>
		</xsl:call-template>

		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Identifikator'" />
			<xsl:with-param name="text" select="model:UmatrikuleretIdentifikator" />
		</xsl:call-template>

		<xsl:if test="model:UmatrikuleretarealBeskrivelse">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Beskrivelse'" />
				<xsl:with-param name="text" select="model:UmatrikuleretarealBeskrivelse" />
			</xsl:call-template>
		</xsl:if>
		
		<xsl:apply-templates select="model:UmatrikuleretKoordinater"/>

		<xsl:if test="kms:CadastralDistrictIdentifier">
			<xsl:variable name="Ejerlav" select="kms:CadastralDistrictIdentifier"/>
			<!-- Tag landsejerlavnavn fra snapshot -->
			<xsl:variable name="Matrikel" select="//snapshot:EjendomStruktur//model:Umatrikuleretareal[kms:CadastralDistrictIdentifier = $Ejerlav]"/>
			<xsl:choose>
				<xsl:when test="$Matrikel/kms:CadastralDistrictName">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Landsejerlav'"/>
						<xsl:with-param name="text" select="$Matrikel/kms:CadastralDistrictName"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Landsejerlav'" />
						<xsl:with-param name="text" select="kms:CadastralDistrictIdentifier" />
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		
		<xsl:if test="ois:JurisdictionCode">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Retskreds'" />
				<xsl:with-param name="text" select="ois:JurisdictionCode" />
			</xsl:call-template>
		</xsl:if>

	</xsl:template>

	<!-- *********************************  UdskrivHaeftelser   ******************************** -->
	<xsl:template name="UdskrivHaeftelser">
		<xsl:param name="Root" select=".//model:FastEjendomSamling"/>
		<xsl:variable name="AntalEjendomme" select="count($Root/*)"/>
		<xsl:variable name="AntalEjendommeSnapshot" select="count(//snapshot:EjendomStruktur)"/>
		
		<xsl:variable name="haeftelser">
			<xsl:if test="$AntalEjendommeSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RettighedIdentifikator) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="FastEjendom" select="."/>
					<xsl:variable name="PantRettigheder" select="key('PantRettigheder', $FastEjendom//model:Respekt/model:RettighedIdentifikator)"/>
					<xsl:variable name="rettigheder">
						<xsl:for-each select="$PantRettigheder">
							<xsl:sort select="model:Rettighed/model:Pantrettighed/model:PrioritetNummer" />
							<!-- Hvis hæftelsen hører til dette dokument, så udskriv den -->
							<xsl:variable name="rettighedIdentifikator" select="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator" />
							<!-- Hæftelsen findes i RespektSamling -->
							<xsl:variable name="dokumentIdentifikator" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
							<xsl:variable name="revisionNummer" select="model:DokumentRevisionIdentifikator/model:RevisionNummer" />
							<xsl:variable name="Struktur" select="key('DokumentStruktur', concat($dokumentIdentifikator,'_',$revisionNummer))"/>
							<!-- Vis den dokumentstruktur, som matcher -->
							<xsl:call-template name="DokumentStruktur_Haeftelse">
								<xsl:with-param name="dokumentStruktur" select="$Struktur" />
								<xsl:with-param name="doc_id" select="$dokumentIdentifikator" />
							</xsl:call-template>
							<xsl:call-template name="linefeed" />
						</xsl:for-each>
					</xsl:variable>
					<xsl:if test="$AntalEjendommeSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="UdskrivEjerlavMatrikelnr">
							<xsl:with-param name="FastEjendom" select="$FastEjendom"/>
						</xsl:call-template>
						<xsl:call-template name="linefeed" />
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>

		<xsl:if test="string-length($haeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$haeftelser"/>
		</xsl:if>
	</xsl:template>
  
	<!-- *********************************  Udskriv FremtidigeHaeftelser   ******************************** -->
	<xsl:template name="UdskrivFremtidigeHaeftelser">
		<xsl:param name="Root" select=".//model:FastEjendomSamling"/>

		<xsl:variable name="AntalEjendomme" select="count($Root/*)" />
		<xsl:variable name="AntalEjendommeSnapshot" select="count(//snapshot:EjendomStruktur)"/>
		
		<xsl:variable name="fremtidigehaeftelser">
			<xsl:if test="$AntalEjendommeSnapshot > 0 and count($Root//model:RespektSamling/model:Respekt/model:RespektHaeftelseFremtidig) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="FastEjendom" select="."/>
					
					<xsl:variable name="rettigheder">
						<xsl:variable name="antalRHF" select="count(.//model:Respekt/model:RespektHaeftelseFremtidig)" />
						<xsl:for-each select=".//model:Respekt/model:RespektHaeftelseFremtidig">
							<xsl:apply-templates select="."/>
							<xsl:if test="position() &lt; $antalRHF">
								<xsl:call-template name="linefeed" />
							</xsl:if>
						</xsl:for-each>
					</xsl:variable>	
					
					<xsl:if test="$AntalEjendommeSnapshot > 1 and string-length($rettigheder) > 1">
						<xsl:call-template name="UdskrivEjerlavMatrikelnr">
							<xsl:with-param name="FastEjendom" select="$FastEjendom"/>
						</xsl:call-template>
						<xsl:call-template name="linefeed" />
					</xsl:if>
					<xsl:copy-of select="$rettigheder"/>
				</xsl:for-each>
				<xsl:call-template name="linefeed" />
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($fremtidigehaeftelser) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE FREMTIDIGE HÆFTELSER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$fremtidigehaeftelser"/>
		</xsl:if>
		
	</xsl:template> 
  
	<!-- *********************************  Udskriv Servitutter   ******************************** -->
	<xsl:template name="UdskrivServitutter">
		<xsl:param name="Root" select=".//model:FastEjendomSamling"/>
		<xsl:variable name="AntalEjendomme" select="count($Root/*)" />
		<xsl:variable name="AntalEjendommeSnapshot" select="count(//snapshot:EjendomStruktur)"/>

		<xsl:variable name="servitutter">
			<xsl:if test="$AntalEjendommeSnapshot > 0 or count($Root//model:RespektSamling/model:Respekt/model:RespektServitutDato) > 0">
				<xsl:for-each select="$Root/*">
					<xsl:variable name="FastEjendom" select="."/>
					<xsl:variable name="respekter">
						<!-- Hvis der findes en servitutdato i anmeldelsen vises denne, ellers vises listen af servitutter i snapshot -->
						<xsl:choose>
							<xsl:when test="$FastEjendom//model:Respekt/model:RespektServitutDato">
								<!-- Der findes en servitutdato -->
								<xsl:variable name="serv_dato" select="$FastEjendom//model:Respekt/model:RespektServitutDato"/>
								<xsl:call-template name="column2">
									<!--<xsl:with-param name="text" select="concat('Servitutter tinglyst til og med ',substring($serv_dato, 9, 2), '.', substring($serv_dato, 6, 2), '.', substring($serv_dato, 1, 4), ' respekteres.')"/>-->
									<xsl:with-param name="text">
										<xsl:value-of select="'Servitutter tinglyst til og med '"/>
										<xsl:call-template name="formatdato">
											<xsl:with-param name="dato" select="$serv_dato"/>
										</xsl:call-template>
										<xsl:value-of select="' respekteres.'"/>
									</xsl:with-param> 
								</xsl:call-template>
								<xsl:call-template name="linefeed" />
							</xsl:when>
							<xsl:otherwise>
							<!-- Gennemløb alle respekter af typen servitutrettighed i snapshot/respektsamling sorteret efter prioritetsnummer -->
							<xsl:variable name="ServitutRettigheder" select="key('ServitutRettigheder', $FastEjendom//model:Respekt/model:RettighedIdentifikator)"/>
							<xsl:for-each select="$ServitutRettigheder">
								<xsl:sort select="model:Rettighed/model:Servitutrettighed/model:PrioritetNummer" />
								<!-- Hvis hæftelsen hører til dette dokument, så udskriv den -->
								<xsl:variable name="rettighedIdentifikator" select="model:Rettighed/model:Servitutrettighed/model:RettighedIdentifikator" />
								<!-- Hæftelsen findes i RespektSamling -->
								<xsl:variable name="dokumentIdentifikator" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
								<xsl:variable name="revisionNummer" select="model:DokumentRevisionIdentifikator/model:RevisionNummer" />
								<!-- Vis den dokumentstruktur, som matcher -->
								<xsl:call-template name="DokumentStruktur_Servitut">
									<xsl:with-param name="dokumentStruktur" select="key('DokumentStruktur', concat($dokumentIdentifikator,'_',$revisionNummer))" />
									<xsl:with-param name="doc_id" select="$dokumentIdentifikator" />
								</xsl:call-template>				
								<xsl:call-template name="linefeed" />
							</xsl:for-each>
						</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					
					<xsl:if test="$AntalEjendommeSnapshot > 1 and string-length($respekter) > 1">
						<xsl:call-template name="UdskrivEjerlavMatrikelnr">
							<xsl:with-param name="FastEjendom" select="$FastEjendom"/>
						</xsl:call-template>
						<xsl:call-template name="linefeed" />
					</xsl:if>
					<xsl:copy-of select="$respekter"/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="string-length($servitutter) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE SERVITUTTER RESPEKTERES'" />
			</xsl:call-template>
			<xsl:copy-of select="$servitutter"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
	</xsl:template>
	
	<!-- ********************************* UdskrivEjerlavMatrikelnr ********************************************** -->
	<xsl:template name="UdskrivEjerlavMatrikelnr">
		<xsl:param name="MatrikelNr"/>
		<xsl:param name="Ejerlav"/>
		<xsl:param name="FastEjendom"/>
		<xsl:param name="Summarisk"/>
		
		<xsl:choose>
			<xsl:when test="$MatrikelNr !='' and $Ejerlav !=''">
				<!-- Tag landsejerlavnavn fra snapshot -->
				<!--<xsl:variable name="Matrikel" select="//snapshot:EjendomStruktur//model:Matrikel[model:Matrikelnummer = $MatrikelNr and kms:CadastralDistrictIdentifier = $Ejerlav]"/>-->
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Landsejerlav'"/>
					<!--<xsl:with-param name="text" select="$Matrikel/kms:CadastralDistrictName"/>-->
					<xsl:with-param name="text">
					 <xsl:choose>
					   <xsl:when test="key('ejendomInfo', concat($Ejerlav, '_',$MatrikelNr))/kms:CadastralDistrictName"><xsl:value-of select="key('ejendomInfo', concat($Ejerlav, '_',$MatrikelNr))/kms:CadastralDistrictName" /></xsl:when>
					   <xsl:when test="key('hoestEjendomInfo', concat($Ejerlav, '_',$MatrikelNr))/kms:CadastralDistrictName"><xsl:value-of select="key('hoestEjendomInfo', concat($Ejerlav, '_',$MatrikelNr))/kms:CadastralDistrictName" /></xsl:when>					   
					   <xsl:otherwise><xsl:value-of select="$Ejerlav" /></xsl:otherwise> <!-- fallback, hvis ejendom ikke er i berigelsen -->
					 </xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Matrikelnummer'"/>
					<xsl:with-param name="text" select="$MatrikelNr"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$FastEjendom">
				<xsl:apply-templates select="$FastEjendom//model:EjendomIdentifikator/model:EjendomType"/>
				<xsl:for-each select="$FastEjendom//model:EjendomIdentifikator/model:Matrikel">
					<xsl:variable name="MatrikelAnm" select="."/>
					<!--<xsl:variable name="Matrikel" select="//snapshot:EjendomStruktur//model:Matrikel[model:Matrikelnummer = $MatrikelAnm/model:Matrikelnummer and kms:CadastralDistrictIdentifier = $MatrikelAnm/kms:CadastralDistrictIdentifier]"/>-->
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Landsejerlav'"/>
						<!--<xsl:with-param name="text" select="$Matrikel/kms:CadastralDistrictName"/>-->
						<xsl:with-param name="text" select="key('ejendomInfo', concat($MatrikelAnm/kms:CadastralDistrictIdentifier, '_',$MatrikelAnm/model:Matrikelnummer))/kms:CadastralDistrictName"/>
					</xsl:call-template>
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Matrikelnummer'"/>
						<xsl:with-param name="text" select="$MatrikelAnm/model:Matrikelnummer"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$Summarisk">
				<xsl:apply-templates select="$Summarisk/model:EjendomIdentifikator/model:EjendomType"/>
				<xsl:for-each select="$Summarisk/model:EjendomIdentifikator/model:Matrikel">
					<xsl:variable name="MatrikelAnm" select="."/>
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Landsejerlav'"/>
						<xsl:with-param name="text" select="$MatrikelAnm/kms:CadastralDistrictName"/>
					</xsl:call-template>
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Matrikelnummer'"/>
						<xsl:with-param name="text" select="$MatrikelAnm/model:Matrikelnummer"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
  
	<!-- ***********************************  Servitut   ********************************** -->
	<xsl:template name="Servitut">
		<xsl:param name="node"/>

		<xsl:if test="$node//model:ServitutType">
		
			<xsl:call-template name="two_columns">
				<xsl:with-param name="text" select="$node//model:ServitutType" />
			</xsl:call-template>
			
		</xsl:if>
		
	</xsl:template>
	
	<!-- ***********************************   Hovedstol   ********************************** -->
	<xsl:template name="Hovedstol">
		<xsl:param name="node" select="."/>
		<xsl:param name="header" select="'Hovedstol'"/>

		<xsl:if test="$node//model:BeloebVaerdi">
		
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="$header"/>
				<xsl:with-param name="text" select="format-number(floor($node//model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')" />
				<xsl:with-param name="text2" select="$node//model:ValutaKode" />
			</xsl:call-template>
			
		</xsl:if>
	</xsl:template>	
	
	<!-- ***********************************   RespektHaeftelseFremtidig   ********************************** -->
	<xsl:template match="model:RespektHaeftelseFremtidig">
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseFastEjendomIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseBilIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseAndelIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseLoesoereIdentifikator"/>
		<xsl:call-template name="Hovedstol"/>
		<xsl:apply-templates select="model:HaeftelseRenteSats"/>
		<xsl:apply-templates select="model:HaeftelseLaantypeKode"/>
		<xsl:apply-templates select="model:HaeftelseSaerligeLaanevilkaarstypeSamling"/>
		<xsl:apply-templates select="model:KreditorSamling"/>	
	</xsl:template>

	<!-- ***********************************   HaeftelseSaerligeLaanevilkaarstypeSamling   ********************************** -->
	<xsl:template match="model:HaeftelseSaerligeLaanevilkaarstypeSamling">
		<xsl:variable name="Root" select="."/>
		<xsl:variable name="AntalVilkaar" select="count(model:HaeftelseSaerligeLaanevilkaarstype)"/>
		
		<xsl:for-each select="model:HaeftelseSaerligeLaanevilkaarstype">
			<xsl:variable name="typeid" select="." />
			<xsl:choose>
				<xsl:when test="$AntalVilkaar = 1">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Særlige lånevilkår'"/>
						<xsl:with-param name="text" select="$opslag//HaeftelseSaerligeLaanevilkaarstype[@id = $typeid]"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="node() = $Root/model:HaeftelseSaerligeLaanevilkaarstype[position()=1]">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Særlige lånevilkår'"/>
								<xsl:with-param name="text" select="$opslag//HaeftelseSaerligeLaanevilkaarstype[@id = $typeid]"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="column2">
								<xsl:with-param name="text" select="$opslag//HaeftelseSaerligeLaanevilkaarstype[@id = $typeid]"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<!-- ***********************************   HaeftelseRenteSats   ********************************** -->
	<xsl:template match="model:HaeftelseRenteSats">
		<xsl:call-template name="model:HaeftelseRenteSats_sub"/>
	</xsl:template>

	<!-- ***********************************   HaeftelseRenteSats_sub   ********************************** -->
	<xsl:template name="model:HaeftelseRenteSats_sub">
		<xsl:param name="node" select="."/>
		
		<xsl:if test="string-length($node)>0">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Rentesats'"/>
				<xsl:with-param name="text" select="format-number($node, $formatrente, 'currency-format')" />
				<xsl:with-param name="text2" select="'%'"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!-- ***********************************   HaeftelseLaantypeKode   ********************************** -->
	<xsl:template match="model:HaeftelseLaantypeKode">
		<xsl:call-template name="model:HaeftelseLaantypeKode_sub">
			<xsl:with-param name="node" select="node()"/>
		</xsl:call-template>			
	</xsl:template>
	
	<!-- ***********************************   HaeftelseLaantypeKode_sub   ********************************** -->
	<xsl:template name="model:HaeftelseLaantypeKode_sub">
		<xsl:param name="node"/>
		<xsl:if test="string-length($node)>0">

			<xsl:choose>
				<xsl:when test="$node='obligationslaan'">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Låntype'"/>
						<xsl:with-param name="text" select="'Obligationslån'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$node='kontantlaan'">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Låntype'"/>
						<xsl:with-param name="text" select="'Kontantlån'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$node='andenlaanetype'">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Låntype'"/>
						<xsl:with-param name="text" select="'Anden lånetype'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>FEJL: Ikke eksisterende låntype.</xsl:text>
					<xsl:value-of select="$node"/>
					<xsl:call-template name="linefeed" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	<!-- **************************** model:HaeftelseSaerligeLaanevilkaarstype *************************** -->
	<xsl:template match="model:HaeftelseSaerligeLaanevilkaarstype">
		<xsl:call-template name="model:HaeftelseSaerligeLaanevilkaarstype_sub">
			<xsl:with-param name="node" select="node()"/>
		</xsl:call-template>			
	</xsl:template>
	
	<!-- **************************** model:HaeftelseSaerligeLaanevilkaarstype_sub *************************** -->
	<xsl:template name="model:HaeftelseSaerligeLaanevilkaarstype_sub">
		<xsl:param name="node"/>
		
		<xsl:choose>
			<xsl:when test="$node='mulighedForAfdragsfrihed'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Mulighed for afdragsfrihed'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='staaendeLaan'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Stående lån'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='mulighedForAfdragsfrihed'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Mulighed for afdragsfrihed'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='kontantlaan'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Kontantlån'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='inkonvertibel'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Inkonvertibel'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='refinansiering '">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Refinansiering'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='indeksregulering'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'indeksregulering'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='rentetilpasning'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Rentetilpasning'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$node='opskrevetHovedstol'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Opskrevet hovedstol'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>FEJL: Ikke defineret lånevilkårstype:</xsl:text>
				<xsl:value-of select="$node"/>
				<xsl:call-template name="linefeed" />
			</xsl:otherwise>
		</xsl:choose>
			
	</xsl:template>
	
	<!-- ***************************   Servitutter  ************************* -->	

	<!-- ***********************************   UmatrikuleretKoordinater   ********************************** -->
	<xsl:template match="model:UmatrikuleretKoordinater">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Easting ETRS89'" />
			<xsl:with-param name="text" select="osak:CoordETRS89z32EMeasure" />
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Northing ETRS89'" />
			<xsl:with-param name="text" select="osak:CoordETRS89z32NMeasure" />
		</xsl:call-template>
		<xsl:if test="model:adrXKoordinat">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'X-koordinat (Syst 34)'" />
				<xsl:with-param name="text" select="model:adrXKoordinat" />
			</xsl:call-template>
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Y-koordinat (Syst 34)'" />
				<xsl:with-param name="text" select="model:adrYKoordinat" />
			</xsl:call-template>
		</xsl:if>		
	</xsl:template>

	<!-- ***********************************   BFE-Nummer   ********************************** -->
	<xsl:template match="model:BestemtFastEjendomNummer">

		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'BFE-nummer'" />
			<xsl:with-param name="text" select="." />
		</xsl:call-template>                    
	</xsl:template>

	<!-- ***********************************   EjendomType   ********************************** -->
	<xsl:template match="model:EjendomType">
	
		<xsl:apply-templates/>
		
	</xsl:template>

	<!-- ***********************************   Ejerlejlighed   ********************************** -->
	<xsl:template match="model:Ejerlejlighed">

		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'" />
			<xsl:with-param name="text" select="'Ejerlejlighed'" />
		</xsl:call-template>

		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Ejerlejlighedsnummer" />
		</xsl:call-template>
	</xsl:template>
	
	<!--*************************************** Anpart *****************************************-->
	<xsl:template match="model:Anpart">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Anpart'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Anpartsnummer"/>
		</xsl:call-template>
	</xsl:template>

	<!--***************************** HovedejendomEjerlejligheder **************************-->
	<xsl:template match="model:HovedejendomEjerlejligheder">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Hovedejendom opdelt i ejerlejligheder'"/>
		</xsl:call-template>		
	</xsl:template>
	
	<!--************************************ AnpartLejetGrund *******************************-->
	<xsl:template match="model:AnpartLejetGrund">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Anpart på lejet grund'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Anpartsnummer"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Bygningsnummer'"/>
			<xsl:with-param name="text" select="model:Bygningsnummer"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<!--******************************* BygningLejetGrund *********************************-->
	<xsl:template match="model:BygningLejetGrund">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Bygning på lejet grund'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Bygningsnummer"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<!--******************************* BygningLejetGrundEjerlejligheder *****************-->
	<xsl:template match="model:BygningLejetGrundEjerlejligheder">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Bygning på lejet grund opdelt i ejerlejligheder'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Bygningsnummer"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--************************** model:BygningLejetGrundAnparter *********************-->
	<xsl:template match="model:BygningLejetGrundAnparter">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Bygning på lejet grund opdelt i anparter'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Bygningsnummer"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--******************************* model:Timeshare **********************************-->
	<xsl:template match="model:Timeshare">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Timeshare'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Timesharenummer"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--******************************* model:TimeshareUger ******************************-->
	<xsl:template match="model:TimeshareUger">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Timeshare'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Timesharenummer"/>
		</xsl:call-template>

		<xsl:apply-templates select="model:UgenummerSamling"/>
	</xsl:template>
	
	<!--******************************* model:UgenummerSamling *****************-->
	<xsl:template match="model:UgenummerSamling">
		<xsl:variable name="uger">
			<xsl:for-each select="model:Ugenummer">
					<xsl:value-of select="."/>
					<xsl:if test="position() != last()">
						<xsl:value-of select="', '"/>
					</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Timeshare uger'"/>
			<xsl:with-param name="text" select="$uger"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--******************************* model:HovedejendomTimeshare *****************-->
	<xsl:template match="model:HovedejendomTimeshare">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Hovedejendom timeshare'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--******************************* model:HovedejendomAnparter *******************-->
	<xsl:template match="model:HovedejendomAnparter">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Hovedejendom anparter'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--******************************* model:Grund **************************************-->
	<xsl:template match="model:Grund">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Grund'"/>
		</xsl:call-template>
	</xsl:template>
	
	<!--************************ model:EjerlejlighedBygningLejetGrund ****************-->
	<xsl:template match="model:EjerlejlighedBygningLejetGrund">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Ejendomstype'"/>
			<xsl:with-param name="text" select="'Ejerlejlighed i bygning på lejet grund'"/>
		</xsl:call-template>
		
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Nummer'"/>
			<xsl:with-param name="text" select="model:Ejerlejlighedsnummer"/>
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Bygningsnummer'"/>
			<xsl:with-param name="text" select="model:Bygningsnummer"/>
		</xsl:call-template>
	</xsl:template>

	<!-- ***********************************   FindAdresse   ********************************** -->
	<xsl:template name="model:FindAdresse"> 
		<xsl:param name="node"/> 

		<xsl:choose>
			<xsl:when test="$node/model:Matrikel">
				<xsl:for-each select="$node/model:Matrikel">
					<xsl:sort select="kms:CadastralDistrictIdentifier" data-type="number" order="ascending" />
					<xsl:sort select="model:Matrikelnummer" data-type="text" order="ascending"/>

					<xsl:variable name="ejendomKey" select="concat(local-name($node/model:EjendomType/*), '_', $node//model:Anpartsnummer, '_', $node//model:Ejerlejlighedsnummer, '_', $node//model:Bygningsnummer, '_', $node//model:Timesharenummer, '_', $node//model:Ugenummer, '_', number(kms:CadastralDistrictIdentifier), '_', model:Matrikelnummer)"/>
					<xsl:variable name="ejendomStruktur" select="key('EjendomStruktur', $ejendomKey)"/>

					<xsl:if test="$ejendomStruktur/xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:MunicipalityCode">
						<!-- AdresseStruktur fra snapshot. 
							 Findes ud fra MunicipalityCode og StreetCode fra EjendomStrukturen i snapshot -->
							 
						<xsl:variable name="adresseKey" select="concat($ejendomStruktur//cpr-1:MunicipalityCode, '_',$ejendomStruktur //cpr-1:StreetCode, '_',$ejendomStruktur //dkcc-1:StreetBuildingIdentifier, '_', $ejendomStruktur//dkcc-1:FloorIdentifier, '_', $ejendomStruktur//dkcc-1:SuiteIdentifier)"/>
						<xsl:variable name="adresseStruktur" select="key('AdresseStruktur', $adresseKey)"/>
							 
						<!-- Vejnavn og husnr -->
						<xsl:choose>
							<xsl:when test="count($adresseStruktur//dkcc-1:FloorIdentifier)>0 and count($adresseStruktur//dkcc-1:SuiteIdentifier)>0">
								<xsl:call-template name="two_columns">
									<xsl:with-param name="prompt" select="'Adresse'" />
									<xsl:with-param name="text" select="$adresseStruktur/dkcc:StreetName" />
									<xsl:with-param name="text2" select="concat(string($adresseStruktur //dkcc-1:StreetBuildingIdentifier), ', ',string($adresseStruktur//dkcc-1:FloorIdentifier), '. ', string($adresseStruktur//dkcc-1:SuiteIdentifier),'.')" />
								</xsl:call-template>
							</xsl:when>
							<xsl:when test="count($adresseStruktur//dkcc-1:FloorIdentifier)>0 and count($adresseStruktur//dkcc-1:SuiteIdentifier)=0">
								<xsl:call-template name="two_columns">
									<xsl:with-param name="prompt" select="'Adresse'" />
									<xsl:with-param name="text" select="$adresseStruktur/dkcc:StreetName" />
									<xsl:with-param name="text2" select="concat(string($adresseStruktur //dkcc-1:StreetBuildingIdentifier), ', ',string($adresseStruktur//dkcc-1:FloorIdentifier),'.')" />
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="two_columns">
									<xsl:with-param name="prompt" select="'Adresse'" />
									<xsl:with-param name="text" select="$adresseStruktur/dkcc:StreetName" />
									<xsl:with-param name="text2" select="$adresseStruktur //dkcc-1:StreetBuildingIdentifier" />
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
				
						<!-- Postnummer og by -->
						<xsl:call-template name="column2">
							<xsl:with-param name="text" select="$adresseStruktur/dkcc:PostCodeIdentifier" />
							<xsl:with-param name="text2" select="$adresseStruktur/dkcc:DistrictName" />
						</xsl:call-template>
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$node/../xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:MunicipalityCode">
					<xsl:variable name="UMadresseKey" select="concat($node/../xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:MunicipalityCode, '_',$node/../xkom:AddressSpecific/xkom-1:AddressAccess/cpr-1:StreetCode, '_',$node/../xkom:AddressSpecific/xkom-1:AddressAccess/dkcc-1:StreetBuildingIdentifier, '_', $node/../xkom:AddressSpecific/dkcc-1:FloorIdentifier, '_', $node/../xkom:AddressSpecific/dkcc-1:SuiteIdentifier)"/>
					<xsl:variable name="UMadresseStruktur" select="key('AdresseStruktur', $UMadresseKey)"/>
						 
					<!-- Vejnavn og husnr -->
					<xsl:choose>
						<xsl:when test="count($UMadresseStruktur//dkcc-1:FloorIdentifier)>0 and count($UMadresseStruktur//dkcc-1:SuiteIdentifier)>0">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Adresse'" />
								<xsl:with-param name="text" select="$UMadresseStruktur/dkcc:StreetName" />
								<xsl:with-param name="text2" select="concat(string($UMadresseStruktur //dkcc-1:StreetBuildingIdentifier), ', ',string($UMadresseStruktur//dkcc-1:FloorIdentifier), '. ', string($UMadresseStruktur//dkcc-1:SuiteIdentifier),'.')" />
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="count($UMadresseStruktur//dkcc-1:FloorIdentifier)>0 and count($UMadresseStruktur//dkcc-1:SuiteIdentifier)=0">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Adresse'" />
								<xsl:with-param name="text" select="$UMadresseStruktur/dkcc:StreetName" />
								<xsl:with-param name="text2" select="concat(string($UMadresseStruktur //dkcc-1:StreetBuildingIdentifier), ', ',string($UMadresseStruktur//dkcc-1:FloorIdentifier),'.')" />
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Adresse'" />
								<xsl:with-param name="text" select="$UMadresseStruktur/dkcc:StreetName" />
								<xsl:with-param name="text2" select="$UMadresseStruktur //dkcc-1:StreetBuildingIdentifier" />
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
			
					<!-- Postnummer og by -->
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$UMadresseStruktur/dkcc:PostCodeIdentifier" />
						<xsl:with-param name="text2" select="$UMadresseStruktur/dkcc:DistrictName" />
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
</xsl:stylesheet>
