<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				version="1.0"
				xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
			    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
                xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
                xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    			xmlns="http://www.w3.org/1999/xhtml"
    			xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    			xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    			exclude-result-prefixes="#default cpr-1 cvr model snapshot"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DiverseFunktionerXHtml.xslt 165542 2020-01-29 11:36:48Z cander28@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- DIVERSE HJÆLPEFUNKTIONER -->

	<!-- ***************************************************************************************** -->
	<xsl:template name="eakt:DokumentAliasIdentifikator">
		<xsl:param name="node"/>

		<xsl:if test="$node/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator">
			<xsl:call-template name="DokumentAlias">
				<xsl:with-param name="Identifikator" select="$node/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator"/>
					<xsl:with-param name="indent" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$node/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator">
			<xsl:call-template name="DokumentAlias">
				<xsl:with-param name="Identifikator" select="$node/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator"/>
					<xsl:with-param name="indent" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
  	</xsl:template>

	<!-- ***********************************   OgsaaLystOverfoert  ********************************** -->
	<xsl:template name="OgsaaLystOverfoert">
		<xsl:param name="node"/>
		<xsl:param name="dokumenttype"/>
		<!--<xsl:param name="haeftelse" select="false()" />-->
		<xsl:if test="$node/eakt:OgsaaLystPaaSamling">
			<xsl:call-template name="linefeed"/>
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'OGSÅ TINGLYST PÅ'"/>
			</xsl:call-template>
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Antal'"/>
				<xsl:with-param name="text" select="$node/eakt:OgsaaLystPaaSamling/eakt:OgsaaLystPaaAntal"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$node/eakt:DokumentOverfoertIndikator = 'true'">
			<xsl:if test="$node/eakt:KonverteretDigitalPantebrevIndikator = 'false'">
				<xsl:call-template name="linefeed"/>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Konverteret til digital pantebrev'"/>
					<xsl:with-param name="text" select="'Nej'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$node/eakt:DokumentInformationOverfoert/eakt:DokumentFilnavnTekst != ''">
				<xsl:call-template name="linefeed"/>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Akt nr'"/>
					<xsl:with-param name="text" select="$node/eakt:DokumentInformationOverfoert/eakt:DokumentFilnavnTekst"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	<!-- **************************   bilag_udskriv  *********************** -->
	<xsl:template name="bilag_udskriv">
		<xsl:param name="node" />

		<xsl:for-each select="$node/model:BilagReference">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Bilagsreference'"/>
				<xsl:with-param name="text" select="model:BilagReference"/>
			</xsl:call-template>

			<xsl:variable name="bilag_refkode_typeid" select="model:BilagReferenceKode" />
			<xsl:variable name="bilag_refkode_tekst" select="$opslag//BilagReferenceKode[@id = $bilag_refkode_typeid]"/>


			<xsl:if test="$bilag_refkode_tekst != ''">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Bilag referencekode'"/>
					<xsl:with-param name="text" select="$bilag_refkode_tekst"/>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:BilagBeskrivelse"/>
				<xsl:with-param name="indent_1st_line" select="'off'"/>
				<xsl:with-param name="text" select="'Beskrivelse af bilag'"/>
			</xsl:call-template>


			<xsl:call-template name="BilagProeves">
				<xsl:with-param name="node" select="../model:ProevesIndikator"/>
			</xsl:call-template>

			<xsl:call-template name="linefeed" />
		</xsl:for-each>

	</xsl:template>

	<!-- **************************   PersonCivilRegistrationIdentifier  *********************** -->
	<xsl:template match="cpr-1:PersonCivilRegistrationIdentifier">
    <table>
			<tbody>
				<tr>
					<td class="left">
						<xsl:value-of select="'Cpr-nr.'"/>
				</td>
				<td class="right">
					<xsl:call-template name="VisCPR">
						<xsl:with-param name="CPR" select="."/>
					</xsl:call-template>
				</td>
			</tr>
		</tbody>
		</table>
	</xsl:template>

	<!-- ***********************************   CVRnumberIdentifier   ********************************** -->
	<xsl:template match="cvr:CVRnumberIdentifier">

		<xsl:call-template name="two_columns">
			<xsl:with-param  name="prompt" select="'Cvr-nr.'" />
			<xsl:with-param name="text" select="." />
		</xsl:call-template>

	</xsl:template>

	<!--********************************* UdskrivAnmeldeAdskiller ****************************-->
	<xsl:template name="UdskrivAnmeldeAdskiller">
		<xsl:call-template name="dividerlong"/>
		<h2 class="adskiller">
			<xsl:value-of select="'Nedenstående anmelderoplysninger underskrives alene af anmelder.'"/>
		</h2>
	</xsl:template>

	<!-- *******************************   VisAndenTekst template   ********************************** -->
	<!-- Håndterer visning af anm:AndenTekst med overskrift angivet i parameter -->
	<!-- node       - node som AndenTekst elementet findes i -->
	<!-- overskrift - Tekst som anvendes i heading til teksten  -->
	<xsl:template name="VisAndenTekst">
		<xsl:param name="node" />
		<xsl:param name="overskrift" />

		<xsl:if test="$node !=''">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="$overskrift"/>
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="$node"/>
			</xsl:call-template>
			<xsl:text>&#xa;</xsl:text>
		</xsl:if>

	</xsl:template>

	<!-- *******************************   VisAndenTekstSamling template   ********************************** -->
	<!-- Håndterer visning af anm:AndenTekstSamling med overskrift angivet i parameter -->
	<!-- node       - node som AndenTekstSamling elementet findes i -->
	<!-- overskrift - Tekst som anvendes i heading til teksten  -->
	<xsl:template name="VisAndenTekstSamling">
		<xsl:param name="node" />
		<xsl:param name="overskrift" />

		<xsl:if test="$node !=''">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="$overskrift"/>
			</xsl:call-template>
			<xsl:for-each select="$node/anm:AndenTekstTilSamling">
				<xsl:call-template name="VisTekstAngivelse">
					<xsl:with-param name="node" select="."/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:if>

	</xsl:template>

	<!-- ********************************************************************************************* -->
	<!-- ********************************  VisTekstAngivelse template  ******************************* -->
	<!-- ********************************************************************************************* -->

	<!-- Denne template tager en node af typen 'TekstAngivelse' og viser overskrift i kolonne 1 samt alle -->
	<!-- afsnittene i kolonne 2 med word-wrap. -->
	<!-- 'node' - angiver den TekstAngivelse node, der skal vises. Der tages højde for om $node er tom -->
	<xsl:template name="VisTekstAngivelse">
		<xsl:param name="node"/>
		<xsl:param name="linefeed" select="'on'"/>
		<xsl:param name="text"/>

		<xsl:if test="$node != ''">
			<xsl:choose>
				<xsl:when test="$node/model:TekstGruppe">
					<xsl:apply-templates select="$node/model:TekstGruppe">
						<xsl:with-param name="indent_1st_line" select="'on'"/>
					</xsl:apply-templates>
				</xsl:when>
				<xsl:when test="$node/model:FraseIdentifikator">
					<xsl:apply-templates select="$node/model:FraseIdentifikator">
						<xsl:with-param name="indent_1st_line" select="'on'"/>
					</xsl:apply-templates>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
	</xsl:template>


	<!-- ********************************************************************************************* -->
	<!-- ***********************************   VisFraser template   ********************************** -->
	<!-- ********************************************************************************************* -->

	<!-- Denne template tager en node af typen 'Frase' og viser overskrift i kolonne 1 samt alle -->
	<!-- afsnittene i kolonne 2 med word-wrap. -->
	<!-- Jeg er ikke klar over hvad TekstGruppe gør (DMU) -->
	<!-- 'node' - angiver den Frase node, der skal vises. Der tages højde for om $node er tom -->
	<xsl:template name="VisFraser">
		<xsl:param name="node"/>
		<xsl:param name="indent_1st_line" select="'on'"/>
		<xsl:param name="linefeed" select="'on'"/>
		<xsl:param name="text"/>

		<xsl:if test="$node != ''">
			<xsl:choose>
        <xsl:when test="$node/model:FraseTekst">
          <xsl:apply-templates select="$node/model:FraseTekst">
            <xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
            <xsl:with-param name="linefeed" select="$linefeed"/>
            <xsl:with-param name="text" select="$text"/>
          </xsl:apply-templates>
        </xsl:when>
				<xsl:when test="$node/model:TekstGruppe or $node/model:FraseIdentifikator">
					<xsl:for-each select="$node/model:TekstGruppe | $node/model:FraseIdentifikator">
						<xsl:choose>
							<xsl:when test="position()=1">
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
									<xsl:with-param name="text" select="$text"/>
								</xsl:apply-templates>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="'on'"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
								</xsl:apply-templates>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
	</xsl:template>



	<!-- ********************************************************************************************* -->
	<!-- ***********************************   VisFraser template   ********************************** -->
	<!-- ********************************************************************************************* -->

	<!-- Denne template tager en node af typen 'Frase' og viser overskrift i kolonne 1 samt alle -->
	<!-- afsnittene i kolonne 2 med word-wrap. -->
	<!-- Jeg er ikke klar over hvad TekstGruppe gør (DMU) -->
	<!-- 'node' - angiver den Frase node, der skal vises. Der tages højde for om $node er tom -->
	<xsl:template name="VisFraser_old">
		<xsl:param name="node"/>
		<xsl:param name="indent_1st_line" select="'on'"/>
		<xsl:param name="linefeed" select="'on'"/>
		<xsl:param name="text"/>

		<xsl:if test="$node != ''">
			<xsl:choose>
				<xsl:when test="$node/model:TekstGruppe">
					<xsl:for-each select="$node/model:TekstGruppe">
						<xsl:choose>
							<xsl:when test="position()=1">
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
									<xsl:with-param name="text" select="$text"/>
								</xsl:apply-templates>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="'on'"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
								</xsl:apply-templates>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$node/model:FraseTekst">
					<xsl:apply-templates select="$node/model:FraseTekst">
						<xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
						<xsl:with-param name="linefeed" select="$linefeed"/>
						<xsl:with-param name="text" select="$text"/>
					</xsl:apply-templates>
				</xsl:when>
				<xsl:when test="not($node/model:TekstGruppe or $node/model:FraseTekst) and $node/model:FraseIdentifikator">
					<xsl:for-each select="$node/model:FraseIdentifikator">
						<xsl:choose>
							<xsl:when test="position()=1">
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
									<xsl:with-param name="text" select="$text"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
								</xsl:apply-templates>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select=".">
									<xsl:with-param name="indent_1st_line" select="'on'"/>
									<xsl:with-param name="text" select="$text"/>
									<xsl:with-param name="linefeed" select="$linefeed"/>
								</xsl:apply-templates>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</xsl:if>

	</xsl:template>

	<!-- ***********************************   FraseIdentifikator   ********************************** -->
	<xsl:template match="model:FraseIdentifikator">
		<xsl:param name="indent_1st_line" select="'on'"/>
		<xsl:param name="text"/>
		<xsl:param name="linefeed" select="'on'"/>

		<xsl:variable name="FraseIdentifikator" select="."/>
		<xsl:variable name="Frasen" select="//snapshot:SnapshotSamling/snapshot:FraseSamling/model:Frase[model:FraseIdentifikator = $FraseIdentifikator]"/>

		<xsl:choose>
			<xsl:when test="$Frasen">
				<xsl:apply-templates select="$Frasen/model:FraseTekst">
					<xsl:with-param name="indent_1st_line" select="$indent_1st_line"/>
						<xsl:with-param name="text" select="$text"/>
						<xsl:with-param name="linefeed" select="$linefeed"/>
				</xsl:apply-templates>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Fejl: Manglende tekst i snapshot.'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- *********************************** FraseTekst ********************************** -->
	<xsl:template match="model:FraseTekst | model:TekstGruppe">
		<xsl:param name="indent_1st_line" select="'on'"/>
		<xsl:param name="linefeed" select="'on'"/>
		<xsl:param name="text"/>

		<xsl:choose>
			<xsl:when test="$indent_1st_line = 'off'">
				<xsl:choose>
					<xsl:when test="model:Overskrift and model:Overskrift != ''">
						<xsl:call-template name="two_columns">
							<xsl:with-param name="prompt" select="$text"/>
							<xsl:with-param name="text" select="model:Overskrift"/>
						</xsl:call-template>
						<xsl:for-each select="model:Afsnit">
							<xsl:call-template name="column2">
								<xsl:with-param name="text" select="."/>
							</xsl:call-template>
							<xsl:if test="position() != last()">
								<xsl:call-template name="linefeed" /> <!--  ikke hvis sidste afsnit -->
							</xsl:if>
						</xsl:for-each>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="model:Afsnit">
							<xsl:choose>
								<xsl:when test="position()=1">
									<xsl:call-template name="two_columns">
										<xsl:with-param name="prompt" select="$text"/>
										<xsl:with-param name="text" select="."/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="column2">
										<xsl:with-param name="text" select="."/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:if test="position() != last()">
								<xsl:call-template name="linefeed" /> <!--  ikke hvis sidste afsnit -->
							</xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="model:Overskrift != ''">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="model:Overskrift"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:for-each select="model:Afsnit">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="."/>
					</xsl:call-template>
					<xsl:if test="position() != last()">
						<xsl:call-template name="linefeed" /> <!--  ikke hvis sidste afsnit -->
					</xsl:if>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:if test="$linefeed='on'">
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>

	<!-- ********************************************************************************************* -->
	<!-- ******************************************  Headers   ************************************* -->
	<!-- ********************************************************************************************* -->

	<!-- Håndterer visning af dokument overskrift centreret -->
	<!-- 'text' - angiver sidens overskrift, der skal centreres -->
	<xsl:template match="node( ) | @*" mode="document_header" name="document_header">
		<xsl:param name="text" select="."/>
		<xsl:param name="subheader" select="''"/>
		<xsl:param name="proevetinglysning" select="'false'"/>
		<xsl:param name="ekstra_linefeed" select="'true'"/>
		<xsl:param name="show_logo" select="'true'"/>

		<xsl:variable name="camelCaseText">
		    <xsl:call-template name="CamelCaseText">
		    	<xsl:with-param name="text" select="$text"/>
		    </xsl:call-template>
		</xsl:variable>

		<xsl:if test="$show_logo='true'">
			<img class="logo" alt="Tinglysningsrettens logo" src="dss-logo.png"/>
		</xsl:if>
		<h1 class="title">
			<xsl:value-of select="$camelCaseText"/>
		</h1>
		
		<!-- Udskriv teksten i subheader centreret -->
		<xsl:if test="$subheader!=''">
			<h1 class="title">
				<xsl:value-of select="$subheader"/>
			</h1>
		</xsl:if>
		
		<!-- Udskriv evt. teksten for prøvetinglysning centreret -->
		<xsl:choose>
			<xsl:when test="$proevetinglysning = 'true'">
				<div class="proevetinglysning">
					<xsl:value-of select="$proevetinglysning_text"/>
				</div>
			</xsl:when>
			<xsl:otherwise>
				<!--<xsl:call-template name="linefeed"/>	-->
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="''"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

		<!-- Håndterer visning af underoverskrift på dokument, centreret -->
	<!-- 'text' - angiver sidens overskrift, der skal centreres -->
	<!-- Udskriv teksten i TEXT2 i kolonne 2 med word wrap -->
	<!-- ***********************************   document_subheader   ******************************* -->
	<xsl:template match="node( ) | @*" mode="document_subheader" name="document_subheader">
		<xsl:param name="text" select="."/>
		<xsl:param name="text2" select="''"/>
		<xsl:param name="linefeed" select="'on'"/>

		<xsl:variable name="camelCaseText">
		    <xsl:call-template name="CamelCaseText">
		    	<xsl:with-param name="text" select="$text"/>
		    </xsl:call-template>
		</xsl:variable>

		<!-- Udskriv teksten i TEXT centreret -->
		<xsl:if test="string-length($text)>0">
			<xsl:call-template name="dividerlong"/>
			<h2 class="subheader">
				<xsl:value-of select="$camelCaseText"/>
			</h2>
    	</xsl:if>
		<!-- Udskriv teksten i TEXT2 i kolonne 2 med word wrap -->
		<xsl:if test="string-length($text2)>0">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$text2"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<!-- Håndterer visning af tekst i kolonne 1. Foretager word-wrap hvis nødvendigt -->
	<!-- 'text' - angiver teksten, der skal vises i kolonne 1 -->
	<!-- ***********************************   heading   ******************************* -->
	<xsl:template match="node( ) | @*" mode="heading" name="heading">
		<xsl:param name="text" select="."/>
		<xsl:param name="colon" select="':'"/>
		
		<hr class="heading"/>
		<h4 class="header">
			<xsl:call-template name="CamelCaseText">
				<xsl:with-param name="text" select="concat($text,$colon)"/>
			</xsl:call-template>
		</h4>
	</xsl:template>


	<!-- Håndterer visning af tekst i kolonne 1. Foretager word-wrap hvis nødvendigt -->
	<!-- 'text' - angiver teksten, der skal vises i kolonne 1 -->
	<!-- ***********************************   heading   ******************************* -->
	<xsl:template match="node( ) | @*" mode="heading" name="headingPreserveCase">
		<xsl:param name="text" select="."/>
		<xsl:param name="divider" select="'true'"/>
		<xsl:param name="colon" select="':'"/>

		<hr class="heading"/>
		<h4 class="header">
			<xsl:value-of select="concat($text,$colon)"/>
		</h4>
	</xsl:template>


	<!-- Laver skillelinje i hele sidens bredde -->
	<xsl:template name="dividerlong">
		<hr class="long"/>
	</xsl:template>

	<!-- Laver skillelinje i hele sidens bredde, med linjeskift før og efter -->
	<xsl:template name="dividersvar">
		<xsl:call-template name="linefeed"/>
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed"/>
	</xsl:template>

	<xsl:template name="dividerlong_dashed">
		<hr class="long_dashed"/>
	</xsl:template>

	<!-- Laver skillelinje i hele sidens bredde -->
	<xsl:template name="divider">
			<hr/>
	</xsl:template>

   <!-- Indsætter en blank linje -->
	<xsl:template name="linefeed">
		<div class="linefeed">
				<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
		</div>
	</xsl:template>

	<!-- ********************************************************************************************* -->
	<!-- ***********************************   Wrap tekst i kolonner   ******************************* -->
	<!-- ********************************************************************************************* -->

	<!-- Håndterer visning af tekst i kolonne 1. Foretager word-wrap hvis nødvendigt -->
	<!-- 'text' - angiver teksten, der skal vises i kolonne 1 -->
	<xsl:template match="node( ) | @*" mode="column1" name="column1">
		<xsl:param name="text" select="."/>

		<div class="column1">
			<xsl:value-of select="concat($text, ':')" />
		</div>
	</xsl:template>

	<!-- Håndterer visning af tekst i kolonne 2. Foretager word-wrap hvis nødvendigt -->
	<!-- 'text'  - angiver teksten, der skal vises i kolonne 2 -->
	<!-- 'text2' - angiver en 'del 2' af teksten der skal vises. Hvis angivet, vises de -->
	<!--           to tekst-dele adskilt med et mellemrum -->
	<xsl:template match="node( ) | @*" mode="column2" name="column2">
		<xsl:param name="text" select="."/>
		<xsl:param name="text2" select="''"/>

		<table>
			<tbody>
				<tr>
					<td class="left">
						<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
					</td>
					<td class="right">
						<xsl:choose>
							<xsl:when test="$text != ''">
								<xsl:value-of select="normalize-space(concat($text, ' ', $text2))" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>

	<!-- Håndterer visning af prompt i kolonne 1 efterfulgt af tekst i kolonne 2. -->
	<!-- Foretager word-wrap i begge kolonner hvis nødvendigt -->
	<!-- 'prompr' - angiver teksten til kolonne 1 (ledeteksten) -->
	<!-- 'text'   - angiver teksten til kolonne 2 -->
	<!-- 'text2'  - angiver en 'del 2' af teksten der skal vises. Hvis angivet, vises de -->
	<!--            to tekst-dele adskilt med et mellemrum -->
	<xsl:template name="two_columns">
		<xsl:param name="prompt" />
		<xsl:param name="text" />
		<xsl:param name="text2" select="''"/>

		<table>
			<tbody>
				<tr>
					<td class="left">
						<xsl:choose>
							<xsl:when test="$prompt != ''">
								<xsl:value-of select="concat($prompt, ':')" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td class="right">
						<xsl:choose>
							<xsl:when test="$text != ''">
								<xsl:value-of select="normalize-space(concat($text, ' ', $text2))" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>

	<!-- Håndterer visning af prompt i kolonne 1 efterfulgt af tekst i kolonne 2. -->
	<!-- Foretager word-wrap i begge kolonner hvis nødvendigt -->
	<!-- 'prompr' - angiver teksten til kolonne 1 (ledeteksten) -->
	<!-- 'text'   - angiver teksten til kolonne 2 -->
	<!-- 'text2'  - angiver en 'del 2' af teksten der skal vises. Hvis angivet, vises de -->
	<!--            to tekst-dele adskilt med et mellemrum -->
	<xsl:template name="two_columns_sub">
		<xsl:param name="prompt" />
		<xsl:param name="text" />
		<xsl:param name="text2" select="''"/>
		<table class="two_columns">
			<tbody>
				<tr>
					<td class="left">
						<xsl:value-of select="concat($prompt, ':')" />
					</td>
					<td class="right">
						<xsl:choose>
							<xsl:when test="$text != ''">
								<xsl:value-of select="normalize-space(concat($text, ' ', $text2))" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:text disable-output-escaping="yes">&amp;#160;</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>


	<!-- Template til at foretage word-wrap af tekst baseret på venstre margin og kolonnebredde -->
	<!-- 'input'           - angiver den tekst, der skal vises. Default er current node -->
	<!-- 'left_margin'     - angiver hvor mange mellemrum, der skal vises før teksten -->
	<!-- 'width'           - angiver bredden på teksten, der vises pr. linje -->
	<!-- 'indent_1st_line' - angiver, om første linje også skal have mellemrum foranstillet. -->
	<!--                     Hvis der allerede er skrevet ledetekst, sættes denne til 'off', eller 'on'. -->
	<!--                     Default er 'on' -->
	<xsl:template match="node( ) | @*" name="wrap" mode="wrap">
		<xsl:param name="input" select="."/>
		<xsl:param name="left_margin" select="0" />
		<xsl:param name="width" select="$linelength" />
		<xsl:param name="indent_1st_line" select="'on'"/>

		<xsl:if test="$input">
			<xsl:variable name="line">
				<xsl:choose>
					<xsl:when test="string-length($input) > $width">
						<xsl:call-template name="substring-before-last">
							<xsl:with-param name="input" select="substring($input,1,$width)"/>
							<xsl:with-param name="substr" select=" ' ' "/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$input"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<xsl:choose>
				<xsl:when test="$indent_1st_line = 'on'" >
					<xsl:value-of select="substring($spaces,1,$left_margin)" />
				</xsl:when>
			</xsl:choose>

			<xsl:value-of select="$line"/>
			<xsl:value-of select="substring($spaces,1,$width - string-length($line) + 1)" />

			<xsl:variable name="leftover" select="substring($input, string-length($line) + 2)"/>
			<xsl:if test="$leftover">
				<xsl:text>&#xa;</xsl:text>
			</xsl:if>

			<xsl:call-template name="wrap">
				<xsl:with-param name="input" select="$leftover"/>
				<xsl:with-param name="left_margin" select="$left_margin"/>
				<xsl:with-param name="width" select="$width"/>
				<xsl:with-param name="indent_1st_line" select="'on'"/>
			</xsl:call-template>
		</xsl:if>

	</xsl:template>


</xsl:stylesheet>
