<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				version="1.0"
				xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
			    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
                xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
                xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
                xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
                xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: DiverseFunktioner.xslt 113504 2017-02-23 11:50:03Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- VARIABELDEFINITIONER -->	
	<xsl:variable name="fremtidsfuldmagtstandardtekst2" select="'Nærværende fremtidsfuldmagt er vedstået for notar, der ved sin underskrift har bekræftet fuldmagtsgiverens identitet samt at denne var i stand til fornuftsmæssigt at oprette en fremtidsfuldmagt.'"/>
	<xsl:variable name="fremtidsfuldmagtstandardtekst2_statsforvaltning" select="'Oprettet af og vedstået for Familieretshuset.'"/>
	<xsl:variable name="proevetinglysning_text" select="'Prøvetinglysning - Tinglysning er ikke gennemført'" />
	<xsl:variable name="linelength" select="80"/>
	<xsl:variable name="tabstop" select="30"/>
	<xsl:variable name="spaces" select="'                                                                                          '"/>
	<xsl:variable name="heading_divider" select="'=========================================================================================='"/>
	<xsl:variable name="divider" select="'------------------------------------------------------------------------------------------'"/>
	<xsl:variable name="linefeed" select="'&#xa;'" />
	<xsl:variable name="linelong" select="'----------------------------------------------------------------------'" />
	<xsl:variable name="lineshort" select="'------------------------------'" />
	<xsl:variable name="formatvaluta" select="'###.###.###.###.##0'" />
	<xsl:variable name="formatkurs" select="'##.##0,####'" />
	<xsl:variable name="formatrente" select="'##0,######'" />
	<xsl:variable name="datosep" select="'.'" />
	
	<xsl:variable name="opslag" select="document('../Mapning/Opslag.xml')"/>
	<xsl:variable name="opslagAlternativ" select="document('../Mapning/OpslagAlternativ.xml')"/>
	<xsl:decimal-format name="currency-format" decimal-separator="," grouping-separator="." NaN="Ikke oplyst" />
	
	<xsl:variable name="lowercase" select="'abcdefghijklmnopqrstuvwxyzæøå'" />
	<xsl:variable name="uppercase" select="'ABCDEFGHIJKLMNOPQRSTUVWXYZÆØÅ'" />	

	<!-- DIVERSE GENERELLE HJÆLPEFUNKTIONER -->
		<!-- Fjernelse af de sidste 4 cifre i cpr -->
	<xsl:template name ="VisCPR">
		<xsl:param name="CPR" select="''"/>
		<xsl:value-of select="concat(substring($CPR,1,6),'-****')"/>
	</xsl:template>

		<!-- Ændrer EJENDOM: til Ejendom: eller ejendom: til Ejendom: -->
	<xsl:template name="CamelCaseText">
	  <xsl:param name="text"/>
		<xsl:choose>
			<xsl:when test="$text = 'SDRO-PANTEBREV'">
				<xsl:value-of select="'SDRO-Pantebrev'" />
			</xsl:when>
			<xsl:when test="$text = 'SDO-PANTEBREV'">
				<xsl:value-of select="'SDO-Pantebrev'" />
			</xsl:when>
			<xsl:otherwise>
				  	  <xsl:value-of select="translate(substring($text,1,1), $lowercase, $uppercase)" /><xsl:value-of select="translate(substring($text,2,string-length($text)-1), $uppercase, $lowercase)" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Returnerer en delstreng af 'input' før sidste forekomst af 'substr' -->
	<!-- E.g. kaldt med "Dette er en tekst" og " " returneres "Dette er en"  -->
	<!-- 'input'  - angiver den tekst, der skal deles -->
	<!-- 'substr' - angiver den karakter, der angiver 'word-boundry' -->
	<xsl:template name="substring-before-last">
		<xsl:param name="input" />
		<xsl:param name="substr" />
		<xsl:choose>
			<xsl:when test="$substr and contains($input, $substr)">
				<xsl:variable name="temp" select="substring-after($input, $substr)" />
				<xsl:value-of select="substring-before($input, $substr)" />
				<xsl:if test="contains($temp, $substr)">
					<xsl:value-of select="$substr" />
					<xsl:call-template name="substring-before-last">
						<xsl:with-param name="input" select="$temp"/>
						<xsl:with-param name="substr" select="$substr" />
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$substr = ' ' and contains($input, '&#xA0;')">
				<xsl:call-template name="substring-before-last">
					<xsl:with-param name="input" select="$input"/>
					<xsl:with-param name="substr" select="'&#xA0;'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="substring($input,1,49)" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Returnerer en delstreng af 'input' efter sidste forekomst af 'substr' -->
	<!-- E.g. kaldt med "Dette er en tekst" og " " returneres "tekst"          -->
	<!-- 'input'  - angiver den tekst, der skal deles -->
	<!-- 'substr' - angiver den karakter, der angiver 'word-boundry' -->
	<xsl:template name="substring-after-last" >
		<xsl:param name="input" />
		<xsl:param name="substr" />
		<xsl:variable name="temp" select="substring-after($input, $substr)" />

		<xsl:choose>
			<xsl:when test="@substr and contains($temp, $substr)">
				<xsl:call-template name="substring-after-last">
					<xsl:with-param name="input" select="$temp" />
					<xsl:with-param name="substr" select="$substr" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$temp"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- ********************************************************************************************* -->
	<!-- *********************************   År og måneder formatering   ************************* -->
	<!-- ********************************************************************************************* -->
	
	<!-- Skriver antal måneder som År og måneder -->
	<xsl:template name ="month-year">
		<xsl:param name="month"/>
		<xsl:param name="column1_text" select="''"/>
		<xsl:param name="indent" select="'false'"/>

		<xsl:choose>
			<xsl:when test="$indent = 'false'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="$column1_text"/>
					<xsl:with-param name="text">
						<xsl:call-template name="month-year_sub">
							<xsl:with-param name="month" select="$month"/>
						</xsl:call-template>				
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="$column1_text"/>
					<xsl:with-param name="text">
						<xsl:call-template name="month-year_sub">
							<xsl:with-param name="month" select="$month"/>
						</xsl:call-template>				
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>

	<xsl:template name ="month-year_sub">
		<xsl:param name="month"/>
			<xsl:choose>
					<xsl:when test="$month &lt; 12">
						<xsl:value-of select="concat(string($month),' måneder')" />			
					</xsl:when>
					<xsl:when test="$month mod 12 = 0">
							<xsl:value-of select="concat(string(floor($month div 12)),' år')"/>
					</xsl:when>
					<xsl:when test="$month &gt; 12">
							<xsl:value-of select="concat(string(floor($month div 12)),' år og ',string($month mod 12),' måneder')"/>
					</xsl:when>
					<xsl:otherwise>
							<xsl:value-of select="concat('Fejl: ',$month)"/>
					</xsl:otherwise>
				</xsl:choose>
	</xsl:template>
	
<!-- Skriver År og Måned ud som Tidspunkt -->
	<xsl:template name="month-name-year">
		<xsl:param name="yearmonth" />
		<xsl:param name="column1_text" select="''"/>
		<xsl:param name="indent" select="'false'"/>
		
		<xsl:choose>
			<xsl:when test="$indent = 'false'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="$column1_text"/>
					<xsl:with-param name="text">
						<xsl:call-template name="month-name-year_display">
							<xsl:with-param name="yearmonth" select="$yearmonth"/>
						</xsl:call-template>				
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="$column1_text"/>
					<xsl:with-param name="text">
						<xsl:call-template name="month-name-year_display">
							<xsl:with-param name="yearmonth" select="$yearmonth"/>
						</xsl:call-template>				
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<xsl:template name="month-name-year_display">
		<xsl:param name="yearmonth" />
				<xsl:variable name="month" select="substring($yearmonth,6)" />
				<xsl:variable name="year" select="substring($yearmonth,1,4)" />
				<xsl:choose>
					<xsl:when test="$month = '01'">
						<xsl:value-of select="concat('Januar ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '02'">
						<xsl:value-of select="concat('Februar ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '03'">
						<xsl:value-of select="concat('Marts ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '04'">
						<xsl:value-of select="concat('April ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '05'">
						<xsl:value-of select="concat('Maj ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '06'">
						<xsl:value-of select="concat('Juni ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '07'">
						<xsl:value-of select="concat('Juli ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '08'">
						<xsl:value-of select="concat('August ', $year)"/>
					</xsl:when>			
					<xsl:when test="$month = '09'">
						<xsl:value-of select="concat('September ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '10'">
						<xsl:value-of select="concat('Oktober ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '11'">
						<xsl:value-of select="concat('November ', $year)"/>
					</xsl:when>
					<xsl:when test="$month = '12'">
						<xsl:value-of select="concat('December ', $year)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="column2">
							<xsl:with-param name="text" select="concat($month, ' måneder.')"/>
						</xsl:call-template>
					</xsl:otherwise>			
				</xsl:choose>		
	</xsl:template>



	<!-- Returnerer en dato formateret som dd.mm.åååå -->
	<!-- E.g. kaldt med "2009-08-13" returneres "13.08.2009"          -->
	<!-- Ex.	<xsl:call-template name="formatdato">			-->
	<!-- Ex.		<xsl:with-param name="prompt" select="'UdlaegDato'"/>	-->
	<!-- Ex.		<xsl:with-param name="dato" select="model:UdlaegDato" />	-->
	<!-- Ex.	</xsl:call-template>		-->
	<xsl:template name="formatdato">
		<xsl:param name="dato" />
		
		<xsl:choose>
			<xsl:when test="substring($dato, 1, 10) = '1585-01-01'">
				<xsl:value-of select="'11.11.1111'" />
			</xsl:when>
			<xsl:otherwise>
				<!-- Dag -->
				<xsl:value-of select="substring($dato, 9, 2)" />
				<xsl:value-of select="$datosep" />
				<!-- Måned -->
				<xsl:value-of select="substring($dato, 6, 2)" />
				<xsl:value-of select="$datosep" />
				<!-- år -->
				<xsl:value-of select="substring($dato, 1, 4)" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- Returnerer en dato formateret som dd.mm.yyyy -->
	<!-- E.g. kaldt med "2009-08-13" returneres "13 August 2009"          -->
	<xsl:template name="formatdato_lang">
		<xsl:param name="dato" />
		<!-- Dag -->
		<xsl:value-of select="concat(number(substring($dato, 9, 2)),$datosep)" />
		<xsl:text> </xsl:text>
		<!-- Måned -->
		<xsl:variable name="maaned" select="number(substring($dato, 6, 2))"/>
			<xsl:choose>
				<xsl:when test="$maaned=01">Januar</xsl:when>
				<xsl:when test="$maaned=02">Februar</xsl:when>
				<xsl:when test="$maaned=03">Marts</xsl:when>
				<xsl:when test="$maaned=04">April</xsl:when>
				<xsl:when test="$maaned=05">Maj</xsl:when>
				<xsl:when test="$maaned=06">Juni</xsl:when>
				<xsl:when test="$maaned=07">Juli</xsl:when>
				<xsl:when test="$maaned=08">August</xsl:when>
				<xsl:when test="$maaned=09">September</xsl:when>
				<xsl:when test="$maaned=10">Oktober</xsl:when>
				<xsl:when test="$maaned=11">November</xsl:when>
				<xsl:when test="$maaned=12">December</xsl:when>
				<xsl:otherwise>Ugyldig Måned</xsl:otherwise>
			</xsl:choose>
		<xsl:text> </xsl:text>
		<!-- år -->
		<xsl:value-of select="substring($dato, 1, 4)" />
	</xsl:template>		
		
	<!-- Viser prompt i kolonne og derefter en dato formateret som dd.mm.åååå -->
	<xsl:template name="formatdato_two_columns">
		<xsl:param name="prompt" />
		<xsl:param name="dato" />
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="$prompt"/>
			<xsl:with-param name="text" select="concat(substring($dato, 9, 2), $datosep, substring($dato, 6, 2), $datosep, substring($dato, 1, 4))"/>
		</xsl:call-template>
	</xsl:template>

	<!-- Viser prompt i kolonne og derefter en dato formateret som dd.mm.åååå -->
	<xsl:template name="formatdato_column2">
		<xsl:param name="dato" />
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="concat(substring($dato, 9, 2), $datosep, substring($dato, 6, 2), $datosep, substring($dato, 1, 4))"/>
		</xsl:call-template>
	</xsl:template>

	<!-- Returnerer en dato formateret som dd.mm.åååå tt:mm:ss-->
	<!-- E.g. kaldt med "2001-12-17T09:30:47.0Z" returneres "17.12.2001 09:30:47"          -->
	<!-- Ex	<xsl:variable name="anmdato">    -->
	<!-- Ex	<xsl:call-template name="formatdatotid">    -->
	<!-- Ex		<xsl:with-param name="dato" select="//model:AnmeldelsesTidspunkt"/>    -->
	<!-- Ex	</xsl:call-template>    -->
	<!-- Ex	</xsl:variable>    -->
	<!-- Ex	<xsl:call-template name="column2">    -->
	<!-- Ex		<xsl:with-param name="text" select="string($anmdato)"/>    -->
	<!-- Ex	</xsl:call-template>    -->
	<xsl:template name="formatdatotid">
		<xsl:param name="dato" />
		<!-- Dag -->
		<xsl:value-of select="substring($dato, 9, 2)" />
		<xsl:value-of select="$datosep" />
		<!-- Måned -->
		<xsl:value-of select="substring($dato, 6, 2)" />
		<xsl:value-of select="$datosep" />
		<!-- år -->
		<xsl:value-of select="substring($dato, 1, 4)" />
		<xsl:value-of select="' '" />
		<!-- tid -->
		<xsl:value-of select="substring($dato, 12, 8)" />
	</xsl:template>


	<!-- ****************************************************************************************************-->
	<!-- ********************** termin-write skriver betalingstermin perioder ud i tre steps*********** -->
	<!-- ****************************************************************************************************--> 	
	
	<xsl:template name="termin-write">
		<xsl:param name="pstart"/>
		<xsl:param name="pend"/>
		<xsl:param name="pup"/>
		
		<xsl:variable name="day">
			<xsl:call-template name="strip-zero">
				<xsl:with-param name="date" select="substring($pstart,6,2)"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="substring($pstart,3,2) ='01'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. januar - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='02'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. febuar - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="substring($pstart,3,2) ='03'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. marts - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='04'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. april - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='05'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. maj - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='06'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. juni - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='07'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. juli - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='08'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. august - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='09'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. september - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='10'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. oktober - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='11'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. november - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pstart,3,2) ='12'">
				<xsl:call-template name="termin-write2">
					<xsl:with-param name="text" select="concat('Perioden ', $day, '. december - ')"/>
					<xsl:with-param name="pend" select="$pend"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat('Fejl: Ukendt måned. ', substring($pstart,3,2))"/>
				</xsl:call-template>
			</xsl:otherwise>

		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template name="termin-write2">
		<xsl:param name="text"/>
		<xsl:param name="pend"/>
		<xsl:param name="pup"/>
		
		<xsl:variable name="day">
			<xsl:call-template name="strip-zero">
				<xsl:with-param name="date" select="substring($pend,6,2)"/>
			</xsl:call-template>
		</xsl:variable>

		
		<xsl:choose>
			<xsl:when test="substring($pend,3,2) ='01'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. januar forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='02'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. febuar forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="substring($pend,3,2) ='03'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. marts forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='04'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. april forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='05'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. maj forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='06'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. juni forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='07'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. juli forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='08'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. august forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='09'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. september forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='10'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. oktober forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='11'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. november forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pend,3,2) ='12'">
				<xsl:call-template name="termin-write3">
					<xsl:with-param name="text" select="concat($text, $day, '. december forfalder ')"/>
					<xsl:with-param name="pup" select="$pup"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat('Fejl: Ukendt måned. ', substring($pend,3,2))"/>
				</xsl:call-template>
			</xsl:otherwise>
			
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template name="termin-write3">
		<xsl:param name="text"/>
		<xsl:param name="pup"/>
		
		<xsl:variable name="day">
			<xsl:call-template name="strip-zero">
				<xsl:with-param name="date" select="substring($pup,6,2)"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="substring($pup,3,2) ='01'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. januar')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='02'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. febuar')"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="substring($pup,3,2) ='03'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. marts')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='04'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. april')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='05'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. maj')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='06'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. juni')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='07'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. juli')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='08'">
				<xsl:call-template name="column2">					
					<xsl:with-param name="text" select="concat($text, $day, '. august')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='09'">
				<xsl:call-template name="column2">					
					<xsl:with-param name="text" select="concat($text, $day, '. september')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='10'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. oktober')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='11'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. november')"/>
				</xsl:call-template>
			</xsl:when>

			<xsl:when test="substring($pup,3,2) ='12'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat($text, $day, '. december')"/>
				</xsl:call-template>
			</xsl:when>
			
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="concat('Fejl: Ukendt måned. ', substring($pup,3,2))"/>
				</xsl:call-template>
			</xsl:otherwise>
			
		</xsl:choose>
		
	</xsl:template>
	
	<!--*********************** Fjerner foranstillet nul, eks. 01 -> 1************-->
	<xsl:template name="strip-zero">
		<xsl:param name="date"/>
		<xsl:if test="substring($date,1,1) = '0'">
			<xsl:value-of select="substring($date,2,1)"/>
		</xsl:if>
		<xsl:if test="substring($date,1,1) != '0'">
			<xsl:value-of select="substring($date,1,2)"/>
		</xsl:if>
	</xsl:template>

	<!--********************* Afgør hvad løsøreteksten skal være  -->
	
<xsl:template name="afgoerloesoeretekst">
	<xsl:param name="samling"/>
	<xsl:variable name="antalcpr" select="count(.//model:LoesoereIdentifikator/cpr-1:PersonCivilRegistrationIdentifier)"/>
	<xsl:variable name="antalcvr" select="count(.//model:LoesoereIdentifikator[not(cpr-1:PersonCivilRegistrationIdentifier)])"/>
	<xsl:variable name="cprtekst">
		<xsl:choose>
			<xsl:when test="$antalcpr = 0"/>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$antalcpr = 1">Person</xsl:when>
					<xsl:otherwise>Personer</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="cvrtekst">
		<xsl:choose>
			<xsl:when test="$antalcvr = 0"/>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$antalcvr = 1">Virksomhed</xsl:when>
					<xsl:otherwise>Virksomheder</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="loesoeretekst">
		<xsl:choose>
			<xsl:when test="$antalcpr > 0 and $antalcvr > 0">
				<xsl:value-of select="concat($cprtekst,'/',$cvrtekst)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$antalcpr > 0">
						<xsl:value-of select="$cprtekst"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$cvrtekst"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:value-of select="$loesoeretekst"/>
</xsl:template>


</xsl:stylesheet>
