<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"

>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Haeftelse.xslt 190138 2020-11-05 18:30:18Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende hæftelser. Disse bruges kun i forbindelse med pantebreve  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   HaeftelseBeloeb   ********************************** -->
	<xsl:template match="model:HaeftelseBeloeb">

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'HOVEDSTOL'"/>
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="format-number(floor(.//model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select=".//model:ValutaKode" />
		</xsl:call-template>

		<xsl:call-template name="linefeed" />

	</xsl:template>
	
	<!-- ***********************************   NytHaeftelseBeloeb   ********************************** -->
	<xsl:template match="model:NytHaeftelseBeloeb">

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'NY HOVEDSTOL'"/>
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="format-number(floor(.//model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select=".//model:ValutaKode" />
		</xsl:call-template>

		<xsl:call-template name="linefeed" />

	</xsl:template>
	
	<!-- ***********************************   model:HaeftelseLaan   ********************************** -->
	<xsl:template match="model:HaeftelseLaan">
		<xsl:variable name="laantype" select="model:HaeftelseLaantypeKode"/>
		<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//HaeftelseLaantypeKode[@id = $laantype]" />
		</xsl:call-template>
	</xsl:template>
	
	<!-- ***********************************   HaeftelseLaanKreditorbetegnelseTekst   ********************************** -->
	<xsl:template match="model:HaeftelseLaanKreditorbetegnelseTekst">

		<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="." />
		</xsl:call-template>

	</xsl:template>	
	
	<!-- ***********************************   HaeftelseSaelgerpantebrev   ********************************** -->
	<xsl:template match="model:HaeftelseSaelgerpantebrev">

		<xsl:if test="model:HaeftelseSaelgerpantebrev=true">
		
			<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette er et sælgerpantebrev.'" />
			</xsl:call-template>
			
			<xsl:call-template name="linefeed" />
			
		</xsl:if>

	</xsl:template>
	
	<!-- ***********************************   HaeftelseIndeksregulering   ********************************** -->
	<xsl:template match="model:HaeftelseIndeksreguleringIndikator">
		<xsl:if test=".='true'">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Indeksregulering'" />
				<xsl:with-param name="text" select="'Lånet kan indeksreguleres.'" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>

	</xsl:template>
	
	<!-- ***********************************   HaeftelseVilkaarOpskrivning   ********************************** -->
	<xsl:template match="model:HaeftelseVilkaarOpskrivning">

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'OPSKRIVNINGSKLAUSUL'" />
		</xsl:call-template>
		
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Hovedstolen tilskrives rente.'" />
		</xsl:call-template>
		
		<xsl:call-template name="linefeed" />
		
		<xsl:if test="count(model:HaeftelseBeloebOpskrevet/model:BeloebVaerdi) > 0">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'OPSKREVEN HOVEDSTOL'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="format-number(floor(model:HaeftelseBeloebOpskrevet/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="model:HaeftelseBeloebOpskrevet/model:ValutaKode" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'OPSKRIVNINGSVILKÅR'" />
		</xsl:call-template>
		<xsl:apply-templates select="model:HaeftelseVilkaarSamling"/>

	</xsl:template>
	
	<!-- ***********************************   HaeftelseRetsforfoelgningsforbudIndikator   ********************************** -->
	<xsl:template match="model:HaeftelseRetsforfoelgningsforbudIndikator">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'RETSFORFØLGNINGSFORBUD'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test=".='true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette pantebrev kan ikke gøres til genstand for individuel retsforfølgning.'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette pantebrev kan gøres til genstand for individuel retsforfølgning.'" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   HaeftelseKlausulRektaIndikator   ********************************** -->
	<xsl:template match="model:HaeftelseKlausulRektaIndikator">

		<xsl:if test=".='true'">
		
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'REKTAKLAUSUL'"/>
			</xsl:call-template>

			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Dette pantebrev kan ikke overdrages til eje eller pant.'" />
			</xsl:call-template>

			<xsl:call-template name="linefeed" />
			
		</xsl:if>

	</xsl:template>
	
	<!-- ***********************************   HaeftelsePantebrevFormularLovpligtigKode   ********************************** -->
	<xsl:template match="model:HaeftelsePantebrevFormularLovpligtigKode">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'PANTEBREVSFORMULAR'"/>
			</xsl:call-template>
			<xsl:variable name="k" select="."/>
			<xsl:variable name="kode" select="$opslag//HaeftelsePantebrevFormularLovpligtigKode[@id = $k]"/>
  			<xsl:variable name="pfb" select="//snapshot:PantebrevFormularBetingelser"/>
			<xsl:if test="$pfb">
				<xsl:call-template name="VisFraser">
					<xsl:with-param name="node" select="$pfb"/>
					<xsl:with-param name="indent_1st_line" select="'off'"/>
					<xsl:with-param name="text">
						<xsl:choose>
							<xsl:when test="substring($kode,1,1) = 'A' and string-length($kode) > 1">
								<xsl:value-of select="concat('I øvrigt gælder Justitsministeriets almindelige betingelser ',$kode)" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="concat('I øvrigt gælder Justitsministeriets pantebrevsformular ',$kode)" />
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
	</xsl:template>
	
	<!-- ***********************************   HaeftelseSaerligLovgivning   ********************************** -->
	<xsl:template match="model:HaeftelseSaerligLovgivning">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'LÅN YDET I HENHOLD TIL FØLGENDE LOV'"/>
		</xsl:call-template>
		<xsl:variable name="lovtekst">
			<xsl:if test="model:LovNummerTekst">
					<xsl:value-of select="concat('Lov nr. ',string(model:LovNummerTekst))"/>
			</xsl:if>
			<xsl:if test="model:LovDato">
					<xsl:variable name="lovdato">
						<xsl:call-template name="formatdato_lang">
							<xsl:with-param name="dato" select="model:LovDato"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:value-of select="concat(' af ',string($lovdato))"/>
			</xsl:if>
			<xsl:if test="model:LovNavnTekst">
					<xsl:value-of select="concat(' om ',string(model:LovNavnTekst))"/>
			</xsl:if>
			<xsl:if test="model:LovParagrafNummer">
					<xsl:value-of select="concat(', ',string(model:LovParagrafNummer))"/>
			</xsl:if>
		</xsl:variable>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$lovtekst"/>
		</xsl:call-template>				
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ***********************************   HaeftelseLovOmKreditaftaler   ********************************** -->
	<xsl:template match="model:HaeftelseLovOmKreditaftaler">
		
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'KREDITAFTALELOV'"/>
		</xsl:call-template>
		
		<xsl:if test="model:HaeftelseOplysningspligtKode='ikkeOmfattet'">
			<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette pantebrev er ikke omfattet af loven om kreditaftaler.'" />
			</xsl:call-template>
		</xsl:if>
		
		<xsl:choose>
		
			<xsl:when test="./model:HaeftelseOplysningspligtKode='omfattetDetaljerUdleveretSeparat'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette pantebrev er omfattet af Kreditaftaleloven. Oplysninger i henhold til loven er udleveret separat.'" />
				</xsl:call-template>
			</xsl:when>
			
			<xsl:when test="./model:HaeftelseOplysningspligtKode='omfattetMedDetaljer'">
				
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Dette pantebrev er omfattet af Kreditaftaleloven. Kreditoplysninger i henhold til loven:'" />
				</xsl:call-template>
				
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Kreditomkostninger'" />
					<xsl:with-param name="text" select="format-number(floor(./model:HaeftelseKreditoplysninger/model:KreditOmkostninger/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
					<xsl:with-param name="text2" select="./model:HaeftelseKreditoplysninger/model:KreditOmkostninger/model:ValutaKode" />
				</xsl:call-template>
				
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Årlige omkostninger'" />
					<xsl:with-param name="text" select="format-number(./model:HaeftelseKreditoplysninger/model:AarligeOmkostningerProcent, $formatrente, 'currency-format')" />
					<xsl:with-param name="text2" select="'%'"/>
				</xsl:call-template>
				
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Andre omkostninger'" />
					<xsl:with-param name="text" select="format-number(floor(./model:HaeftelseKreditoplysninger/model:AndreOmkostninger/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
					<xsl:with-param name="text2" select="./model:HaeftelseKreditoplysninger/model:AndreOmkostninger/model:ValutaKode" />
				</xsl:call-template>
				
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Samlet beløb'" />
					<xsl:with-param name="text" select="format-number(floor(./model:HaeftelseKreditoplysninger/model:SamletBeloeb/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
					<xsl:with-param name="text2" select="./model:HaeftelseKreditoplysninger/model:SamletBeloeb/model:ValutaKode" />
				</xsl:call-template>
				
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Ydelser, disses beløb, forfaldstid og antal'" />
					<xsl:with-param name="text" select="'Antal ydelser:'" />
					<xsl:with-param name="text2" select="model:HaeftelseKreditoplysninger/model:AntalYdelser" />
				</xsl:call-template>
				
				<xsl:apply-templates select="model:HaeftelseKreditoplysninger/model:HaeftelseYdelseSamling"/>
				
			</xsl:when>
		</xsl:choose>
		
		<xsl:call-template name="linefeed" />

	</xsl:template>
	
	<!-- ***********************************   HaeftelseYdelseSamling   ********************************** -->
	<!-- *****************************   Bruges af HaeftelseLovOmKreditaftaler   ************************ -->
	<xsl:template match="model:HaeftelseYdelseSamling">

		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Nr. Forfaldsdato'" />
			<xsl:with-param name="text2" select="'Beløb'" />
		</xsl:call-template>
			
		<xsl:for-each select="model:HaeftelseYdelse">
		<xsl:sort select="model:HaeftelseForfaldDato"/>
			<xsl:variable name="dato">
				<xsl:call-template name="formatdato">
					<xsl:with-param name="dato" select="model:HaeftelseForfaldDato"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="concat('#',position(),' ',$dato,' :')" />
				<xsl:with-param name="text2" select="concat(format-number(floor(model:HaeftelseYdelseBeloeb/model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format'),' ',model:HaeftelseYdelseBeloeb/model:BeloebValuta/model:ValutaKode)" />
			</xsl:call-template>
		</xsl:for-each>
	
	</xsl:template>

	<!-- ***********************************   HaeftelseVilkaarRente   ********************************** -->
	<xsl:template match="model:HaeftelseVilkaarRente">
		<!-- choise either -->
		<xsl:apply-templates select="model:HaeftelseRente/model:HaeftelseRenteFast"/>
		<!-- or -->
		<xsl:apply-templates select="model:HaeftelseRente/model:HaeftelseRenteVariabel"/>
		<!-- end choise -->
		<xsl:apply-templates select="model:ForrentningTvangsauktionIndikator"/>
		<xsl:apply-templates select="model:ForrentningDato"/>
		<xsl:if test="count(model:HaeftelseVilkaarSamling/model:HaeftelseVilkaar) > 0">
			<xsl:apply-templates select="model:HaeftelseVilkaarSamling">
				<xsl:with-param name="Indent_first_line" select="'false'"/>
				<xsl:with-param name="text" select="'Øvrige rentevilkår'"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>

	<!-- ************************   ForrentningTvangsauktionIndikator   *************************** -->
	<xsl:template match="model:ForrentningTvangsauktionIndikator">
		<xsl:if test=". = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'I tilfælde af tvangsauktion over den/de pantsatte genstand/e forrentes ejerpantebrevet fra tidspunktet for tvangsauktion til betaling finder sted.'" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>
	
	
	<!-- ***********************************   HaeftelseRenteFast   ********************************** -->
	<xsl:template match="model:HaeftelseRenteFast">

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'FAST RENTE'" />
		</xsl:call-template>

		<!-- HaeftelseRentePaalydendeSats -->
		<xsl:if test="model:HaeftelseRentePaalydendeSats">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Pålydende årlig rente'" />
				<xsl:with-param name="text" select="format-number(model:HaeftelseRentePaalydendeSats, $formatrente, 'currency-format')" />
				<xsl:with-param name="text2" select="'%'" />
			</xsl:call-template>
		</xsl:if>
		
		<!-- HaeftelseRenteNominelSats -->
		<xsl:if test="model:HaeftelseRenteNominelSats">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Nominel årlig rente'" />
				<xsl:with-param name="text" select="format-number(model:HaeftelseRenteNominelSats, $formatrente, 'currency-format')" />
				<xsl:with-param name="text2" select="'%'" />
			</xsl:call-template>
		</xsl:if>

		<xsl:if test="model:HaeftelseRenteSatsForeloebigIndikator = 'true'">
			<xsl:call-template name="column2" >
				<xsl:with-param name="text" select="'Renten er foreløbig fastsat'" />
			</xsl:call-template>
		</xsl:if>

		<xsl:call-template name="linefeed" />

	</xsl:template>

	<!-- ***********************************   HaeftelseRenteVariabel   ********************************** -->
	<xsl:template match="model:HaeftelseRenteVariabel">

		<xsl:variable name="RenteTekst">
			<!-- HaeftelseRentePaalydendeSats-->
			<xsl:if test="model:HaeftelseRentePaalydendeSats">
				<xsl:variable name="Paalydende" select="format-number(model:HaeftelseRentePaalydendeSats, $formatrente, 'currency-format')" />
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Pålydende årlig rente'" />
					<xsl:with-param name="text" select="$Paalydende" />
					<xsl:with-param name="text2" select="'%'" />
				</xsl:call-template>
			</xsl:if>
	
			<!-- HaeftelseRenteNominelSats er optional-->
			<xsl:if test="model:HaeftelseRenteNominelSats">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Nominel årlig rente'" />
					<xsl:with-param name="text" select="format-number(model:HaeftelseRenteNominelSats, $formatrente, 'currency-format')" />
					<xsl:with-param name="text2" select="'%'" />
				</xsl:call-template>
			</xsl:if>
			<!-- MinimumRenteSats er optional -->
			<xsl:if test="model:AftaleOmRenteniveau/model:MinimumRenteSats != ''">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Minimum'" />
					<xsl:with-param name="text" select="format-number(model:AftaleOmRenteniveau/model:MinimumRenteSats, $formatrente, 'currency-format')" />
					<xsl:with-param name="text2" select="'%'" />
				</xsl:call-template>
			</xsl:if>
			<!-- MaksimumRenteSats er optional -->
			<xsl:if test="model:AftaleOmRenteniveau/model:MaksimumRenteSats != ''">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Maksimum'" />
					<xsl:with-param name="text" select="format-number(model:AftaleOmRenteniveau/model:MaksimumRenteSats, $formatrente, 'currency-format')" />
					<xsl:with-param name="text2" select="'%'" />
				</xsl:call-template>
			</xsl:if>

			<!-- HaeftelseReferenceRente er optional -->
			<xsl:if test="model:HaeftelseReferenceRente/model:ReferenceRenteNavn != ''">
				<xsl:variable name="referencerentenavn" select="model:HaeftelseReferenceRente/model:ReferenceRenteNavn" />
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Referencerente'" />
					<xsl:with-param name="text" select="$opslag//ReferenceRenteNavn[@id = $referencerentenavn]" />
				</xsl:call-template>
			</xsl:if>
	
			<!-- HaeftelseReferenceRente/ReferenceRenteSats er optional -->
			<xsl:if test="model:HaeftelseReferenceRente/model:ReferenceRenteSats != ''">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Den aktuelle referencerentesats'" />
					<xsl:with-param name="text" select="format-number(model:HaeftelseReferenceRente/model:ReferenceRenteSats, $formatrente, 'currency-format')" />
					<xsl:with-param name="text2" select="'%'" />
				</xsl:call-template>
			</xsl:if>
	
			<!-- HaeftelseReferenceRente/ReferenceRenteTillaegFradrag er optional -->
			<xsl:if test="model:HaeftelseReferenceRente/model:ReferenceRenteTillaegFradrag/model:TillaegFradragIndikator != ''">
				<xsl:choose>
					<xsl:when test="model:HaeftelseReferenceRente/model:ReferenceRenteTillaegFradrag/model:TillaegFradragIndikator='tillaeg'">
						<xsl:call-template name="two_columns_sub">
							<xsl:with-param name="prompt" select="'Tillæg'" />
							<xsl:with-param name="text" select="format-number(model:HaeftelseReferenceRente/model:ReferenceRenteTillaegFradrag/model:Procentsats, $formatrente, 'currency-format')" />
							<xsl:with-param name="text2" select="'%'" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="two_columns_sub">
							<xsl:with-param name="prompt" select="'Fradrag'" />
							<xsl:with-param name="text" select="format-number(model:HaeftelseReferenceRente/model:ReferenceRenteTillaegFradrag/model:Procentsats, $formatrente, 'currency-format')" />
							<xsl:with-param name="text2" select="'%'" />
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
	
				<!-- FastVariabelIndikator -->
				<xsl:choose>
					<xsl:when test="model:HaeftelseReferenceRente/model:ReferenceRenteTillaegFradrag/model:FastVariabelIndikator='fast'">
						<xsl:call-template name="column2">
							<xsl:with-param name="text" select="'Tillægget/fradraget er fast i hæftelsens løbetid.'" />
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="column2">
							<xsl:with-param name="text" select="'Tillægget/fradraget er variabelt.'" />
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
	
			</xsl:if>
		</xsl:variable>

		<xsl:if test="string-length($RenteTekst) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'VARIABEL RENTE'" />
			</xsl:call-template>
			<xsl:copy-of select="$RenteTekst"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>

	</xsl:template>

	<!--*********************************** model:ForrentningDato *************************************-->
	<xsl:template match="model:ForrentningDato">
		<xsl:variable name="date">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="."/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Rente beregnes fra'"/>
			<xsl:with-param name="text" select="$date"/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!-- ***********************************   HaeftelseVilkaarSamling   ********************************** -->
	<xsl:template match="model:HaeftelseVilkaarSamling">
	<xsl:param name="Indent_first_line" select="'true'"/>
	<xsl:param name="text"/>
		
		<xsl:choose>
			<xsl:when test="$Indent_first_line = 'true'">
				<xsl:for-each select="model:HaeftelseVilkaar">
					<xsl:call-template name="VisFraser">
						<xsl:with-param name="node" select="." />
					</xsl:call-template>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="./model:HaeftelseVilkaar">
					<xsl:choose>
						<xsl:when test="position()=1">
							<xsl:call-template name="VisFraser">
								<xsl:with-param name="node" select="." />
								<xsl:with-param name="indent_1st_line" select="'off'"/>
								<xsl:with-param name="text" select="$text"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="VisFraser">
								<xsl:with-param name="node" select="." />
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<!-- ***********************************   HaeftelseOprykningsretIndikator   ********************************** -->
	<xsl:template match="model:HaeftelseOprykningsretIndikator">

		<xsl:if test=". = 'true'">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'OPRYKNINGSRET'" />
		</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Dette dokument er med oprykningsret.'" />
			</xsl:call-template>
		</xsl:if>

		<xsl:call-template name="linefeed" />

	</xsl:template>

	<!-- ***********************************   HaeftelseSaerligBestemmelseSamling   ********************************** -->
	<xsl:template match="model:HaeftelseSaerligBestemmelseSamling">

		<xsl:if test="count(model:HaeftelseSaerligBestemmelse) > 0">
		
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'SÆRLIGE BESTEMMELSER'" />
			</xsl:call-template>
			
			<xsl:for-each select="model:HaeftelseSaerligBestemmelse">
				<xsl:call-template name="VisFraser">
					<xsl:with-param name="node" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			
		</xsl:if>

	</xsl:template>

	<!-- ***********************************   HaeftelseAndenTekstamling   ********************************** -->
	<xsl:template match="model:HaeftelseAndenTekstSamling">

		<xsl:if test="count(model:HaeftelseAndenTekst) > 0">
		
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'ØVRIGT'" />
			</xsl:call-template>
			
			<xsl:for-each select="model:HaeftelseAndenTekst">
				<xsl:call-template name="VisFraser">
					<xsl:with-param name="node" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			
		</xsl:if>

	</xsl:template>




	<!-- ***********************************   Saelgerpantebrev   ********************************** -->
	<xsl:template match="model:Saelgerpantebrev">

		<xsl:if test="node() = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Dette er et sælgerpantebrev.'" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>

	</xsl:template>
	
	<!-- ********************************* HaeftelseRefinansiering *********************************** -->
	
	<xsl:template match="model:HaeftelseRefinansiering">
		<xsl:if test="model:HaeftelseRefinansieringIndikator = 'aftalt'">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Refinansiering.'" />
				<xsl:with-param name="text" select="'Lån kan refinansieres på ændrede vilkår.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:HaeftelseRefinansieringIndikator = 'mulig'">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Refinansiering'" />
				<xsl:with-param name="text" select="'Mulighed for refinansiering af lån på ændrede vilkår efter aftale.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:RefinansieringsIntervalMaaneder != ''">
			<xsl:call-template name="month-year">
				<xsl:with-param name="column1_text" select="'Refinansieringsinterval'" />
				<xsl:with-param name="month" select="model:RefinansieringsIntervalMaaneder"/>
				<xsl:with-param name="indent" select="'true'"/>				
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:FoersteRefinansieringAarMaaned != ''">
			<xsl:call-template name="month-name-year">
				<xsl:with-param name="column1_text" select="'Tidspunkt for første refinansiering'" />
				<xsl:with-param name="yearmonth" select="substring(model:FoersteRefinansieringAarMaaned,1,7)" />
				<xsl:with-param name="indent" select="'true'"/>				
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!-- ******************************* HaeftelseLoebetid ********************************** -->
	<xsl:template match="model:HaeftelseLoebetid">
		<xsl:call-template name="HaeftelseLoebetid">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="HaeftelseLoebetid">
		<xsl:param name="node" />
		<xsl:param name="fastIndikatorTekst" select="'Løbetiden er fast.'" />

		<xsl:if test="count(*) > 0">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'LØBETID'"/>
			</xsl:call-template>
			
			<!-- Maksimal løbetid -->
			<xsl:if test="//model:HaeftelseMaksimalLoebetidMaaneder">
				<xsl:call-template name="month-year">
					<xsl:with-param name="column1_text" select="'Maksimal løbetid'"/>
					<xsl:with-param name="month" select="//model:HaeftelseMaksimalLoebetidMaaneder"/>
				</xsl:call-template>
			</xsl:if>
			
			<!-- Aftalt løbetid -->
			<xsl:if test="//model:HaeftelseLoebetidMaaneder">
				<xsl:call-template name="month-year">
					<xsl:with-param name="column1_text" select="'Aftalt løbetid'"/>
					<xsl:with-param name="month" select="//model:HaeftelseLoebetidMaaneder"/>
				</xsl:call-template>
			</xsl:if>
			
			<!-- fast eller variabel løbetid -->
			<xsl:choose>
				<xsl:when test="//model:FastVariabelIndikator = 'fast'">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="$fastIndikatorTekst"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="//model:FastVariabelIndikator = 'variabel'">
					<xsl:call-template name="column2">
						<xsl:with-param name="text" select="'Løbetiden er variabel.'"/>
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
			<!--QC3324 -->
			
			<!-- Pantebrevet forfalder til betaling -->
			<xsl:if test="model:HaeftelseForfaldDato">
				<xsl:variable name="ForfaldsDato">
					<xsl:call-template name="formatdato_lang">
						<xsl:with-param name="dato" select="model:HaeftelseForfaldDato"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Pantebrevet forfalder til betaling'"/>
					<xsl:with-param name="text" select="$ForfaldsDato"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="linefeed" />
		</xsl:if>
	
	</xsl:template>
	
	<!-- ********************************* HaeftelseVilkaarBetaling ******************************* -->
	
	<xsl:template match="model:HaeftelseVilkaarBetaling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'BETALINGSVILKÅR'"/>
		</xsl:call-template>
		
		<xsl:choose>
			<xsl:when test="model:HaeftelseTilbagebetalingsmaadeKode ='annuitetslaan'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Tilbagebetalingsmåde'" />
					<xsl:with-param name="text" select="'Annuitetslån.'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HaeftelseTilbagebetalingsmaadeKode ='serielaan'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Tilbagebetalingsmåde'" />
					<xsl:with-param name="text" select="'Serielån.'" />
				</xsl:call-template>					
			</xsl:when>
			<xsl:when test="model:HaeftelseTilbagebetalingsmaadeKode ='staaendeLaan'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Tilbagebetalingsmåde'" />
					<xsl:with-param name="text" select="'Stående lån.'" />
				</xsl:call-template>					
			</xsl:when>
			<xsl:when test="model:HaeftelseTilbagebetalingsmaadeKode ='oevrigeTilbagebetalingsvilkaar'">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Tilbagebetalingsmåde'" />
					<xsl:with-param name="text" select="'Øvrige tilbagebetalingsvilkår.'" />
				</xsl:call-template>					
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Tilbagebetalingsmåde'" />
					<xsl:with-param name="text" select="'Fejl: Ukendt tilbagebetalingsmåde.'" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:if test="model:HaeftelseAfdragsfrihed/model:HaeftelseAfdragsfrihedIndikator = 'aftalt'">
		
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Afdragsfrihed'"/>
				<xsl:with-param name="text" select="'Der er aftalt afdragsfrihed.'"/>
			</xsl:call-template>
			
			<xsl:apply-templates select="model:HaeftelseAfdragsfrihed/model:MaksimaltAntalMaaneder"/>
			
		</xsl:if>
		
		<xsl:if test="model:HaeftelseAfdragsfrihed/model:HaeftelseAfdragsfrihedIndikator = 'mulig'">
		
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Afdragsfrihed'"/>
				<xsl:with-param name="text" select="'Der er aftalt mulighed for afdragsfrihed.'"/>
			</xsl:call-template>
			
			<xsl:apply-templates select="model:HaeftelseAfdragsfrihed/model:MaksimaltAntalMaaneder"/>
			
		</xsl:if>
		
		<xsl:if test="count(model:HaeftelseBetalingTerminSamling/model:HaeftelseBetalingTermin)>0">
		
			<xsl:call-template name="column1">
				<xsl:with-param name="text" select="'Betalingstermin'"/>
			</xsl:call-template>
			<xsl:for-each select="model:HaeftelseBetalingTerminSamling/model:HaeftelseBetalingTermin">
				<xsl:sort select="model:HaeftelseForfaldTidspunkt" />
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			<xsl:call-template name="linefeed" />
			
		</xsl:if>
		 
		<xsl:apply-templates select="model:HaeftelseBetalingTerminFoerste"/>
		<xsl:apply-templates select="model:HaeftelseBetalingTerminSidste"/>
		<xsl:apply-templates select="model:HaeftelseFoersteBetalingDato"/>
		<xsl:call-template name="linefeed" />
		<xsl:if test="model:HaeftelseYdelsestype/model:YdelsestypeFast">
			<xsl:apply-templates select="model:HaeftelseYdelsestype/model:YdelsestypeFast"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:if test="model:HaeftelseYdelsestype/model:YdelsestypeVariabel">
			<xsl:apply-templates select="model:HaeftelseYdelsestype/model:YdelsestypeVariabel"/>
		</xsl:if>
		<xsl:if test="model:HaeftelseYdelseAarligtSamlet">
			<xsl:apply-templates select="model:HaeftelseYdelseAarligtSamlet"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:if test="model:HaeftelseBidrag">
			<xsl:apply-templates select="model:HaeftelseBidrag"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:if test="model:HaeftelseMorarente">
			<xsl:apply-templates select="model:HaeftelseMorarente"/>
		</xsl:if>
		
		<xsl:if test="count(model:HaeftelseVilkaarSamling/model:HaeftelseVilkaar)>0">
			<xsl:apply-templates select="model:HaeftelseVilkaarSamling">
				<xsl:with-param name="Indent_first_line" select="'false'"/>
				<xsl:with-param name="text" select="'Øvrige betalingsvilkår'" />
			</xsl:apply-templates>
		</xsl:if>
	
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<xsl:template match="model:MaksimaltAntalMaaneder">
		
		<xsl:call-template name="month-year">
			<xsl:with-param name="column1_text" select="'I maksimalt'"/>
			<xsl:with-param name="month" select="."/>
			<xsl:with-param name="indent" select="'true'"/>
		</xsl:call-template>
	
	</xsl:template>
	
	<xsl:template match="model:HaeftelseBetalingTermin">
		
		<xsl:call-template name="termin-write">
			<xsl:with-param name="pstart" select="model:HaeftelseBetalingPeriode/model:PeriodeStart"/>
			<xsl:with-param name="pend" select="model:HaeftelseBetalingPeriode/model:PeriodeSlut"/>
			<xsl:with-param name="pup" select="model:HaeftelseForfaldTidspunkt"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<xsl:template match="model:HaeftelseBetalingTerminFoerste">
		<xsl:variable name="HaeftelseForfaldDato">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseForfaldDato"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PeriodeStart">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseBetalingPeriodeDato/model:PeriodeStart"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PeriodeSlut">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseBetalingPeriodeDato/model:PeriodeSlut"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="two_columns_sub">
			<xsl:with-param name="prompt" select="'Første termin'"/>
			<xsl:with-param name="text" select="format-number(floor(model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="model:BeloebValuta/model:ValutaKode" />
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="concat('Perioden ', $PeriodeStart,' - ', $PeriodeSlut, ' forfalder ',$HaeftelseForfaldDato)" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:HaeftelseBetalingTerminSidste">
		<xsl:variable name="HaeftelseForfaldDato">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseForfaldDato"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PeriodeStart">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseBetalingPeriodeDato/model:PeriodeStart"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="PeriodeSlut">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="model:HaeftelseBetalingTerminDato/model:HaeftelseBetalingPeriodeDato/model:PeriodeSlut"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="two_columns_sub">
			<xsl:with-param name="prompt" select="'Sidste termin'"/>
			<xsl:with-param name="text" select="format-number(floor(model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="model:BeloebValuta/model:ValutaKode" />
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="concat('Perioden ', $PeriodeStart,' - ', $PeriodeSlut, ' forfalder ',$HaeftelseForfaldDato)" />
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="model:HaeftelseFoersteBetalingDato">
		<xsl:variable name="date">
			<xsl:call-template name="formatdato_lang">
				<xsl:with-param name="dato" select="."/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:call-template name="column1">
			<xsl:with-param name="text" select="'Dato for betaling af'"/>
		</xsl:call-template>
		<xsl:call-template name="two_columns_sub">
			<xsl:with-param name="prompt" select="'første ydelse'"/>
			<xsl:with-param name="text" select="$date"/>
		</xsl:call-template>
		
	</xsl:template>
		
	<xsl:template match="model:YdelsestypeFast">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Fast ydelse'"/>
		</xsl:call-template>
		
		<xsl:if test="model:BeloebValuta">
			<xsl:call-template name="two_columns_sub">
				<xsl:with-param name="prompt" select="'Beløb pr. termin'"/>
				<xsl:with-param name="text" select="format-number(floor(model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="model:BeloebValuta/model:ValutaKode" />
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="model:TerminProcentsats">
			<xsl:call-template name="two_columns_sub">
				<xsl:with-param name="prompt" select="'Procentsats af hovedstol pr. termin'"/>
				<xsl:with-param name="text" select="format-number(model:TerminProcentsats, $formatrente, 'currency-format')" />
				<xsl:with-param name="text2" select="'%'"/>
			</xsl:call-template>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="model:YdelsestypeVariabel">
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="model:YdelsestypeVariabelTekst" />
			<xsl:with-param name="indent_1st_line" select="'off'"/>
			<xsl:with-param name="text" select="'Variabel ydelse'" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:HaeftelseYdelseAarligtSamlet">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Årlig ydelse'"/>
			<xsl:with-param name="text" select="format-number(floor(model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="model:BeloebValuta/model:ValutaKode" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="model:HaeftelseBidrag">
	
		<xsl:call-template name="column1">
			<xsl:with-param name="text" select="'Bidrag'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="model:HaeftelseBidragGrundlag = 'obligationsrestgaeld'">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Obligationrestgæld'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HaeftelseBidragGrundlag = 'obligationshovedstol'">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Obligationshovedstol'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HaeftelseBidragGrundlag = 'laanerestgaeld'">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Lånerestgæld'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HaeftelseBidragGrundlag = 'hovedstol'">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Hovedstol'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HaeftelseBidragGrundlag = 'ydelse'">
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Ydelse'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="two_columns_sub">
					<xsl:with-param name="prompt" select="'Grundlag for beregning af bidragssatsen'"/>
					<xsl:with-param name="text" select="'Fejl: Ukendt grundlag.'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>

		<xsl:if test="model:HaeftelseBidragMinimum">
			<xsl:call-template name="two_columns_sub">
				<xsl:with-param name="prompt" select="'Minimumsbeløb'"/>
				<xsl:with-param name="text" select="format-number(floor(model:HaeftelseBidragMinimum/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="model:HaeftelseBidragMinimum/model:ValutaKode" />
			</xsl:call-template>
		</xsl:if>
		
		<xsl:call-template name="two_columns_sub">
			<xsl:with-param name="prompt" select="'Procentsats'"/>
			<xsl:with-param name="text" select="format-number(model:HaeftelseBidragSats, $formatrente, 'currency-format')" />
			<xsl:with-param name="text2" select="'%'"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<xsl:template match="model:HaeftelseMorarente">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Årlig morarente'"/>
			<xsl:with-param name="text" select="format-number(model:RenteSats, $formatrente, 'currency-format')" />
			<xsl:with-param name="text2" select="'%'"/>
		</xsl:call-template>
		<xsl:apply-templates select="model:MinimumBeloeb"/>
	</xsl:template>
	
	<xsl:template match="model:MinimumBeloeb">
		<xsl:call-template name="two_columns_sub">
			<xsl:with-param name="prompt" select="'Dog mindst'"/>
			<xsl:with-param name="text" select="format-number(floor(model:BeloebValuta/model:BeloebVaerdi), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="model:BeloebValuta/model:ValutaKode" />
		</xsl:call-template>
	</xsl:template>
		
<!-- *********************************** model:HaeftelseVilkaarOpsigelseSamling *************************** -->   
  <xsl:template match="model:HaeftelseVilkaarOpsigelseSamling">
    <xsl:call-template name="heading">
      <xsl:with-param name="text" select="'OPSIGELSESVILKÅR'"/>
    </xsl:call-template>
    
    <xsl:for-each select="model:HaeftelseVilkaar">
      <xsl:call-template name="VisFraser">
        <xsl:with-param name="node" select="." />
      </xsl:call-template>
    </xsl:for-each>
  </xsl:template>
		
<!-- *********************************** model:HaeftelseVilkaarOpsigelse ********************************** -->		
	<xsl:template match="model:HaeftelseVilkaarOpsigelse">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'OPSIGELSESVILKÅR'"/>
		</xsl:call-template>
		
		<xsl:if test="model:HaeftelseIndfrielseKonverterbar = 'nej'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Pantebrevet er inkonvertibel.'"/>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="model:HaeftelseIndfrielseKonverterbar = 'betinget'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Pantebrevet er konvertibelt med de betingelser, der er angivet i de øvrige opsigelsesvilkår.'"/>
			</xsl:call-template>
			<xsl:if test="model:HaeftelseIndfrielseKurs">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Indfrielseskurs'"/>
					<xsl:with-param name="text" select="format-number(model:HaeftelseIndfrielseKurs, $formatkurs, 'currency-format')"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		
		<xsl:if test="model:HaeftelseIndfrielseKonverterbar = 'ja'">
			<xsl:if test="model:HaeftelseIndfrielseKurs">
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Indfrielseskurs'"/>
					<xsl:with-param name="text" select="format-number(model:HaeftelseIndfrielseKurs, $formatkurs, 'currency-format')"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:apply-templates select="model:HaeftelseOpsigelseAntalMaaneder"/>
		</xsl:if>	
		
		<xsl:if test="count(model:HaeftelseVilkaarSamling/*) > 0">
			<xsl:apply-templates select="model:HaeftelseVilkaarSamling">
				<xsl:with-param name="Indent_first_line" select="'false'"/>
				<xsl:with-param name="text" select="'Øvrige opsigelsesvilkår'"/>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:call-template name="linefeed" />
		
	</xsl:template>
	
	<xsl:template match="model:HaeftelseOpsigelseAntalMaaneder">
		<xsl:if test=". = 0">
			<xsl:call-template name="two_columns_sub">
				<xsl:with-param name="prompt" select="'Debitors opsigelsesfrist'"/>
				<xsl:with-param name="text" select="'Uden varsel.'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test=". &gt; 0">
			<xsl:call-template name="month-year">
				<xsl:with-param name="column1_text" select="'Debitors opsigelsesfrist'"/>
				<xsl:with-param name="month" select="."/>
				<xsl:with-param name="indent" select="'true'"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="forhoejUnderpant">
		<xsl:param name="beloeb"/>
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'UNDERPANT'"/>
		</xsl:call-template>
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Underpantets beløb'"/>
			<xsl:with-param name="text" select="format-number(floor($beloeb), '###.###.###.###.##0', 'currency-format')"/>
			<xsl:with-param name="text2" select="'DKK'"/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>

			
</xsl:stylesheet>
