<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:bilbog="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
    xmlns:andelsbog="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
    xmlns:personbog="http://rep.oio.dk/tinglysning.dk/service/message/personbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Pantebrev.xslt 197178 2021-04-29 09:18:38Z cander28@dxc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

		
	<!--*********************************************************************************************************************-->
	<!--************************************ 7 - PantebrevFastEjendom ******************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:PantebrevFastEjendomOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseSaerligLovgivning"/>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:PantebrevFastEjendom/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	
	<xsl:template name="PantebrevFastEjendom">
		<xsl:param name="visType" select="'true'"/>
		<xsl:param name="node"/>
		
		<xsl:if test="$visType = 'true'">
			<xsl:variable name="haeftelsestypeid" select="$node/../eakt:HaeftelseType" />
			<xsl:call-template name="UdskrivHaeftelseType">
				<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
			</xsl:call-template>
		</xsl:if>

		<xsl:if test="count($node/model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count($node/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count($node/model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="$node/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="$node/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="$node/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="$node/model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="$node/model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="$node/model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseAndenTekstSamling"/>
		
	</xsl:template>
	
	<xsl:template match="model:PantebrevFastEjendom">
		<xsl:call-template name="PantebrevFastEjendom">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--************************************ 11 - EjerpantebrevFastEjendom *************************************-->
	<!--*********************************************************************************************************************-->

	<xsl:template match="msg:EjerpantebrevFastEjendomOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseBeloeb"/>
		<!-- Underpant -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:UnderpantIndikator"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseVilkaarRente"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseVilkaarOpsigelseSamling"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:EjerpantebrevFastEjendom/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	
	<xsl:template name="EjerpantebrevFastEjendom">
		<xsl:param name="visType" select="'true'"/>
		<xsl:param name="node"/>
		
		<xsl:if test="$visType = 'true'">
			<xsl:variable name="haeftelsestypeid" select="$node/../eakt:HaeftelseType" />
			<xsl:call-template name="UdskrivHaeftelseType">
				<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="$node/model:HaeftelseBeloeb"/>
		<xsl:if test="count($node/../model:UnderpantrettighedSamling) =0">
			<xsl:apply-templates select="$node/model:UnderpantIndikator"/>
		</xsl:if>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="$node/model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="$node/model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseAndenTekstSamling"/>
	</xsl:template>		
	
	<xsl:template match="model:EjerpantebrevFastEjendom">
		<xsl:call-template name="EjerpantebrevFastEjendom">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--*************************************** 23 - Realkreditpantebrev ******************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:RealkreditpantebrevOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseLaan"/>
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<!-- Særlig lovgivning -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseSaerligLovgivning"/>
		<!-- Ejendomme -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseRefinansiering"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse andentekst -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:Realkreditpantebrev/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:Realkreditpantebrev">
		<!--<xsl:variable name="haeftelsestypeid" select="../eakt:HaeftelseType" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
		<xsl:apply-templates select="model:HaeftelseLaan"/>
		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>-->

		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template name="HaeftelseStrukturHeader">
		<xsl:param name="node"/>
		
		
		<xsl:variable name="haeftelsestypeid" select="$node/eakt:HaeftelseType" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
		<xsl:apply-templates select="$node//model:HaeftelseLaan"/>
		<xsl:apply-templates select="$node//model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="$node//model:HaeftelseSaerligLovgivning"/>
        <xsl:call-template name="linefeed" />
	</xsl:template>
	
	
	
	<!--*********************************************************************************************************************-->
	<!--*************************************  24 - IndekspantebrevFastEjendom ********************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:IndekspantebrevFastEjendomOpret">
		
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseSaerligLovgivning"/>

		<!-- Ejendomme -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>	
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseBeloeb"/>
		<!-- IndeksReguleringsTekst -->
		<xsl:apply-templates select="//model:IndeksreguleringTekst"/>
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseRefinansiering"/>	
		<!-- Løbetid -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:IndekspantebrevFastEjendom/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template name="IndekspantebrevFastEjendom">
		<xsl:param name="visType" select="'true'"/>
		<xsl:param name="node"/>
		
		<xsl:if test="$visType = 'true'">
			<xsl:variable name="haeftelsestypeid" select="$node/../eakt:HaeftelseType" />
			<xsl:call-template name="UdskrivHaeftelseType">
				<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="count($node/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count($node/model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="$node/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="$node/model:IndeksreguleringTekst"/>
		<xsl:apply-templates select="$node/model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="$node/model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="$node/model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="$node/model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseAndenTekstSamling"/>
	</xsl:template>
	
	<xsl:template match="model:IndekspantebrevFastEjendom">
		<xsl:call-template name="IndekspantebrevFastEjendom">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>
	
	
	
	<!--*********************************************************************************************************************-->
	<!--************************************* 25 - SkadesloesbrevFastEjendom *********************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:SkadesloesbrevFastEjendomOpret | msg:SkadesloesbrevEjendomsskatOpret">
		
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
	
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseSaerligLovgivning"/>

		<!-- Ejendomme -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseBeloeb"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseOprykningsretIndikator"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:FuldmagtAnmeldtSamling"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:SkadesloesbrevFastEjendom/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template name="SkadesloesbrevFastEjendom">
		<xsl:param name="visType" select="'true'"/>
		<xsl:param name="node"/>
		
		<xsl:if test="$visType = 'true'">
			<xsl:variable name="haeftelsestypeid" select="$node/../eakt:HaeftelseType" />
			<xsl:call-template name="UdskrivHaeftelseType">
				<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
			</xsl:call-template>
		</xsl:if>

		<xsl:if test="count($node/model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="$node/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="$node/model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarSamling"/>
		<xsl:apply-templates select="$node/model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseAndenTekstSamling"/>
	</xsl:template>

	<xsl:template match="model:SkadesloesbrevFastEjendom">
		<xsl:call-template name="SkadesloesbrevFastEjendom">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>


	<!--********************************* UdskrivSkyldnerErklaering ****************************-->
	<xsl:template name="UdskrivSkyldnerErklaering">
        
        <xsl:variable name="ekspeditionstype_tingbog" select="msg:EkspeditionstypeIdentifikator" />
        <xsl:variable name="ekspeditionstype_bilbog" select="bilbog:EkspeditionstypeIdentifikator" />
        <xsl:variable name="ekspeditionstype_andelsbog" select="andelsbog:EkspeditionstypeIdentifikator" />
        <xsl:variable name="ekspeditionstype_personbog" select="personbog:EkspeditionstypeIdentifikator" />
        
        <xsl:if test="$ekspeditionstype_tingbog">
          <xsl:call-template name="OversaetOgUdskrivSkylnderErklaering">
            <xsl:with-param name="ekstype" select="$ekspeditionstype_tingbog" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$ekspeditionstype_bilbog">
          <xsl:call-template name="OversaetOgUdskrivSkylnderErklaering">
            <xsl:with-param name="ekstype" select="$ekspeditionstype_bilbog" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$ekspeditionstype_andelsbog">
          <xsl:call-template name="OversaetOgUdskrivSkylnderErklaering">
            <xsl:with-param name="ekstype" select="$ekspeditionstype_andelsbog" />
          </xsl:call-template>
        </xsl:if>
        <xsl:if test="$ekspeditionstype_personbog">
          <xsl:call-template name="OversaetOgUdskrivSkylnderErklaering">
            <xsl:with-param name="ekstype" select="$ekspeditionstype_personbog" />
          </xsl:call-template>
        </xsl:if>
        
		
	</xsl:template>
	
    <xsl:template name="OversaetOgUdskrivSkylnderErklaering">
      <xsl:param name="ekstype" />
      <xsl:variable name="tekst" select="$opslag//EkspeditionstypeLedetekst[@id=$ekstype]" />
      <xsl:if test="$tekst">
        <xsl:call-template name="column2">
          <xsl:with-param name="text" select="$tekst" />
        </xsl:call-template>
        <xsl:call-template name="linefeed" />
      </xsl:if>
    </xsl:template>
    
	<!--********************************* IndeksreguleringTekst ****************************-->
	<xsl:template match="model:IndeksreguleringTekst">
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="."/>
			<xsl:with-param name="indent_1st_line" select="'off'"/>
			<xsl:with-param name="text" select="'Indeksregulering'"/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!--********************************* UdskrivHaeftelseType ****************************-->
	<xsl:template name="UdskrivHaeftelseType">
		<xsl:param name="haeftelsestypeid"/>
		<xsl:if test="$haeftelsestypeid != ''">
			<xsl:variable name="haeftelsestype" select="$opslag//HaeftelseType[@id = $haeftelsestypeid]" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="translate($haeftelsestype,'abcdefghijklmnopqrstuvwxyzæøå','ABCDEFGHIJKLMNOPQRSTUVWXYZÆØÅ')"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!--********************************* UdskrivHaeftelseTypeMedEkstra ****************************-->
	<xsl:template name="UdskrivHaeftelseTypeMedEkstra">
      <xsl:param name="haeftelsestypeid" />
      <xsl:param name="ekstra" />
	  <xsl:if test="$haeftelsestypeid != ''">
		<xsl:variable name="haeftelsestype" select="$opslag//HaeftelseType[@id = $haeftelsestypeid]" />
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="$haeftelsestype"/>
			<xsl:with-param name="text" select="$ekstra" />
		</xsl:call-template>
	  </xsl:if>
	  <xsl:call-template name="divider" />
    </xsl:template>
	
</xsl:stylesheet>
