<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:dkcc-2="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/05/19/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:xkom-2="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:kms="http://rep.oio.dk/kms.dk/xml/schemas/2005/03/11/"
    xmlns:eamsg="http://rep.oio.dk/tinglysning.dk/service/message/elektroniskakt/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
	xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
	>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: PersonbogDokumentAktuelHent.xslt 144095 2018-11-23 14:38:03Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	
	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<!-- ***********************************   MAIN   ********************************** -->
	<xsl:template match="eamsg:PersonbogDokumentAktuelHentResultat">
		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'AKTUELT TINGLYST DOKUMENT'" />
		</xsl:call-template>
	
		<xsl:apply-templates select="eakt:DokumentAlias"/>

		<xsl:if test="not(eakt:LoesoereDokumentStruktur/model:Testamente)">
			<xsl:call-template name="LoesoereDokumentHeader">
				<xsl:with-param name="node" select="eakt:LoesoereDokumentStruktur"/>
			</xsl:call-template>
			
			<xsl:call-template name="TinglysningsDato">
				<xsl:with-param name="dato" select="model:TinglysningsDato"/>
				<xsl:with-param name="alias" select="eakt:DokumentAlias"/>
			</xsl:call-template>
		</xsl:if>
		
		<xsl:if test="eakt:LoesoereDokumentStruktur/model:Testamente">
			<xsl:apply-templates select="eakt:LoesoereDokumentStruktur/model:Testamente"/>
			
			<xsl:call-template name="TinglysningsDato">
				<xsl:with-param name="dato" select="model:TinglysningsDato"/>
				<xsl:with-param name="alias" select="eakt:DokumentAlias"/>
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:if test="eakt:LoesoereMedRettighederSamling/eakt:LoesoereMedRettigheder">
			<xsl:apply-templates select="eakt:LoesoereMedRettighederSamling"/>
		</xsl:if>

		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:LoesoereDokumentStruktur/eakt:LoesoereDokumentTypeTekst='hoestpantebrev' or eakt:LoesoereDokumentStruktur/eakt:LoesoereDokumentTypeTekst='privatPantebrev'">
						<xsl:value-of select="'yes'"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'no'"/>
					</xsl:otherwise> 
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>
		<xsl:apply-templates select="eakt:LoesoereDokumentStruktur"/>
		<xsl:apply-templates select="eakt:ElektroniskaktAnmeldelseInformation">
			<xsl:with-param name="gaeldsansvar">
				<xsl:choose>
					<xsl:when test="eakt:LoesoereDokumentStruktur/eakt:LoesoereDokumentTypeTekst='hoestpantebrev' or eakt:LoesoereDokumentStruktur/eakt:LoesoereDokumentTypeTekst='privatPantebrev'"><xsl:value-of select="'yes'"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="'no'"/></xsl:otherwise>
				</xsl:choose>
			</xsl:with-param>
		</xsl:apply-templates>
		<xsl:apply-templates select="eakt:AnmaerkningSamling"/>
		<xsl:apply-templates select="eakt:FristInformationSamling"/>
		<xsl:apply-templates select="eamsg:TillaegstekstSamling"/>
		<xsl:if test="eakt:TinglysningAfgiftOverfoerselIndikator = 'true'">
			<xsl:call-template name="linefeed" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TINGLYSNINGSAFGIFT OVERFØRSEL'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Der findes en erklæring om, at hæftelse alene indestår med henblik på overførsel af tinglysningsafgift'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="eakt:LoesoereAendringspaategningSamling"/>
		<xsl:apply-templates select="eakt:SenesteAnmeldelseSvar/anm:TinglysningspaategningElementSamling">
			<xsl:with-param name="vis_eksptype" select="'true'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	
	<xsl:template match="eakt:LoesoereDokumentStruktur">
		<xsl:apply-templates select="model:EjerpantebrevLoesoere"/>
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant"/>
		<xsl:apply-templates select="model:HoestPantebrev"/>
		<xsl:apply-templates select="model:PantebrevLoesoere"/>

		<xsl:call-template name="SkadesloesbrevLoesoereKrop">
		   <xsl:with-param name="node" select="model:SkadesloesbrevLoesoere"/>
		</xsl:call-template>
			
		<xsl:apply-templates select="model:TinglysningFormueforhold"/>
		<xsl:if test="model:UnderpantrettighedSamling">
			<xsl:call-template name="linefeed" />
			<xsl:apply-templates select="model:UnderpantrettighedSamling"/>
		</xsl:if>
		<!-- Respekter-->
	    <xsl:call-template name="UdskrivLoesoereHaeftelser">
	      <xsl:with-param name="Root" select="../eakt:LoesoereMedRettighederSamling"/>
	    </xsl:call-template>
	    <xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser">
	      <xsl:with-param name="Root" select="../eakt:LoesoereMedRettighederSamling"/>
    	</xsl:call-template>

	</xsl:template>
	
	<!-- ***********************************   LoesoereMedRettighederSamling   ********************************** -->	
	<xsl:template match="eakt:LoesoereMedRettighederSamling">
		<xsl:variable name="loesoeretekst">
			<xsl:call-template name="afgoerloesoeretekst">
				<xsl:with-param name="samling" select="."/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="$loesoeretekst" />
		</xsl:call-template>
		<xsl:for-each select="eakt:LoesoereMedRettigheder">
			<xsl:call-template name="VisLoesoere">
				<xsl:with-param name="node" select="."/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>	

</xsl:stylesheet>
