<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msgperson="http://rep.oio.dk/tinglysning.dk/service/message/personbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: PersonbogPantebrev.xslt 197024 2021-04-26 12:05:34Z lpallesen@dxc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

		
	<!--*********************************************************************************************************************-->
	<!--************************************ 9 - PantebrevLoesoere ******************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgperson:PantebrevLoesoereOpret">
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseSaerligLovgivning"/>
		<!-- Loesoere -->
		<xsl:apply-templates select="model:LoesoereSamling"/>
		<!-- PersonbogTekstSamling -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:PersonbogTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivLoesoereHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:PantebrevLoesoere/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:PantebrevLoesoere">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:LoesoereDokumentTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
	-->	
	
		<xsl:apply-templates select="model:PersonbogTekstSamling"/>
		<xsl:if test="count(model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count(model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
<!--		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>-->
		<xsl:apply-templates select="model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>
	</xsl:template>


	<!--*********************************************************************************************************************-->
	<!--************************************ 13 - EjerpantebrevLoesoere *************************************-->
	<!--*********************************************************************************************************************-->

	<xsl:template match="msgperson:EjerpantebrevLoesoereOpret">
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Loesoere -->
		<xsl:apply-templates select="model:LoesoereSamling"/>
		<!-- PersonbogTekstSamling -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:PersonbogTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseBeloeb"/>
		<!-- Underpant -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:UnderpantIndikator"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseVilkaarRente"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseVilkaarOpsigelseSamling"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivLoesoereHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:EjerpantebrevLoesoere/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template match="model:EjerpantebrevLoesoere">
<!--
		<xsl:variable name="haeftelsestypeid" select="../eakt:LoesoereDokumentTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="model:PersonbogTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:if test="count(../model:UnderpantrettighedSamling) =0">
			<xsl:apply-templates select="model:UnderpantIndikator"/>
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>
	</xsl:template>
	
	
	<!--*********************************************************************************************************************-->
	<!--***************************************** 27 - SkadesloesbrevLoesoere  ***************************************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msgperson:SkadesloesbrevLoesoereOpret">
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseSaerligLovgivning"/>
		<!-- Loesoere -->
		<xsl:apply-templates select="model:LoesoereSamling"/>
		<!-- PersonbogTekstSamling -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:PersonbogTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseBeloeb"/>
		<!-- Virksomhedspant -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:VirksomhedspantTypeTekstSamling"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:if test="not($doctypeid = '29') and not($doctypeid = '30')">
			<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		</xsl:if>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseOprykningsretIndikator"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:FuldmagtAnmeldtSamling"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivLoesoereHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:SkadesloesbrevLoesoere/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:SkadesloesbrevLoesoere">

		<!--xsl:variable name="haeftelsestypeid" select="../eakt:LoesoereDokumentTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template> -->
<!--
		<xsl:if test="count(model:PersonbogTekstSamling) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="model:VirksomhedspantTypeTekstSamling"/>
		<xsl:apply-templates select="model:FordringspantIndikator"/>
		<xsl:apply-templates select="model:PersonbogTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarSamling"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>
-->	
		<xsl:call-template name="SkadesloesbrevLoesoereKrop">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
	</xsl:template>

   <xsl:template name="SkadesloesbrevLoesoereKrop">
     <xsl:param name="node"/>
     <xsl:if test="count(model:PersonbogTekstSamling) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:apply-templates select="$node/model:VirksomhedspantTypeTekstSamling"/>
		<xsl:apply-templates select="$node/model:FordringspantIndikator"/>
		<xsl:apply-templates select="$node/model:PersonbogTekstSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="$node/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="$node/model:HaeftelseKlausulRektaIndikator"/>
		<!-- xsl:apply-templates select="$node/model:HaeftelseRetsforfoelgningsforbudIndikator"/ -->
		<xsl:apply-templates select="$node/model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="$node/model:HaeftelseVilkaarSamling"/>
		<xsl:apply-templates select="$node/model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelseAndenTekstSamling"/>
		<xsl:apply-templates select="$node/model:HaeftelsePantebrevFormularLovpligtigKode"/>
   </xsl:template>



	<!-- ***********************************   VirksomhedspantTypeTekstSamling   ********************************** -->
	<xsl:template match="model:VirksomhedspantTypeTekstSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'VIRKSOMHEDSPANT'"/>
		</xsl:call-template>
		<xsl:for-each select="model:VirksomhedspantTypeTekst">
			<xsl:variable name="virksomhedspant" select="." />		
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//VirksomhedspantTypeTekst[@id = $virksomhedspant]" />
			</xsl:call-template>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!-- ***********************************   FordringspantIndikator   ********************************** -->
	<xsl:template match="model:FordringspantIndikator">
		<xsl:if test=".='true'">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FORDRINGSPANT'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>





	<!--*********************************************************************************************************************-->
	<!--************************************ 31 - HoestPantebrev ******************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgperson:HoestpantebrevOpret">
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Kreditorbetegnelse -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseLaanKreditorbetegnelseTekst"/>
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseSaerligLovgivning"/>
		<!-- Loesoere -->
		<xsl:apply-templates select="model:LoesoereSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
			<xsl:with-param name="gaeldsansvar" select="'yes'" />
		</xsl:apply-templates>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseRefinansiering"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Løbetid -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseLoebetid"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseVilkaarRente"/>
		<!-- Betalingsvilkår -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseVilkaarBetaling"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseVilkaarOpsigelse"/>
		<!-- Pantsætning -->
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'PANTSÆTNING AF'"/>
		</xsl:call-template>
		<xsl:for-each select="model:HoestPantebrev/model:HoestPantebrevObjektSamling/model:HoestPantebrevObjekt">
			<xsl:variable name="pantret" select="./model:HoestPantebrevTypeTekst" />	
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//HoestPantebrevTypeTekst[@id = $pantret]" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="./model:TekstAngivelse"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
		<!-- Pantret -->
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'PANTRET'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="model:HoestPantebrev/model:ForaarEfteraarIndikatorTekst = 'foraar'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Forår: høstpantebrevet vedrører beplantning fra 1.januar til 31.juli'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:HoestPantebrev/model:ForaarEfteraarIndikatorTekst = 'efteraar'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Efterår: høstpantebrevet vedrører beplantning fra 1.august til 31.december'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Hele året: høstpantebrevet vedrører beplantning fra 1.august til 31.juli'" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
		<!-- Ejendomme -->
		<xsl:if test="model:HoestPantebrev/model:HoestEjendomIdentifikatorSamling">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'EJENDOM'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:HoestPantebrev/model:HoestEjendomIdentifikatorSamling"/>
		</xsl:if>
		<!-- Rektaklausul -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseKlausulRektaIndikator"/>
		<!-- Retsforfølgningsforbud -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivLoesoereHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:HoestPantebrev/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Kreditaftalelov -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseLovOmKreditaftaler"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:HoestPantebrev/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<xsl:template match="model:HoestPantebrev">
<!--
		<xsl:variable name="haeftelsestypeid" select="../eakt:LoesoereDokumentTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->
		<xsl:if test="count(model:HaeftelseLaanKreditorbetegnelseTekst) = 0 and count(model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev) = 0  and count(model:HaeftelseSaerligLovgivning) = 0">
			<xsl:call-template name="linefeed" />
		</xsl:if>
<!--
		<xsl:apply-templates select="model:HaeftelseLaanKreditorbetegnelseTekst"/>
	-->	
		<xsl:apply-templates select="model:HaeftelseSaelgerpantebrevIndikator/model:Saelgerpantebrev"/>
		
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:apply-templates select="model:HaeftelseIndeksreguleringIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRefinansiering"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseLoebetid"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarBetaling"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<!-- Pantsætning -->
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'PANTSÆTNING AF'"/>
		</xsl:call-template>
		<xsl:for-each select="model:HoestPantebrevObjektSamling/model:HoestPantebrevObjekt">
			<xsl:variable name="pantret" select="./model:HoestPantebrevTypeTekst" />	
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//HoestPantebrevTypeTekst[@id = $pantret]" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="./model:TekstAngivelse"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
		<!-- Pantret -->
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'PANTRET'"/>
		</xsl:call-template>
		<xsl:choose>
			<xsl:when test="model:ForaarEfteraarIndikatorTekst = 'foraar'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Forår: høstpantebrevet vedrører beplantning fra 1.januar til 31.juli'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="model:ForaarEfteraarIndikatorTekst = 'efteraar'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Efterår: høstpantebrevet vedrører beplantning fra 1.august til 31.december'" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Hele året: høstpantebrevet vedrører beplantning fra 1.august til 31.juli'" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="linefeed" />
		<!-- Ejendomme -->
		<xsl:if test="model:HoestEjendomIdentifikatorSamling">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'EJENDOM'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:HoestEjendomIdentifikatorSamling"/>
		</xsl:if>

		<xsl:apply-templates select="model:HaeftelseKlausulRektaIndikator"/>
		<xsl:apply-templates select="model:HaeftelseRetsforfoelgningsforbudIndikator"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseLovOmKreditaftaler"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>
	</xsl:template>

	<!-- ***********************************   HoestEjendomIdentifikatorSamling   ********************************** -->
    <xsl:template match="model:HoestEjendomIdentifikatorSamling">
        <xsl:for-each select="model:HoestEjendomIdentifikator">
			<xsl:apply-templates select="model:EjendomIdentifikator"/>
			<xsl:if test="model:ForpagtetIndikator='true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Ejendommen er forpagtet'" />
				</xsl:call-template>
			</xsl:if>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
    </xsl:template>	
 
	<!--*********************************************************************************************************************-->
	<!--************************************ 243 - Ejerpantebrev virksomhedspant *************************************-->
	<!--*********************************************************************************************************************-->

	<xsl:template match="msgperson:EjerpantebrevVirksomhedspantOpret">
		<xsl:variable name="doctypeid" select="msgperson:EkspeditionstypeIdentifikator" />
		<!-- Overskrift og prøvetinglysning -->
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseSaerligLovgivning"/>
		<!-- Loesoere -->
		<xsl:apply-templates select="model:LoesoereSamling"/>
		<!-- PersonbogTekstSamling -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:PersonbogTekstSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>
		<!-- Hovedstol -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseBeloeb"/>
		<!-- Virksomhedspant -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:VirksomhedspantTypeTekstSamling"/>
		<!-- Underpant -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:UnderpantIndikator"/>
		<!-- Opskrivningsklausul -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseVilkaarOpskrivning"/>
		<!-- Fast eller variabel rente -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseVilkaarRente"/>
		<!-- Opsigelsesvilkår -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseVilkaarOpsigelseSamling"/>
		<!-- Oprykningsret -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseOprykningsretIndikator"/>
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivLoesoereHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeLoesoereHaeftelser"/>
		<!-- Fuldmagtsbestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:FuldmagtAnmeldtSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Særlige bestemmelser -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseSaerligBestemmelseSamling"/>
		<!-- Hæftelse anden tekst -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelseAndenTekstSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Pantebrevsformular -->
		<xsl:apply-templates select="model:EjerpantebrevVirksomhedspant/model:HaeftelsePantebrevFormularLovpligtigKode"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<!--*********************************************************************************************************************-->
	<xsl:template match="model:EjerpantebrevVirksomhedspant">
<!--	
		<xsl:variable name="haeftelsestypeid" select="../eakt:LoesoereDokumentTypeTekst" />
		<xsl:call-template name="UdskrivHaeftelseType">
			<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
		</xsl:call-template>
-->		
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="model:VirksomhedspantTypeTekstSamling"/>
		<xsl:apply-templates select="model:PersonbogTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligLovgivning"/>
		<xsl:apply-templates select="model:HaeftelseBeloeb"/>
		<xsl:if test="count(../model:UnderpantrettighedSamling) =0">
			<xsl:apply-templates select="model:UnderpantIndikator"/>
		</xsl:if>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpskrivning"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarRente"/>
		<xsl:apply-templates select="model:HaeftelseVilkaarOpsigelse"/>
		<xsl:apply-templates select="model:HaeftelseOprykningsretIndikator"/>
		<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>
		<xsl:apply-templates select="model:HaeftelseSaerligBestemmelseSamling"/>
		<xsl:apply-templates select="model:HaeftelseAndenTekstSamling"/>
		<xsl:apply-templates select="model:HaeftelsePantebrevFormularLovpligtigKode"/>
	</xsl:template>

	<xsl:template name="LoesoereDokumentHeader">
		<xsl:param name="node"/>

		<xsl:variable name="haeftelsestypeid" select="$node/eakt:LoesoereDokumentTypeTekst" />
		<xsl:choose>
			<xsl:when test="$node/model:TinglysningFormueforhold/model:Formueordning">
				<xsl:variable name="formueordning" select="$node/model:TinglysningFormueforhold/model:Formueordning" />
				<xsl:variable name="ekstra" select="$opslag//FormueordningTekst[@id = $formueordning]" />
				<xsl:call-template name="UdskrivHaeftelseTypeMedEkstra">
					<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
					<xsl:with-param name="ekstra" select="$ekstra" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>		
				<xsl:call-template name="UdskrivHaeftelseType">
					<xsl:with-param name="haeftelsestypeid" select="$haeftelsestypeid" />
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
<!--		<xsl:apply-templates select="$node//model:HaeftelseLaan"/> findes kun i realkreditpantebrev--> 
		<xsl:apply-templates select="$node//model:HaeftelseLaanKreditorbetegnelseTekst"/>
<!--		<xsl:apply-templates select="$node//model:HaeftelseSaerligLovgivning"/>-->
		<xsl:for-each select="$node//model:PantsaetningsforbudTypeTekstSamling/model:PantsaetningsforbudTypeTekst">
			<xsl:variable name="MeddelelseType" select="."/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//PantsaetningsforbudTypeTekst[@id = $MeddelelseType]"/> 
			</xsl:call-template>			
		</xsl:for-each>		
        <xsl:call-template name="linefeed" />
	</xsl:template>

 
</xsl:stylesheet>
