<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/" 
	xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/" 
	xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/" 
	xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
	xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Servitut.xslt 111770 2017-01-25 14:16:18Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle XSLT templates vedrørende Servitutter -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>
	
	<xsl:key name="DokumentIdentifikator" match="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur" use="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator"/>
	
	<!--*********************************************************************************************************************-->
	<!--************************************************** 50 - ServitutOpret *********************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:ServitutOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator"/>
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]"/>
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator"/>
		</xsl:call-template>
		<!-- FastEjendomSamling -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		
		<!-- AnmeldelseInformation -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmeldereInformation"/>
		<xsl:call-template name="linefeed" />
		
		<!-- ServitutInformation -->
		<xsl:apply-templates select="model:ServitutInformation"/>
		
		<!-- ServitutTekst -->
		<xsl:apply-templates select="model:ServitutTekstSamling"/>
		
		<xsl:call-template name="VisServitutInformationForrang">
			<xsl:with-param name="node" select="model:ServitutInformation"/>
			<xsl:with-param name="overskrift" select="'OPLYSNINGER OM SERVITUTTEN'"/>
		</xsl:call-template>
		
		<!-- Servitut Tidsbegrænsning -->
		<xsl:apply-templates select="model:ServitutInformation/model:Tidsbegraensning">
			<xsl:with-param name="overskrift" select="'TIDSBEGRÆNSNING'"/>
		</xsl:apply-templates>
		
		<xsl:if test="//model:BilagReference/model:BilagReferenceKode='38'">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'STEDFÆSTET'"/>
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Servitutten kan være helt eller delvist stedfæstet.'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
		<!-- Respekter: Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:if test="not(model:ServitutInformation/model:ServitutKanTinglysesMedPrioritetForudForGaeldOgServitutterIndikator) or model:ServitutInformation/model:ServitutKanTinglysesMedPrioritetForudForGaeldOgServitutterIndikator != 'true' ">
			<xsl:call-template name="UdskrivHaeftelser"/>
			<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
			<xsl:call-template name="UdskrivServitutter"/>
		</xsl:if>

		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	
	<!--*********************************************************************************************************************-->
	<!--******************************************** 182 - ServitutErklæring *********************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:ServitutErklaeringOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator"/>
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]"/>
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator"/>
		</xsl:call-template>
		
		<xsl:for-each select="model:ServitutErklaering/model:ServitutStedfaestelseSamling/model:ServitutStedfaestelseStruktur">
			<xsl:variable name="alias">
			<xsl:variable name="doc_id" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator"/>
			<xsl:if test="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $doc_id]/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator">
				<xsl:variable name="Identifikator" select="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $doc_id]/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator"/>
				<xsl:value-of select="concat(substring($Identifikator,7,2),'.',substring($Identifikator,5,2),'.',substring($Identifikator,1,4),substring($Identifikator, 9))"/>
			</xsl:if>
			<xsl:if test="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $doc_id]/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator">
				<xsl:variable name="hIdentifikator" select="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $doc_id]/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator"/>
				<xsl:value-of select="concat(substring($hIdentifikator,7,2),'.',substring($hIdentifikator,5,2),'.',substring($hIdentifikator,1,4),substring($hIdentifikator, 9))"/>
			</xsl:if> 
			</xsl:variable>

			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="concat('EJENDOM HVOR ',$alias,' NU ER TINGLYST')"/>
			</xsl:call-template>
			<xsl:apply-templates select="//model:ServitutErklaering/model:EjendomIdentifikator"/>
			<xsl:call-template name="linefeed" />
			
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="concat('EJENDOM HVOR ',$alias,' FREMOVER SKAL VÆRE TINGLYST')"/>
			</xsl:call-template>

			<xsl:for-each select="model:FastEjendomSamling/model:FastEjendom">
				<xsl:apply-templates select="model:EjendomIdentifikator"/>
				<xsl:call-template name="linefeed" />
			</xsl:for-each>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
		<xsl:call-template name="linefeed" />
			

		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="linefeed" />
		
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling"/>
		
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			  <xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>
	

	<!--*********************************************************************************************************************-->
	<!--****************************************** ServitutKombinationPaategn *****************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:ServitutKombinationPaategn">
	
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<xsl:variable name="doc_id" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
		<xsl:call-template name="dokument_som_paategnes">
			<xsl:with-param name="doc_id" select="$doc_id" />
		</xsl:call-template>

		<!-- Udskriv de enkelte påtegninger  -->
		<xsl:for-each select="node()">
		    <!-- Namespace fjernes inden sammenligning med nodenavn -->
		    <xsl:choose>
				<xsl:when test="starts-with( substring-after( string(name()), ':' ), 'Ekspeditionstype') != ''">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="starts-with(string(name()), 'Ekspeditionstype')">
						<xsl:apply-templates select="."/>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>

		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<!-- Rollesamling -->
		<xsl:apply-templates select="//anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>

		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>


	<!--*****************************************************************************************************************-->
	<!--******************************  104 - RespektServitutFastEjendom  ***************************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypeRespektServitutFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="text2" select="$opslag//PaategningHjaelpetekst[@id = $doctypeid]" />
		</xsl:call-template>
		
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivServitutter">
			<xsl:with-param name="Root" select="model:RespektFastEjendomSamling"/>
		</xsl:call-template>
	</xsl:template>


	<!--*****************************************************************************************************************-->
	<!--****************** 105 - EkspeditionstypeNyPaataleberettigetFastEjendom *****************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypeNyPaataleberettigetFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="model:EkspeditionstypeIdentifikator"/>
		</xsl:call-template>
	</xsl:template>

	
	<!--*****************************************************************************************************************-->
	<!--**********************************************  106 - PaategnServitut  ***************************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypePaategningServitutFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="model:EkspeditionstypeIdentifikator"/>
		</xsl:call-template>

		<!-- ServitutInformation -->
		<xsl:apply-templates select="model:ServitutInformation"/>
		<!-- ServitutTekst -->
		<xsl:apply-templates select="model:ServitutTekstSamling"/>
		<!-- Servitut Tidsbegrænsning -->
		<xsl:apply-templates select="model:ServitutInformation/model:Tidsbegraensning">
			<xsl:with-param name="overskrift" select="'TIDSBEGRÆNSNING'"/>
		</xsl:apply-templates>
	</xsl:template>
	
	
	<!--*****************************************************************************************************************-->
	<!--****************************  107 - RelaksationServitutFastEjendom  *************************************-->
	<!--*****************************************************************************************************************-->
	<xsl:template match="model:EkspeditionstypeRelaksationServitutFastEjendom">
		<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		
		<xsl:call-template name="ledetekst">
			<xsl:with-param name="doctypeid" select="model:EkspeditionstypeIdentifikator"/>
		</xsl:call-template>
		
		<!-- Udskriver evt. ejendomme -->
		<xsl:variable name="Ejendomme">
			<xsl:for-each select="model:RelaksationFastEjendomSamling/model:RelaksationFastEjendom">
				<xsl:apply-templates select="model:EjendomIdentifikator"/>
				<xsl:if test="model:BetingelserTekst">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Betingelser'"/>
						<xsl:with-param name="text" select="model:BetingelserTekst"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="model:BetingelseTekstAngivelse">
					<xsl:call-template name="VisFraser">
						<xsl:with-param name="node" select="model:BetingelseTekstAngivelse"/>
						<xsl:with-param name="indent_1st_line" select="'off'"/>
						<xsl:with-param name="text" select="'Betingelser'"/>
					</xsl:call-template>		
				</xsl:if>
				<xsl:call-template name="linefeed" />
			</xsl:for-each>
		</xsl:variable>
		<xsl:if test="$Ejendomme">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'EJENDOM'"/>
			</xsl:call-template>
			<xsl:copy-of select="$Ejendomme"/>
		</xsl:if>

	</xsl:template>

	<!--********************************************** ServitutInformation ************************************************-->
	<xsl:template match="model:ServitutInformation">
		<xsl:if test="model:ServitutAfsnitKoebSalg">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'KØB/SALG'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitKoebSalg"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitAnvendelse">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'AREALANVENDELSE'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitAnvendelse"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitBebyggelse">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'BEBYGGELSE'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitBebyggelse"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitEjendomsforhold">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'EJENDOMSFORHOLD'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitEjendomsforhold"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitTekniskeAnlaeg">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'TEKNISKE ANLÆG'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitTekniskeAnlaeg"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitLedninger">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'LEDNINGER'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitLedninger"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitFaerdsel">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FÆRDSEL'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitFaerdsel"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitForsyning">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FORSYNINGSPLIGT'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitForsyning"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitBrugsLejeForhold">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'BRUGSRET'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitBrugsLejeForhold"/>
		</xsl:if>
		<xsl:if test="model:ServitutAfsnitAndet">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'ANDET'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutAfsnitAndet"/>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<xsl:if test="model:ServitutFortrinsret">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'SERVITUT FORTRINSRET'"/>
			</xsl:call-template>
			<xsl:apply-templates select="model:ServitutFortrinsret"/>
		</xsl:if>
	</xsl:template>

	<!--*************************************** ServitutTekstSamling ************************************************-->
	<xsl:template match="model:ServitutTekstSamling">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'SERVITUT TEKST'"/>
		</xsl:call-template>
		<xsl:for-each select="model:ServitutTekst">
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutTekst ************************************************-->
	<xsl:template match="model:ServitutTekst">
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="."/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	<!--********************************************** ServitutInformation forrang ************************************************-->
	<xsl:template name="VisServitutInformationForrang">
		<xsl:param name="node" />
		<xsl:param name="overskrift" />
		
		<xsl:if test="$node !=''">
			<xsl:if test="$node/model:ServitutKanTinglysesUdenEjersTiltraedelseIndikator = 'true' or 
						  $node/model:ServitutKanTinglysesMedPrioritetForudForGaeldOgServitutterIndikator = 'true' or
						  $node/model:ServitutHarBetydningForEjendommensVaerdiIndikator = 'true'">
				<xsl:call-template name="heading">
					<xsl:with-param name="text" select="$overskrift"/>
				</xsl:call-template>
	        </xsl:if>
			
			<xsl:if test="$node/model:ServitutKanTinglysesUdenEjersTiltraedelseIndikator = 'true' ">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Servitutten kan tinglyses uden ejers tiltrædelse.'" />
				</xsl:call-template>
				<xsl:call-template name="linefeed" />
			</xsl:if>
			<xsl:if test="$node/model:ServitutKanTinglysesMedPrioritetForudForGaeldOgServitutterIndikator = 'true' ">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Servitutten kan tinglyses med prioritet forud for anden gæld og servitutter.'" />
				</xsl:call-template>
				<xsl:call-template name="linefeed" />
			</xsl:if>
			<xsl:if test="$node/model:ServitutHarBetydningForEjendommensVaerdiIndikator = 'true' ">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Servitutten har betydning for ejendommens værdi.'" />
				</xsl:call-template>
				<xsl:call-template name="linefeed" />
			</xsl:if>
			<xsl:if test="$node/model:ServitutKanTinglysesUdenEjersTiltraedelseIndikator = 'true' or 
						  $node/model:ServitutKanTinglysesMedPrioritetForudForGaeldOgServitutterIndikator = 'true'">
				<xsl:if test="$node/model:FritekstInformationTekst  != ''">
					<xsl:call-template name="heading">
						<xsl:with-param name="text" select="'HJEMMEL'"/>
					</xsl:call-template>
					<xsl:call-template name="column2">
					  <xsl:with-param name="text" select="$node/model:FritekstInformationTekst" />
					</xsl:call-template>
					<xsl:call-template name="linefeed" />
				</xsl:if>
	        </xsl:if>
        </xsl:if>
    </xsl:template>

	<!--********************************************** Tidsbegraensning ************************************************-->
	<xsl:template match="model:Tidsbegraensning">
		<xsl:value-of select="current()"/>
		<xsl:call-template name="linefeed" />
	</xsl:template>

	<!--********************************************** ServitutErklaering ************************************************-->
	<xsl:template match="model:ServitutErklaering">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'EJENDOM'"/>
		</xsl:call-template>
		<xsl:variable name="ejend_id" select="model:EjendomIdentifikator"/>
		<xsl:apply-templates select="model:FastEjendomSamling/model:FastEjendom[model:EjendomIdentifikator=$ejend_id]"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'ERKLÆRING'"/>
		</xsl:call-template>
		<xsl:variable name="dok_id" select="model:DokumentRevisionIdentifikator"/>
		<xsl:call-template name="DokumentStruktur_Servitut">
			<xsl:with-param name="dokumentStruktur" select="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator=$dok_id]"/>
		</xsl:call-template>
	</xsl:template>

	<!--********************************************** ServitutAfsnitKoebSalg ************************************************-->
	<xsl:template match="model:ServitutAfsnitKoebSalg">
		<xsl:for-each select="model:ServitutIndholdKoebSalg">
			<xsl:variable name="test_var" select="model:ServitutIndholdKoebSalgKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitAnvendelse ************************************************-->
	<xsl:template match="model:ServitutAfsnitAnvendelse">
		<xsl:for-each select="model:ServitutIndholdAnvendelse">
			<xsl:variable name="test_var" select="model:ServitutIndholdAnvendelseKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
		<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitBebyggelse ************************************************-->
	<xsl:template match="model:ServitutAfsnitBebyggelse">
		<xsl:for-each select="model:ServitutIndholdBebyggelse">
			<xsl:variable name="test_var" select="model:ServitutIndholdBebyggelseKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitEjendomsforhold ************************************************-->
	<xsl:template match="model:ServitutAfsnitEjendomsforhold">
		<xsl:for-each select="model:ServitutIndholdEjendomsforhold">
			<xsl:variable name="test_var" select="model:ServitutIndholdEjendomsforholdKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitTekniskeAnlaeg ************************************************-->
	<xsl:template match="model:ServitutAfsnitTekniskeAnlaeg">
		<xsl:for-each select="model:ServitutIndholdTekniskeAnlaeg">
			<xsl:variable name="test_var" select="model:ServitutIndholdTekniskeAnlaegKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitLedninger ************************************************-->
	<xsl:template match="model:ServitutAfsnitLedninger">
		<xsl:for-each select="model:ServitutIndholdLedninger">
			<xsl:variable name="test_var" select="model:ServitutIndholdLedningerKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitFaerdsel ************************************************-->
	<xsl:template match="model:ServitutAfsnitFaerdsel">
		<xsl:for-each select="model:ServitutIndholdFaerdsel">
			<xsl:variable name="test_var" select="model:ServitutIndholdFaerdselKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitForsyning ************************************************-->
	<xsl:template match="model:ServitutAfsnitForsyning">
		<xsl:for-each select="model:ServitutIndholdForsyning">
			<xsl:variable name="test_var" select="model:ServitutIndholdForsyningKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitBrugsLejeForhold ************************************************-->
	<xsl:template match="model:ServitutAfsnitBrugsLejeForhold">
		<xsl:for-each select="model:ServitutIndholdBrugsLejeForhold">
			<xsl:variable name="test_var" select="model:ServitutIndholdBrugsLejeForholdKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutAfsnitAndet ************************************************-->
	<xsl:template match="model:ServitutAfsnitAndet">
		<xsl:for-each select="model:ServitutIndholdAndet">
			<xsl:variable name="test_var" select="model:ServitutIndholdAndetKode"/>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//ServitutIndholdKode[@id = $test_var]"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:for-each>
	</xsl:template>

	<!--********************************************** ServitutFortrinsret ************************************************-->
	<xsl:template match="model:ServitutFortrinsret">
		<xsl:choose>
			<xsl:when test="model:FortrinsretIndikator='true'">
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Servitutten kan tillægges prioritetsstilling forud for allerede tinglyste rettigheder i henhold til den angivne lovhjemmel.'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="column2">
					<xsl:with-param name="text" select="'Servitutten kan ikke tillægges prioritetsstilling forud for allerede tinglyste rettigheder i henhold til den angivne lovhjemmel.'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="model:FortrinsretTekst">
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:FortrinsretTekst" />
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />
	</xsl:template>

</xsl:stylesheet>
