<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: ServitutOevrigeOpret.xslt 111139 2017-01-17 13:58:55Z lpallesen@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>


	<!--*********************************************************************************************************************-->
	<!--**************************************** ServitutOevrigeOpret for ekspeditionstype 40, 41, 46, 47, 48****************-->
	<!--*********************************************************************************************************************-->
	
	<xsl:template match="msg:ServitutOevrigeOpret">
	
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<!-- FastEjendomSamling -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		
		<!-- AnmeldelseInformation -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmeldereInformation"/>
		<xsl:call-template name="linefeed" />
		
		<xsl:apply-templates select="model:ServitutTekstSamling"/>
		<xsl:call-template name="linefeed" />
		
		<!-- TIDSBEGRÆNSNINGSDATOEN KALDES HER. MEN KUN HVIS DEN FINDES I INPUT XML -->
		<xsl:if test="model:Tidsbegraensning != ''">
			<xsl:apply-templates select="model:Tidsbegraensning"/>
		</xsl:if>
		
		<!--Her tilføjes respekter, hæftelser og servitutter Templates er defineret i ejendom.xslt .. tilføjet 03.12.08 JE-->
		<xsl:call-template name="UdskrivHaeftelser">
			<xsl:with-param name="Root" select="model:FastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser">
			<xsl:with-param name="Root" select="model:FastEjendomSamling"/>
		</xsl:call-template>
		<xsl:call-template name="UdskrivServitutter">
			<xsl:with-param name="Root" select="model:FastEjendomSamling"/>
		</xsl:call-template>
		
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/model:ErklaeringSamling" />
		</xsl:apply-templates>
		<!-- Bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--****************************************** Tidsbegraensning template *************************************-->
	
	<xsl:template match="model:Tidsbegraensning">
		<xsl:param name="overskrift" select="'ANMODET TIDSBEGRÆNSNINGSDATO'"/>

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="$overskrift" />
		</xsl:call-template>
	
		<xsl:variable name="tidsbegraensning">
			<xsl:call-template name="formatdato">
				<xsl:with-param name="dato" select="."/>
				</xsl:call-template>
		</xsl:variable>
		
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="string($tidsbegraensning)"/>
		</xsl:call-template>
			<xsl:call-template name="linefeed" />
	</xsl:template>
	
</xsl:stylesheet>

