<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
  	xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: SkifteretsAttest.xslt 195459 2021-03-04 10:07:55Z lpallesen@dxc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT templates specielt vedrørende SkifteretsAttest (118) -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<!-- ***********************************   SkifteretsAttestOpret   ************************************** -->
	<xsl:template match="msg:SkifteretsAttestOpret">
		<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
				<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<!-- FastEjendomSamling -->
		<xsl:apply-templates select="model:FastEjendomSamling"/>
		<!-- Anmeldelse -->
        <xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Skifteretsattest -->
		<xsl:apply-templates select="model:SkifteretsAttest"/>
		
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>
	
		<!-- Erklæringer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- BilagReferencer -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling"/>
	
		<!-- Øvrigt / AndenTekst (fraser, overskrifter og tekstafsnit) -->
		<xsl:call-template name="VisAndenTekst"> <!-- bagudkompatibel -->
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekst" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
		<xsl:call-template name="VisAndenTekstSamling">
			<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekstSamling" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
	
		<!-- ANMELDER -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>		
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			  <xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
				 
	</xsl:template>
	
	<xsl:template match="model:SkifteretsAttest">
		<!-- Dødsdato -->
		<xsl:if test="model:DoedsDato">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'Overtagelsesdato'" />
			</xsl:call-template>
			<xsl:call-template name="formatdato_column2">
				<xsl:with-param name="dato" select="model:DoedsDato" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
		<!--<xsl:apply-templates select="model:MyndighedOplysninger"/>-->

		<!-- Skifteform - Fjernet jvnfør QC13483 -->
		<!-- xsl:if test="model:SkifteformKode">
			<xsl:variable name="skifteform" select="model:SkifteformKode" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'SKIFTEFORM'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//SkifteformKode[@id = $skifteform]" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if -->
		
		<!-- Adkomst -->
		<xsl:if test="model:AdkomstSkifteretsAttestKode">
			<xsl:variable name="adkomst" select="model:AdkomstSkifteretsAttestKode" />
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'SKIFTERETSATTESTEN LYSES SOM ADKOMST'" />
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="$opslag//AdkomstSkifteretsAttestKode[@id = $adkomst]" />
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
