<?xml version="1.0" encoding="UTF-8"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:ois="http://rep.oio.dk/ois.dk/xml/schemas/2006/04/25/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Skoede.xslt 193848 2021-02-01 06:26:25Z cander28@dxc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

    <!-- Specifikation af output format -->
    <xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
    <xsl:strip-space elements="*"/>


<!-- ***********************************   SkoedeAuktionOpret   ************************************** -->
<xsl:template match="msg:SkoedeAuktionOpret">
	<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
	<xsl:call-template name="document_header">
		<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
	</xsl:call-template>

	<!-- EJENDOM - EjendomSamling -->
<xsl:variable name="antalEjendomme" select="count(//model:FastEjendomSamling/model:FastEjendom)"/>

<xsl:if test="not(model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme) or model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme = 'false' or $antalEjendomme &lt; 2">
    <xsl:call-template name="fastEjendomSamlingMedBraendeovne">
      <xsl:with-param name="fasteEjendomSamling" select="model:FastEjendomSamling"/>
    </xsl:call-template>
  </xsl:if>
  
	<!-- EJENDOM - EjendomSamling  uden brændeovne efterfulgt af samlet brændeovne-->
  <xsl:if test="model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme = 'true' and $antalEjendomme &gt; 1">
	  <xsl:apply-templates select="model:FastEjendomSamling"/>
    <xsl:call-template name="braendeovneAlene">
      <xsl:with-param name="ejendomsamling" select="model:FastEjendomSamling"/>
    </xsl:call-template>
  </xsl:if>

	<!-- EjendomsType, enhedsnummer -->
	<xsl:apply-templates select="model:EjendomIdentifikator/model:EjendomType"/>

  <!-- Anmeldelse information -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
		<xsl:with-param name="skoedevirksomhedoverdragelse" select="model:Skoede/model:VirksomhedOverdragelseIndikator"/>
	</xsl:apply-templates>
	<!--<xsl:apply-templates select="anm:AnmeldelseInformation"/>-->

	<!-- Skødeauktion -->
	<xsl:apply-templates select="model:SkoedeAuktion"/>

	<!-- EjendomKategori -->
	<xsl:apply-templates select="model:EjendomKategori"/>

	<!-- Hæftelser, fremtidige hæftelser og servitutter -->
	<xsl:call-template name="UdskrivHaeftelser"/>
	<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
	<xsl:call-template name="UdskrivServitutter"/>

	<!-- Erklæringer -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>

	<!-- BilagReferencer -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling"/>

	<!-- Øvrigt / AndenTekst (fraser, overskrifter og tekstafsnit) -->
	<xsl:call-template name="VisAndenTekst">
		<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekst" />
		<xsl:with-param name="overskrift" select="'ØVRIGT'" />
	</xsl:call-template>
	<xsl:call-template name="VisAndenTekstSamling">
		<xsl:with-param name="node" select="anm:AnmeldelseInformation/anm:AndenTekstSamling" />
		<xsl:with-param name="overskrift" select="'ØVRIGT'" />
	</xsl:call-template>

	<!-- ANMELDER -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
	<!-- Erklæring vedr. tinglysningsafgift: -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
		  <xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
	</xsl:apply-templates>
</xsl:template>

<!-- ***********************************   SkoedeOpret   ************************************** -->
<xsl:template match="msg:SkoedeOpret">
	<xsl:variable name="doctypeid" select="msg:EkspeditionstypeIdentifikator" />
	<xsl:call-template name="document_header">
		<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		<xsl:with-param name="proevetinglysning" select="anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
	</xsl:call-template>

	<!-- EjendomSamling -->
  <xsl:variable name="antalEjendomme" select="count(//model:FastEjendomSamling/model:FastEjendom)"/>

	<!-- EJENDOM - EjendomSamling  med brændeovne pr ejendom-->
	<xsl:if test="not(model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme) or model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme = 'false' or $antalEjendomme &lt; 2">
    <xsl:call-template name="fastEjendomSamlingMedBraendeovne">
      <xsl:with-param name="fasteEjendomSamling" select="model:FastEjendomSamling"/>
    </xsl:call-template>
  </xsl:if>
  
	<!-- EJENDOM - EjendomSamling  uden brændeovne efterfulgt af samlet brændeovne-->
    <xsl:if test="model:BraendeovnsOplysningsMarkeringerGaelderAlleEjendomme = 'true' and $antalEjendomme &gt; 1">
	  <xsl:apply-templates select="model:FastEjendomSamling"/>
    <xsl:call-template name="braendeovneAlene">
      <xsl:with-param name="ejendomsamling" select="model:FastEjendomSamling"/>
    </xsl:call-template>
  </xsl:if>
  
	<!-- Anmeldelse information -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:RolleSamling">
		<xsl:with-param name="skoedevirksomhedoverdragelse" select="model:Skoede/model:VirksomhedOverdragelseIndikator"/>
	</xsl:apply-templates>
	<!--<xsl:apply-templates select="anm:AnmeldelseInformation"/>-->

	<!-- Skødeinformationer -->
	<xsl:apply-templates select="model:Skoede"/>

	<!-- Hæftelser, fremtidige hæftelser og servitutter -->
	<xsl:call-template name="UdskrivHaeftelser"/>
	<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
	<xsl:call-template name="UdskrivServitutter"/>
	<!-- Øvrigt bagudkompatibel-->
	<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
	<!-- Øvrigt -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
	<!-- Erklæringer -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:ErklaeringSamling"/>
	<!-- Bilag -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:BilagReferenceSamling" />
	<!-- Anmelder incl. bilag -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AnmelderInformation"/>

	<!-- Tinglysningsafgift -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift"/>
	<!-- Beregningsgrundlaget er et andet -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
	<!-- Erklæring vedr. tinglysningsafgift: -->
	<xsl:apply-templates select="anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
		<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
	</xsl:apply-templates>

</xsl:template>



<!-- ***************************************   Skoede   ********************************************* -->
<!-- ************************************************************************************************ -->
<!-- Håndterer rendering af Skoede                                                                    -->
<xsl:template match="model:Skoede | model:SkoedeAuktion">
	<xsl:apply-templates select="model:EjendomKategori"/>

    <xsl:apply-templates select="model:BygningsforholdKode"/>

    <xsl:if test="model:AdkomstInformation/model:EjendomstypeSub">
		<xsl:choose>
			<xsl:when test="model:ValutaKode">
				<xsl:call-template name="model:EjendomstypeSub">
					<xsl:with-param name="node" select="model:AdkomstInformation/model:EjendomstypeSub"/>
					<xsl:with-param name="valuta" select="model:ValutaKode"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="model:EjendomstypeSub">
					<xsl:with-param name="node" select="model:AdkomstInformation/model:EjendomstypeSub"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>

    <xsl:choose>
    	<xsl:when test="model:AdkomstInformation/model:AdkomstHandelKodeSub != ''">
			<xsl:apply-templates select="model:AdkomstInformation/model:AdkomstHandelKodeSub"/>
	    </xsl:when>
    	<xsl:otherwise>
        	<xsl:apply-templates select="model:AdkomstHandelKode"/>
    	</xsl:otherwise>
	</xsl:choose>

	<xsl:if test="model:AdkomstInformation//model:AdkomstHandelBeskrivelseSub">
	    <xsl:apply-templates select="model:AdkomstInformation//model:AdkomstHandelBeskrivelseSub"/>
	</xsl:if>

	<xsl:if test="model:AdkomstInformation/model:AdkomstHandelBeskrivelse">
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="model:AdkomstInformation/model:AdkomstHandelBeskrivelse"/>
		</xsl:call-template>
	</xsl:if>

	<xsl:if test="model:AdkomstInformation/model:ArealDerAfhaendes">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'AREAL DER OVERDRAGES'" />
		</xsl:call-template>
		<xsl:call-template name="VisFraser">
			<xsl:with-param name="node" select="model:AdkomstInformation/model:ArealDerAfhaendes"/>
		</xsl:call-template>
	</xsl:if>

	<xsl:apply-templates select="model:AdkomstInformation/model:MedtagneEjendomme"/>

    <xsl:apply-templates select="model:AuktionDato"/>

    <xsl:apply-templates select="model:SkoedeOvertagelsesDato"/>
    <xsl:apply-templates select="model:SkoedeKoebsaftaleDato"/>
    <xsl:apply-templates select="model:SkoedeKoebsaftaleReference"/>

	<xsl:if test="model:SkoedeKoebesum">
		<xsl:choose>
			<xsl:when test="model:ValutaKode">
				<xsl:call-template name="model:SkoedeKoebesum">
					<xsl:with-param name="node" select="model:SkoedeKoebesum"/>
					<xsl:with-param name="valuta" select="model:ValutaKode"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="model:SkoedeKoebesum">
					<xsl:with-param name="node" select="model:SkoedeKoebesum"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:if>
    <xsl:apply-templates select="model:SkoedeUdenforKoebesum"/>
    <xsl:apply-templates select="model:BudsumBeloeb"/>
    <xsl:apply-templates select="model:SkoedeTransportBeloeb"/>

    <xsl:apply-templates select="model:SkoedeHandelsbetingelser"/>
    <xsl:apply-templates select="model:SkoedeTekst"/>

    <!-- Udækket gæld -->
    <xsl:if test="model:DokumentIdentifikatorSamling">
      <xsl:call-template name="heading">
        <xsl:with-param name="text" select="'Udækkede hæftelser, der begæres slettet'"/>
      </xsl:call-template>
      <xsl:for-each select="model:DokumentIdentifikatorSamling/model:DokumentIdentifikator">
  			<xsl:call-template name="dokument_som_paategnes">
  				<xsl:with-param name="doc_id" select="." />
  				<xsl:with-param name="include_header" select="'false'"/>
  			</xsl:call-template>
  		</xsl:for-each>
    </xsl:if>


	<!-- Fuldmagtsbestemmelser -->
	<xsl:apply-templates select="model:FuldmagtAnmeldtSamling"/>

	<xsl:call-template name="linefeed" />
</xsl:template>



<!-- ***********************************   EjendomsKategori   ********************************** -->
<xsl:template match="model:EjendomKategori">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'EJENDOMSKATEGORI'"/>
	</xsl:call-template>
	<xsl:choose>
		<xsl:when test="model:EjendomKategoriUbebyggetgrund">
		  <xsl:apply-templates select="model:EjendomKategoriUbebyggetgrund"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriErhvervsejendom">
		  <xsl:apply-templates select="model:EjendomKategoriErhvervsejendom"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriFlerfamiliesejendom">
		  <xsl:apply-templates select="model:EjendomKategoriFlerfamiliesejendom"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriEnfamiliesejendom">
		  <xsl:apply-templates select="model:EjendomKategoriEnfamiliesejendom"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriFritidsejendom">
		  <xsl:apply-templates select="model:EjendomKategoriFritidsejendom"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriLandbrug">
		  <xsl:apply-templates select="model:EjendomKategoriLandbrug"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriGartneri">
		  <xsl:apply-templates select="model:EjendomKategoriGartneri"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriSkovejendom">
		  <xsl:apply-templates select="model:EjendomKategoriSkovejendom"/>
		</xsl:when>
		<xsl:when test="model:EjendomKategoriUdlejningsejendom">
		  <xsl:apply-templates select="model:EjendomKategoriUdlejningsejendom"/>
		</xsl:when>
        <xsl:when test="model:EjendomKategoriAnden">
          <xsl:apply-templates select="model:EjendomKategoriAnden"/>
        </xsl:when>

	</xsl:choose>

	<xsl:call-template name="linefeed" />
</xsl:template>

<xsl:template match="model:EjendomKategoriUbebyggetgrund">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Ubebygget grund'"/>
	</xsl:call-template>
	<xsl:if test="model:ByggemodningsomkostningIndikator = 'true'">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Købesummen omfatter alle omkostninger til byggemodning.'" />
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="model:EjendomKategoriErhvervsejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Erhvervsejendom'"/>
	</xsl:call-template>
		<xsl:if test="model:UdlejningsgradIndikator = 'true' and model:UdlejningsejendomIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Mere end 50% af erhvervs- og boligarealerne har været udlejet i seneste kalenderår.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:UdlejningsgradIndikator = 'false' and model:UdlejningsejendomIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'50% eller mindre af erhvervs- og boligarealerne har været udlejet i seneste kalenderår.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:MomspligtigeformaalIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Ejendommen har været anvendt til momspligtige formål.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:MomspligtigeformaalIndikator = 'false'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Ejendommen har ikke været anvendt til momspligtige formål.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:UdlejningsejendomIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Ejendommen er en udlejningsejendom.'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:AntalBeboelseslejemaal != ''">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Antal beboelseslejemål'" />
				<xsl:with-param name="text" select="model:AntalBeboelseslejemaal" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:AntalErhvervslejemaal != ''">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Antal erhvervslejemål'" />
				<xsl:with-param name="text" select="model:AntalErhvervslejemaal" />
			</xsl:call-template>
		</xsl:if>
</xsl:template>

<xsl:template match="model:EjendomKategoriFlerfamiliesejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Flerfamiliesejendom'" />
	</xsl:call-template>
	<xsl:if test="model:AntalBeboelseslejligheder != ''">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Antal beboelseslejligheder'" />
				<xsl:with-param name="text" select="model:AntalBeboelseslejligheder" />
			</xsl:call-template>
	</xsl:if>
</xsl:template>

<xsl:template match="model:EjendomKategoriEnfamiliesejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Enfamiliesejendom'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriFritidsejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Fritidsejendom'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriLandbrug">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Landbrugsejendom'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriGartneri">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Gartneri'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriSkovejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Skovejendom'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriUdlejningsejendom">
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="'Udlejningsejendom'" />
	</xsl:call-template>
</xsl:template>

<xsl:template match="model:EjendomKategoriAnden">
  <xsl:call-template name="column2">
    <xsl:with-param name="text" select="'Andet'"/>
  </xsl:call-template>
  <xsl:if test="model:EjendomKategoriBeskrivelse != ''">
	<xsl:call-template name="VisFraser">
		<xsl:with-param name="node" select="model:EjendomKategoriBeskrivelse"/>
	</xsl:call-template>
  </xsl:if>
</xsl:template>

<!--   EjendomsKategori  -->


<!-- ***********************************   MedtagneEjendomme   ********************************** -->
<xsl:template match="model:MedtagneEjendomme">
	<xsl:param name="node" select="."/>

	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'FLERE EJENDOMME'" />
	</xsl:call-template>

	<xsl:if test="$node/model:AlleEjdMedtagetIndikator = 'true'">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'Alle de ejendomme, der er indeholdt i købesummen, er medtaget i anmeldelsen'" />
		</xsl:call-template>

		<xsl:call-template name="linefeed" />
	</xsl:if>

	<xsl:if test="$node/model:BfeIkkeKendtIndikator = 'true'">
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="'BFE-numre ikke kendt'" />
		</xsl:call-template>

		<xsl:call-template name="linefeed" />
	</xsl:if>

	<xsl:if test="$node/model:BfeNummerSamling">
		<xsl:for-each select="$node/model:BfeNummerSamling/model:BfeNummer">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="." />
			</xsl:call-template>
		</xsl:for-each>

		<xsl:call-template name="linefeed" />
	</xsl:if>

</xsl:template>

<!-- ***********************************   BygningsforholdKode   ********************************** -->
<xsl:template match="model:BygningsforholdKode">
	<xsl:call-template name="two_columns">
		<xsl:with-param name="prompt" select="'Afgivne oplysninger om bygninger'" />
		<xsl:with-param name="text">
			<xsl:choose>
				<xsl:when test=".='omfatterBygningerPlanlagtNedrevet'">
					<xsl:value-of select="'Handelen omfatter bygning(er), der er planlagt nedrevet.'"/>
				</xsl:when>
				<xsl:when test=".='omfatterBygningerUnderOpfoerelse'">
					<xsl:value-of select="'Handelen omfatter bygning(er) under opførelse.'"/>
				</xsl:when>
				<xsl:when test=".='omfatterPlanlagteBygninger'">
					<xsl:value-of select="'Forventet eller planlagt ombygning/ændret anvendelse.'"/>
				</xsl:when>
			</xsl:choose>
		</xsl:with-param>
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   AdkomstHandelKode   ********************************** -->
<xsl:template match="model:AdkomstHandelKode">
	<xsl:variable name="rtypeid" select="." />

	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'TYPE AF HANDEL'" />
	</xsl:call-template>
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="$opslag//AdkomstHandelKode[@id = $rtypeid]" />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   AdkomstHandelKodeSub  ********************************** -->
<xsl:template match="model:AdkomstHandelKodeSub">
	<xsl:variable name="rtypeid" select="." />

	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'TYPE AF HANDEL'" />
	</xsl:call-template>
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="$opslag//AdkomstHandelKodeSub[@id = $rtypeid]" />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   AdkomstHandelBeskrivelseSub  ********************************** -->
<xsl:template match="model:AdkomstHandelBeskrivelseSub">
	<xsl:variable name="rtypeid" select="." />
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="$opslag//AdkomstHandelBeskrivelseSub[@id = $rtypeid]" />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   AuktionDato   ********************************** -->
<xsl:template match="model:AuktionDato">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'DATO FOR AUKTION'" />
	</xsl:call-template>
	<xsl:call-template name="formatdato_column2">
		<xsl:with-param name="dato" select="." />
	</xsl:call-template>
<!--
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="." />
	</xsl:call-template>
-->
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   SkoedeOvertagelsesDato   ********************************* -->
<xsl:template match="model:SkoedeOvertagelsesDato">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'DATO FOR OVERTAGELSE'" />
	</xsl:call-template>
	<xsl:call-template name="formatdato_column2">
		<xsl:with-param name="dato" select="." />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   SkoedeKoebsaftaleDato   ********************************* -->
<xsl:template match="model:SkoedeKoebsaftaleDato">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'DATO FOR KØBSAFTALE'" />
	</xsl:call-template>
	<xsl:call-template name="formatdato_column2">
		<xsl:with-param name="dato" select="." />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- *******************************   SkoedeKoebsaftaleReference   ********************************* -->
<xsl:template match="model:SkoedeKoebsaftaleReference">
	<!-- Ikke implementeret -->
	<!--<xsl:value-of select="$missing_implementation"/>-->
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- **************************************   ValutaKode   *********************************** -->
<xsl:template match="model:ValutaKode">
	<xsl:call-template name="two_columns">
		<xsl:with-param name="prompt" select="'Valuta'" />
		<xsl:with-param name="text" select="." />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- *******************************   EjendomstypeSub   ********************************* -->
<xsl:template name="model:EjendomstypeSub">
	<xsl:param name="node" select="."/>
	<xsl:param name="valuta" select="'DKK'"/>

	<xsl:if test="$node/model:SamledeAreal">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Det samlede areal, der indgår i handelen'" />
			<xsl:with-param name="text" select="format-number($node/model:SamledeAreal, $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="'kvm'" />
		</xsl:call-template>
	</xsl:if>

	<xsl:if test="$node/model:KoebesumStuehus">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Aftalt købesum stuehus'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:KoebesumStuehus), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>

	<xsl:if test="$node/model:KoebesumDriftsbygninger">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Aftalt købesum driftsbygninger'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:KoebesumDriftsbygninger), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>

	<xsl:if test="$node/model:KoebesumJord">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Aftalt købesum jord'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:KoebesumJord), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>

	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- *******************************   Koebesum   ********************************* -->
<xsl:template name="model:SkoedeKoebesum">
	<xsl:param name="node" select="."/>
	<xsl:param name="valuta" select="'DKK'"/>
	<xsl:param name="showheader" select="'true'"/>

	<xsl:if test="$showheader = 'true'">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'KØBESUM'" />
		</xsl:call-template>
	</xsl:if>

	<xsl:if test="$node/model:KontantKoebesum">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Kontant købssum'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:KontantKoebesum), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:ArvGaveBeloeb">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Købesummen omfatter beløb til arv/gave'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:ArvGaveBeloeb), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:OvertagneRestancer">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Købesummen omfatter overtagne restancer af skatter og afgifter eller af andre ydelser.'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:OvertagneRestancer), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:AfloesningsbareServitutter">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Købesummen omfatter servitutter, tinglyst på det købte, der kan forlanges afløst af en pengeydelse'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:AfloesningsbareServitutter), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:AnlaegsBidrag">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Købesummen omfatter beløb til anlægsbidrag til vej mv., der er forfaldent til betaling på tidspunktet for ejerskiftet'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:AnlaegsBidrag), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:IAltKoebesum">
		<xsl:call-template name="two_columns">
			<xsl:with-param name="prompt" select="'Købesum i alt'" />
			<xsl:with-param name="text" select="format-number(floor($node/model:IAltKoebesum), $formatvaluta, 'currency-format')" />
			<xsl:with-param name="text2" select="$valuta" />
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="$node/model:KoebesumTekst">
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'KØBESUM BEGRUNDELSE'" />
		</xsl:call-template>
	    <xsl:apply-templates select="$node/model:KoebesumTekst"/>
	</xsl:if>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ********************************   SkoedeUdenforKoebesum     **************************** -->
<xsl:template match="model:SkoedeUdenforKoebesum">

	<xsl:if test="model:Enterprise or model:LoesoereDriftsmateriel or model:Husdyrbesaetning">
		<xsl:variable name="valuta" select="../model:ValutaKode"/>

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'UDENFOR KØBESUM OVERTAGER KØBER FØLGENDE'" />
		</xsl:call-template>

		<xsl:if test="model:Enterprise">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Beløb for Enterprise'" />
				<xsl:with-param name="text" select="format-number(floor(model:Enterprise/model:Beloeb), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="$valuta" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:Enterprise/model:EnterpriseTekst"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:LoesoereDriftsmateriel">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Beløb for løsøre/driftsmateriel'" />
				<xsl:with-param name="text" select="format-number(floor(model:LoesoereDriftsmateriel/model:Beloeb), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="$valuta" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:LoesoereDriftsmateriel/model:DriftsmaterielTekst"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:Husdyrbesaetning">
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Beløb for husdyrbesætning'" />
				<xsl:with-param name="text" select="format-number(floor(model:Husdyrbesaetning/model:Beloeb), $formatvaluta, 'currency-format')" />
				<xsl:with-param name="text2" select="$valuta" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:Husdyrbesaetning/model:HusdyrTekst"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />
	</xsl:if>
</xsl:template>

<!-- ******************************   SkoedeHandelsbetingelser     **************************** -->
<xsl:template match="model:SkoedeHandelsbetingelser">
	<xsl:if test="model:KoebesumBetaling/model:KoebesumbetalingIndikator = 'true' or model:BetingetMatrikulaerAendring or model:BetingelserOevrige/model:BetingelserOevrigeIndikator = 'true'">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'HANDELEN ER BETINGET AF'" />
		</xsl:call-template>

		<xsl:if test="model:KoebesumBetaling/model:KoebesumbetalingIndikator = 'true'">
			<xsl:variable name="betalingdato">
				<xsl:call-template name="formatdato">
					<xsl:with-param name="dato" select="model:KoebesumBetaling/model:BetalingDato"/>
				</xsl:call-template >
			</xsl:variable >
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="concat('Handelen er betinget af købesummens betaling, der betales senest pr. ', $betalingdato, '.', $linefeed)" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:BetingetMatrikulaerAendring">
			<xsl:variable name="matrikulaeraendring">
				<xsl:choose>
					<xsl:when test="'arealoverfoersel'">
						<xsl:value-of select="'Arealoverførsel.'"/>
					</xsl:when>
					<xsl:when test="'udstykning'">
						<xsl:value-of select="'Udstykning.'"/>
					</xsl:when>
					<xsl:when test="'sammenlaegning'">
						<xsl:value-of select="'Sammenlægning.'"/>
					</xsl:when>
					<xsl:when test="'andenmatrikulaeraendring'">
						<xsl:value-of select="'Anden matrikulær ændring.'"/>
					</xsl:when>
				</xsl:choose>
			</xsl:variable>
			<!--<xsl:call-template name="column2">
				<xsl:with-param name="text" select="concat('Gennemførelse af matrikulær ændring i form af: ', $matrikulaeraendring, $linefeed)" />
			</xsl:call-template>-->
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="concat('Gennemførelse af matrikulær ændring', $linefeed)" />
			</xsl:call-template>
		</xsl:if>

		<!-- Øvrige betingelser -->
		<xsl:if test="model:BetingelserOevrige/model:BetingelserOevrigeIndikator = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Handelen er i øvrigt betinget af:'" />
			</xsl:call-template>
			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="model:BetingelserOevrige/model:BetingelserTekst"/>
			</xsl:call-template>
		</xsl:if>

		<xsl:call-template name="linefeed" />
	</xsl:if>
</xsl:template>


<!-- ************************************   SkoedeTekst     *********************************** -->
<xsl:template match="model:SkoedeTekst">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'PARTERNE HAR AFTALT FØLGENDE ØVRIGE VILKÅR FOR HANDELEN'" />
	</xsl:call-template>
	<xsl:call-template name="VisFraser">
		<xsl:with-param name="node" select="."/>
	</xsl:call-template>
</xsl:template>

<!-- ***********************************   BudsumBeloeb   ********************************** -->
<xsl:template match="model:BudsumBeloeb">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'BUDSUM'" />
	</xsl:call-template>

	<xsl:variable name="valuta">
		<xsl:choose>
			<xsl:when test="../model:ValutaKode">
				<xsl:value-of select="../model:ValutaKode"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'DKK'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="format-number(floor(.), $formatvaluta, 'currency-format')" />
		<xsl:with-param name="text2" select="$valuta" />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>

<!-- ***********************************   SkoedeTransportBeloeb   ********************************** -->
<xsl:template match="model:SkoedeTransportBeloeb">
	<xsl:call-template name="heading">
		<xsl:with-param name="text" select="'TRANSPORT BELØB'" />
	</xsl:call-template>

	<xsl:variable name="valuta">
		<xsl:choose>
			<xsl:when test="../model:ValutaKode">
				<xsl:value-of select="../model:ValutaKode"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'DKK'"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:call-template name="column2">
		<xsl:with-param name="text" select="format-number(floor(.), $formatvaluta, 'currency-format')" />
		<xsl:with-param name="text2" select="$valuta" />
	</xsl:call-template>
	<xsl:call-template name="linefeed" />
</xsl:template>


<!-- ***********************************   Brændeovnsmarkeringer for sig ********************************** -->
<xsl:template name="braendeovneAlene">
  <xsl:param name="ejendomsamling" select="."/>
  <xsl:call-template name="heading">
    <xsl:with-param name="text" select="'BRÆNDEOVNE'"/>
  </xsl:call-template>
  <!-- Skriv at det gælder alle ejendommene -->
  <xsl:call-template name="column2">
    <xsl:with-param name="text" select="'Oplysningen gælder for alle ejendomme i anmeldelsen.'"/>
  </xsl:call-template>
  <xsl:call-template name="linefeed" />
  <!-- Tag brændeovnsoplysninger fra den første ejendom -->
  <xsl:variable name="ejendom" select="$ejendomsamling/model:FastEjendom[1]"/> 
  <xsl:call-template name="braendeovne">
    <xsl:with-param name="braendeovnsOplysningerSamling" select="$ejendom/model:BraendeovnsOplysningerSamling"/>
  </xsl:call-template>
</xsl:template>
<!-- ***********************************   Brændeovnsmarkeringer ********************************** -->

<xsl:template name="braendeovne">
  <xsl:param name="braendeovnsOplysningerSamling" select="."/>
  <xsl:for-each select="$braendeovnsOplysningerSamling/model:BraendeovnsOplysninger">
    <xsl:variable name="oplysning" select="."/>
    <xsl:call-template name="column2">
			<xsl:with-param name="text" select="$opslag//BraendeovnsOplysninger[@id = $oplysning]"/>
    </xsl:call-template>
    <xsl:call-template name="linefeed" />
  </xsl:for-each>
</xsl:template>

<!-- ***********************************   FastEjendomSamling  med brændeovne ********************************** -->

	<xsl:template name="fastEjendomSamlingMedBraendeovne">
    <xsl:param name="fastEjendomSamling" select="."/>
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'EJENDOM'" />
		</xsl:call-template>
		<xsl:for-each select="$fastEjendomSamling//model:FastEjendom">
    	<xsl:call-template name="fastEjendomMedBraendeovne">
        <xsl:with-param name="fasteEjendom" select="."/>
      </xsl:call-template>
		</xsl:for-each>
	</xsl:template>

<!-- ***********************************   FastEjendom  med brændeovne ********************************** -->

	<xsl:template name="fastEjendomMedBraendeovne">
    <xsl:param name="fastEjendom" select="."/>
		<xsl:apply-templates select="$fastEjendom/model:EjendomIdentifikator"/>
		<xsl:call-template name="linefeed" />
    <xsl:if test="count(//model:BraendeovnsOplysninger) &gt; 0">
      <xsl:call-template name="two_columns">
    	  <xsl:with-param name="prompt" select="'Brændeovne'"/>
			  <xsl:with-param name="text" select="''"/>
      </xsl:call-template>   
    </xsl:if>
		<xsl:call-template name="braendeovne">
    	<xsl:with-param name="braendeovnsOplysningerSamling" select="$fastEjendom/model:BraendeovnsOplysningerSamling" />
		</xsl:call-template>    
	</xsl:template>



</xsl:stylesheet>
