<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
    xmlns:xkom="http://rep.oio.dk/xkom.dk/xml/schemas/2006/01/06/"
    xmlns:xkom-1="http://rep.oio.dk/xkom.dk/xml/schemas/2005/03/15/"
    xmlns:cpr="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:cpr-1="http://rep.oio.dk/cpr.dk/xml/schemas/core/2005/03/18/"
    xmlns:dkcc="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2005/03/15/"
    xmlns:dkcc-1="http://rep.oio.dk/ebxml/xml/schemas/dkcc/2003/02/13/"
    xmlns:cvr="http://rep.oio.dk/cvr.dk/xml/schemas/2005/03/22/"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:eakt="http://rep.oio.dk/tinglysning.dk/schema/elektroniskakt/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: TinglysningsPaategninger.xslt 115166 2017-03-31 07:05:37Z cander28@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<!-- ***********************************   TinglysningspaategningElementSamling   ********************************** -->
	<xsl:template match="anm:TinglysningspaategningElementSamling">
		<xsl:param name="vis_eksptype" select="'false'"/>

		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividersvar" />
		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="'RESULTAT AF TINGLYSNING'" />
			<xsl:with-param name="show_logo" select="'false'" />
		</xsl:call-template>
		
		<xsl:for-each select="anm:TinglysningspaategningElement">
			<xsl:apply-templates select=".">
				<xsl:with-param name="vis_eksptype" select="$vis_eksptype"/>
			</xsl:apply-templates>
		</xsl:for-each>

	</xsl:template>	
	
	<!-- ***********************************   TinglysningspaategningElement   ********************************** -->
	<xsl:template match="anm:TinglysningspaategningElement">
		<xsl:param name="vis_eksptype" select="'true'"/>
	
		<xsl:if test="model:TinglysningObjektIdentifikator/model:EjendomIdentifikator">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'EJENDOM'" />
			</xsl:call-template>
			<xsl:apply-templates select="model:TinglysningObjektIdentifikator/model:EjendomIdentifikator"/>
		</xsl:if>
		<xsl:if test="model:TinglysningObjektIdentifikator/model:BilIdentifikator">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'BIL'" />
			</xsl:call-template>
			<xsl:call-template name="model:VisBil">
				<xsl:with-param name="node" select="model:TinglysningObjektIdentifikator"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:TinglysningObjektIdentifikator/model:AndelIdentifikator">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'ANDEL'" />
			</xsl:call-template>
			<xsl:apply-templates select="model:TinglysningObjektIdentifikator/model:AndelIdentifikator"/>
		</xsl:if>
		<xsl:if test="model:TinglysningObjektIdentifikator/model:LoesoereIdentifikator">
			<xsl:choose>
				<xsl:when test="model:TinglysningObjektIdentifikator/model:LoesoereIdentifikator/cpr:PersonCivilRegistrationIdentifier">
					<xsl:call-template name="heading">
						<xsl:with-param name="text" select="'Person'" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="heading">
						<xsl:with-param name="text" select="'Virksomhed'" />
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:call-template name="VisLoesoere">
				<xsl:with-param name="node" select="model:TinglysningObjektIdentifikator"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="model:TinglysningObjektIdentifikator/model:DokumentRevisionIdentifikator">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENT'" />
			</xsl:call-template>
			<xsl:variable name="doc_id" select="model:TinglysningObjektIdentifikator/model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
			<xsl:call-template name="dokument_som_paategnes">
				<xsl:with-param name="doc_id" select="$doc_id" />
				<xsl:with-param name="include_header" select="'false'" />
				<xsl:with-param name="visAliasLink" select="'false'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:call-template name="linefeed" />

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'STATUS'" />
		</xsl:call-template>
		<xsl:variable name="tinglysningstatus" select="anm:TinglysningStatusKode" />
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="$opslag//TinglysningStatusKode[@id = $tinglysningstatus]" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'TINGLYSNINGSDATO'" />
		</xsl:call-template>
		<xsl:variable name="anmdato">
			<xsl:call-template name="formatdatotid">
				<xsl:with-param name="dato" select="//model:AnmeldelsesTidspunkt"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="string($anmdato)"/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />

		<!--<xsl:if test="$vis_eksptype='true'">-->
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DOKUMENTTYPE'" />
			</xsl:call-template>
			<xsl:variable name="doctypeid" select="model:EkspeditionstypeIdentifikator" />
			<xsl:variable name="eksptypenavn" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:call-template name="column2">
				<xsl:with-param name="text">
					<xsl:choose>
						<xsl:when test="$eksptypenavn = 'SDRO-PANTEBREV'">
							<xsl:value-of select="'SDRO-Pantebrev'" />
						</xsl:when>
						<xsl:when test="$eksptypenavn = 'SDO-PANTEBREV'">
							<xsl:value-of select="'SDO-Pantebrev'" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="concat(substring($eksptypenavn,1,1),translate(substring($eksptypenavn,2),'ABCDEFGHIJKLMNOPQRSTUVWXYZÆØÅ','abcdefghijklmnopqrstuvwxyzæøå'))" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />		
		<!--</xsl:if>-->		

		<xsl:if test="eakt:DokumentAliasIdentifikator">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'DATO/LØBENUMMER'" />
			</xsl:call-template>
			<xsl:call-template name="DokumentAlias">
				<xsl:with-param name="prompt" select="''"/>
				<xsl:with-param name="Identifikator" select="eakt:DokumentAliasIdentifikator"/>
			</xsl:call-template>
			<!--<xsl:call-template name="column2">
				<xsl:with-param name="text" select="eakt:DokumentAliasIdentifikator" />
			</xsl:call-template>-->
			<xsl:call-template name="linefeed" />
		</xsl:if>
		
		<xsl:apply-templates select="eakt:BemaerkningSamling"/>	
		<xsl:apply-templates select="eakt:AnmaerkningSamling"/>	
		<xsl:apply-templates select="eakt:FristInformationSamling"/>	
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
	</xsl:template>	
	
	<!-- ***********************************   BemaerkningSamling   ********************************** -->
	<xsl:template match="eakt:BemaerkningSamling">

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'BEMÆRKNINGER'"/>
		</xsl:call-template>

		<xsl:for-each select="eakt:Bemaerkning">
			<xsl:apply-templates select="."/>
		</xsl:for-each>

	</xsl:template>

	<!-- ***********************************   Bemaerkning   ********************************** -->
	<xsl:template match="eakt:Bemaerkning">

			<xsl:call-template name="VisFraser">
				<xsl:with-param name="node" select="."/>
			</xsl:call-template>

	</xsl:template>	

	<!-- ***********************************   AnmaerkningSamling   ********************************** -->
	<xsl:template match="eakt:AnmaerkningSamling">
		<xsl:param name="header" select="'ANMÆRKNINGER'" />

		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="$header"/>
		</xsl:call-template>

		<xsl:for-each select="eakt:Anmaerkning">
			<xsl:sort select="model:Rettighed//model:PrioritetNummer"/>
			<xsl:apply-templates select="."/>
		</xsl:for-each>

	</xsl:template>

	<!-- ***********************************   Anmaerkning   ********************************** -->
	<xsl:template match="eakt:Anmaerkning">
		<xsl:choose>
			<xsl:when test="model:Rettighed/model:Adkomstrettighed">
			</xsl:when>
			<xsl:when test="model:Rettighed/model:Pantrettighed">
				<xsl:choose>
					<xsl:when test="eakt:DokumentAlias">
						<xsl:if test="eakt:DokumentAlias/eakt:DokumentAliasIdentifikator">
							<xsl:call-template name="DokumentAlias">
								<xsl:with-param name="Identifikator" select="eakt:DokumentAlias/eakt:DokumentAliasIdentifikator"/>
									<xsl:with-param name="indent" select="'false'"/>
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="eakt:DokumentAlias/eakt:AktHistoriskIdentifikator">
							<xsl:call-template name="DokumentAlias">
								<xsl:with-param name="Identifikator" select="eakt:DokumentAlias/eakt:AktHistoriskIdentifikator"/>
									<xsl:with-param name="indent" select="'false'"/>
							</xsl:call-template>
						</xsl:if>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="rettighedsIdentifikator" select="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator" />
						<xsl:variable name="rettigheder" select="//snapshot:SnapshotSamling/snapshot:RettighedIdentifikatorSamling/snapshot:RettighedIdentifikatorStruktur[model:Rettighed/model:Pantrettighed/ model:RettighedIdentifikator = $rettighedsIdentifikator]"/>
						<xsl:variable name="dokumentIdentifikator" select="$rettigheder/model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
						<xsl:variable name="revisionNummer" select="$rettigheder/model:DokumentRevisionIdentifikator/model:RevisionNummer" />
						<xsl:variable name="Struktur" select="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $dokumentIdentifikator and (string-length($revisionNummer)=0 or model:DokumentRevisionIdentifikator/model:RevisionNummer = $revisionNummer)]"/>
						<xsl:if test="$Struktur/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Dato/løbenummer'" />
								<xsl:with-param name="text" select="$Struktur/eakt:DokumentAlias/eakt:DokumentAliasIdentifikator" />
							</xsl:call-template>
						</xsl:if>
						<xsl:if test="$Struktur/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator">
							<xsl:call-template name="two_columns">
								<xsl:with-param name="prompt" select="'Dato/løbenummer'" />
								<xsl:with-param name="text" select="$Struktur/eakt:DokumentAlias/eakt:AktHistoriskIdentifikator" />
							</xsl:call-template>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Prioritet'"/>
					<xsl:with-param name="text">
					 <xsl:choose>
					   <xsl:when test="model:Rettighed/model:Pantrettighed/model:PrioritetNummer"><xsl:value-of select="model:Rettighed/model:Pantrettighed/model:PrioritetNummer" /></xsl:when>
					   <xsl:otherwise><xsl:value-of select="model:Rettighed/model:Servitutrettighed/model:PrioritetNummer" /></xsl:otherwise> 
					 </xsl:choose>
					</xsl:with-param>
				</xsl:call-template>
				<xsl:if test="eakt:HaeftelseRettighedInformation">
					<xsl:apply-templates select="eakt:HaeftelseRettighedInformation"/>
				</xsl:if>
				<xsl:if test="eakt:MeddelelseTypeTekst">
				<xsl:apply-templates select="eakt:MeddelelseTypeTekst"/>
				</xsl:if>
				<xsl:call-template name="linefeed" />
			</xsl:when>
			<xsl:when test="model:Rettighed/model:Servitutrettighed">
				<xsl:if test="eakt:DokumentAlias/eakt:DokumentAliasIdentifikator">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Dato/løbenummer'" />
						<xsl:with-param name="text" select="eakt:DokumentAlias/eakt:DokumentAliasIdentifikator" />
					</xsl:call-template>
				</xsl:if>
				<xsl:if test="eakt:DokumentAlias/eakt:AktHistoriskIdentifikator">
					<xsl:call-template name="two_columns">
						<xsl:with-param name="prompt" select="'Dato/løbenummer'" />
						<xsl:with-param name="text" select="eakt:DokumentAlias/eakt:AktHistoriskIdentifikator" />
					</xsl:call-template>
				</xsl:if>
				<xsl:variable name="servituttype" select="model:ServitutType" />
				<xsl:call-template name="two_columns">
					<xsl:with-param name="prompt" select="'Servitut'" />
					<xsl:with-param name="text" select="$opslag//ServitutType[@id = $servituttype]" />
				</xsl:call-template>
				<xsl:call-template name="linefeed" />
			</xsl:when>
		</xsl:choose>
	</xsl:template>	

	<!-- ***********************************   HaeftelseRettighedInformation   ********************************** -->
	<xsl:template match="eakt:HaeftelseRettighedInformation">
		<!-- Dokumenttype -->
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseAndelIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseBilIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseFastEjendomIdentifikator"/>
		<xsl:apply-templates select="model:EkspeditionstypeHaeftelseLoesoereIdentifikator"/>
		<!-- Hovedstol -->
		<xsl:call-template name="Hovedstol">
			<xsl:with-param name="node" select="node()"/>
		</xsl:call-template>
		<!-- Rentesats -->
		<xsl:apply-templates select="model:HaeftelseRenteSats"/>
		<!-- Lånetype -->
		<xsl:apply-templates select="model:HaeftelseLaantypeKode"/>
		<!-- Særligevilkår -->
		<xsl:apply-templates select="model:HaeftelseSaerligeLaanevilkaarstypeSamling"/>
		<!-- Kreditor -->
		<xsl:apply-templates select="model:KreditorSamling"/>	
		<xsl:apply-templates select="model:KreditorInformationSamling"/>	
	</xsl:template>
	
  <!-- ***********************************   MeddelelseTypeTekst   ********************************** -->
    <xsl:template match="eakt:MeddelelseTypeTekst">
         <xsl:variable name="mt" select="node()" />
     <xsl:call-template name="two_columns">
       <xsl:with-param name="prompt" select="'Meddelelse'" />
       <xsl:with-param name="text" select="$opslag//MeddelelseTekstType[@id = $mt]" />
     </xsl:call-template>
    </xsl:template>
   
</xsl:stylesheet>

