<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:msgbil="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
    xmlns:msgandel="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: UdlaegOpret.xslt 190138 2020-11-05 18:30:18Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder alle pantebrev dokumenttyper  -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>


	<!--*********************************************************************************************************************-->
	<!--**************************************** 32 - UdlaegFastEjendomOpret *****************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:UdlaegFastEjendomOpret">
		<xsl:call-template name="UdlaegOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msg:EkspeditionstypeIdentifikator" />
		</xsl:call-template>		
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--**************************************** 33 - UdlaegBilOpret *****************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgbil:UdlaegBilOpret">
		<xsl:call-template name="UdlaegOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgbil:EkspeditionstypeIdentifikator" />
		</xsl:call-template>		
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--**************************************** 34 - UdlaegAndelOpret *****************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgandel:UdlaegAndelOpret">
		<xsl:call-template name="UdlaegOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgandel:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--**************************************** UdlaegOpret *****************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template name="UdlaegOpret">
		<xsl:param name="node"/>
		<xsl:param name="eksptype"/>

		<xsl:variable name="doctypeid" select="$eksptype" />		
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="$node/anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<!-- Ejendomme -->
		<xsl:apply-templates select="$node/model:FastEjendomSamling"/>
		<xsl:apply-templates select="$node/model:BilSamling"/>
		<xsl:apply-templates select="$node/model:AndelSamling"/>
		<!-- Roller -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering"/>			
		
		<xsl:apply-templates select="$node/model:UdlaegFastEjendom"/>
		<xsl:apply-templates select="$node/model:UdlaegBil"/>
		<xsl:apply-templates select="$node/model:UdlaegAndel"/>
		
		<!-- Hæftelser, fremtidige hæftelser og servitutter -->
		<xsl:call-template name="UdskrivHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeHaeftelser"/>
		<xsl:call-template name="UdskrivServitutter"/>

		<xsl:call-template name="UdskrivAndelHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeAndelHaeftelser"/>

		<xsl:call-template name="UdskrivBilHaeftelser"/>
		<xsl:call-template name="UdskrivFremtidigeBilHaeftelser"/>

		<!-- Erklæringer -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Øvrigt bagudkompatibel-->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekst"/>
		<!-- Øvrigt -->
		<xsl:apply-templates select="anm:AnmeldelseInformation/anm:AndenTekstSamling"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--***** UdlaegFastEjendom | model:UdlaegBil | model:UdlaegAndel:UdlaegFastEjendom | model:UdlaegBil | model:UdlaegAndel ******-->
	<xsl:template match="model:UdlaegFastEjendom | model:UdlaegBil | model:UdlaegAndel">
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'UDLÆG DATO'" />
		</xsl:call-template>
		<xsl:variable name="udlaegdato">
			<xsl:call-template name="formatdato">
				<xsl:with-param name="dato" select="model:UdlaegDato"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="string($udlaegdato)"/>
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'UDLÆG BELØB'" />
		</xsl:call-template>
		<xsl:call-template name="column2">
			<xsl:with-param name="text" select="format-number(floor(.//model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')" />
			<xsl:with-param name="text2" select=".//model:ValutaKode" />
		</xsl:call-template>
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="model:UdlaegKunDebitorAndelIndikator"/>		
	</xsl:template>

<xsl:template match="model:UdlaegKunDebitorAndelIndikator">
		<xsl:if test=". = 'true'">
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="'Udlæg foretaget i debitors ideelle andel af ejendommen'"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
</xsl:template>


</xsl:stylesheet>

