<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
    xmlns:msg="http://rep.oio.dk/tinglysning.dk/service/message/tingbog/1/"
    xmlns:msgbil="http://rep.oio.dk/tinglysning.dk/service/message/bilbog/1/"
    xmlns:msgandel="http://rep.oio.dk/tinglysning.dk/service/message/andelsbog/1/"
    xmlns:msgperson="http://rep.oio.dk/tinglysning.dk/service/message/personbog/1/"
    xmlns:model="http://rep.oio.dk/tinglysning.dk/schema/model/1/"
    xmlns:anm="http://rep.oio.dk/tinglysning.dk/schema/anmeldelse/1/"
    xmlns:snapshot="http://rep.oio.dk/tinglysning.dk/schema/snapshot/1/"
>
<!--
***************************************************************************************************************************************
Renderingsversion: 40.0.30
Dokumentversion: $Id: Underpant.xslt 190138 2020-11-05 18:30:18Z meld@csc.com $
Servicekatalog: 40.0.3
***************************************************************************************************************************************
-->
	<!-- Dette XSLT indeholder UnderpantsaetningOpret og UnderpantsaetningPaategn -->

	<!-- Specifikation af output format -->
	<xsl:output method="text" omit-xml-declaration="yes" indent="no" encoding="UTF-8"/>
	<xsl:strip-space elements="*"/>

	<!--*********************************************************************************************************************-->
	<!--********************************* 19 - UnderpantsætningFastEjendomOpret **********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:UnderpantsaetningFastEjendomOpret">
		<xsl:call-template name="UnderpantsaetningOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msg:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>	

	<!--*********************************************************************************************************************-->
	<!--********************************* 20 - UnderpantsætningBilOpret **********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgbil:UnderpantsaetningBilOpret">
		<xsl:call-template name="UnderpantsaetningOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgbil:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>	

	<!--*********************************************************************************************************************-->
	<!--********************************* 22 - UnderpantsætningAndelOpret **********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgandel:UnderpantsaetningAndelOpret">
		<xsl:call-template name="UnderpantsaetningOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgandel:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>	

	<!--*********************************************************************************************************************-->
	<!--********************************* 21 - UnderpantsætningLøsøreOpret **********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgperson:UnderpantsaetningLoesoereOpret">
		<xsl:call-template name="UnderpantsaetningOpret">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgperson:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>	
	
	<!--*********************************************************************************************************************-->
	<!--******************************************* UnderpantsætningOpret *********************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template name="UnderpantsaetningOpret">
		<xsl:param name="node"/>
		<xsl:param name="eksptype"/>

		<xsl:variable name="doctypeid" select="$eksptype" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
			<xsl:with-param name="proevetinglysning" select="$node/anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>
		<xsl:call-template name="heading">
			<xsl:with-param name="text" select="'DOKUMENT SOM UNDERPANTSÆTTES'"/>
		</xsl:call-template>
		<xsl:call-template name="dokument_som_paategnes">
			<xsl:with-param name="doc_id" select="$node/model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
			<xsl:with-param name="include_header" select="'false'"/>
		</xsl:call-template>
		<!-- Roller -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:RolleSamling"/>
		<xsl:call-template name="UdskrivSkyldnerErklaering" />
        <!-- Underpantbeløb -->
		<xsl:if test="$node/model:UnderpantsaetningFastEjendom/model:UnderpantBeloeb">
			<xsl:variable name="HaeftelseBeloeb" select="$node/model:UnderpantsaetningFastEjendom/model:UnderpantBeloeb"/>
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'BELØB'"/>
			</xsl:call-template>
			<xsl:call-template name="column2">
				<xsl:with-param name="text" select="format-number(floor($HaeftelseBeloeb/model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')"/>
				<xsl:with-param name="text2" select="$HaeftelseBeloeb/model:ValutaKode"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
			<!-- Fuldmagtsbestemmelser -->
			<xsl:apply-templates select="$node/model:UnderpantsaetningFastEjendom/model:FuldmagtAnmeldtSamling"/>
		</xsl:if>	
			<!-- Respekt af underpant -->
		<xsl:if test="$node/model:UnderpantsaetningFastEjendom/model:UnderpantRespektSamling">
			<xsl:apply-templates select="$node/model:UnderpantsaetningFastEjendom/model:UnderpantRespektSamling"/>
		</xsl:if>	
			
        <!-- Underpantbeløb Bil -->
        <xsl:if test="$node/model:UnderpantsaetningBil/model:UnderpantBeloeb">
          <xsl:variable name="HaeftelseBeloeb" select="$node/model:UnderpantsaetningBil/model:UnderpantBeloeb"/>
          <xsl:call-template name="heading">
            <xsl:with-param name="text" select="'BELØB'"/>
          </xsl:call-template>
          <xsl:call-template name="column2">
            <xsl:with-param name="text" select="format-number(floor($HaeftelseBeloeb/model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')"/>
            <xsl:with-param name="text2" select="$HaeftelseBeloeb/model:ValutaKode"/>
          </xsl:call-template>
          <xsl:call-template name="linefeed" />
			<!-- Fuldmagtsbestemmelser -->
			<xsl:apply-templates select="$node/model:UnderpantsaetningBil/model:FuldmagtAnmeldtSamling"/>
      </xsl:if>
			<!-- Respekt af underpant -->
			<xsl:if test="$node/model:UnderpantsaetningBil/model:UnderpantRespektSamling">
				<xsl:apply-templates select="$node/model:UnderpantsaetningBil/model:UnderpantRespektSamling"/>
			</xsl:if>	
        
        <!-- Underpantbeløb Andel -->
        <xsl:if test="$node/model:UnderpantsaetningAndel/model:UnderpantBeloeb">
          <xsl:variable name="HaeftelseBeloeb" select="$node/model:UnderpantsaetningAndel/model:UnderpantBeloeb"/>
          <xsl:call-template name="heading">
            <xsl:with-param name="text" select="'BELØB'"/>
          </xsl:call-template>
          <xsl:call-template name="column2">
            <xsl:with-param name="text" select="format-number(floor($HaeftelseBeloeb/model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')"/>
            <xsl:with-param name="text2" select="$HaeftelseBeloeb/model:ValutaKode"/>
          </xsl:call-template>
          <xsl:call-template name="linefeed" />
			<!-- Fuldmagtsbestemmelser -->
				<xsl:apply-templates select="$node/model:UnderpantsaetningAndel/model:FuldmagtAnmeldtSamling"/>
      </xsl:if>
			<!-- Respekt af underpant -->
			<xsl:if test="$node/model:UnderpantsaetningAndel/model:UnderpantRespektSamling">
				<xsl:apply-templates select="$node/model:UnderpantsaetningAndel/model:UnderpantRespektSamling"/>
			</xsl:if>	
        
        <!-- Underpantbeløb Loesoere -->
        <xsl:if test="$node/model:UnderpantsaetningLoesoere/model:UnderpantBeloeb">
          <xsl:variable name="HaeftelseBeloeb" select="$node/model:UnderpantsaetningLoesoere/model:UnderpantBeloeb"/>
          <xsl:call-template name="heading">
            <xsl:with-param name="text" select="'BELØB'"/>
          </xsl:call-template>
          <xsl:call-template name="column2">
            <xsl:with-param name="text" select="format-number(floor($HaeftelseBeloeb/model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')"/>
            <xsl:with-param name="text2" select="$HaeftelseBeloeb/model:ValutaKode"/>
          </xsl:call-template>
          <xsl:call-template name="linefeed" />
			<!-- Fuldmagtsbestemmelser -->
			<xsl:apply-templates select="$node/model:UnderpantsaetningLoesoere/model:FuldmagtAnmeldtSamling"/>
      </xsl:if>
			<!-- Respekt af underpant -->
			<xsl:if test="$node/model:UnderpantsaetningLoesoere/model:UnderpantRespektSamling">
				<xsl:apply-templates select="$node/model:UnderpantsaetningLoesoere/model:UnderpantRespektSamling"/>
			</xsl:if>	
        
		<!-- Erklæringer -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- BilagReferencer -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:BilagReferenceSamling"/>
		<!-- Øvrigt / AndenTekst (fraser, overskrifter og tekstafsnit) -->
		<xsl:call-template name="VisAndenTekst"> <!-- bagudkompatibel -->
			<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekst" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
		<xsl:call-template name="VisAndenTekstSamling">
			<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekstSamling" />
			<xsl:with-param name="overskrift" select="'ØVRIGT'" />
		</xsl:call-template>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--******************************** 214 - UnderpantsaetningFastEjendomPaategn ******************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msg:UnderpantsaetningFastEjendomPaategn">
		<xsl:call-template name="UnderpantsaetningPaategn">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msg:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--****************************************** 215 - UnderpantsaetningBilPaategn *********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgbil:UnderpantsaetningBilPaategn">
		<xsl:call-template name="UnderpantsaetningPaategn">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgbil:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--************************************ 216 - UnderpantsaetningAndelPaategn ***********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgandel:UnderpantsaetningAndelPaategn">
		<xsl:call-template name="UnderpantsaetningPaategn">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgandel:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--********************************** 231 - UnderpantsaetningLoesoerePaategn *********************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template match="msgperson:UnderpantsaetningLoesoerePaategn">
		<xsl:call-template name="UnderpantsaetningPaategn">
			<xsl:with-param name="node" select="." />
			<xsl:with-param name="eksptype" select="msgperson:EkspeditionstypeIdentifikator" />
		</xsl:call-template>	
	</xsl:template>

	<!--*********************************************************************************************************************-->
	<!--*********************************************** UnderpantsaetningPaategn *************************************-->
	<!--*********************************************************************************************************************-->
	<xsl:template name="UnderpantsaetningPaategn">
		<xsl:param name="node"/>
		<xsl:param name="eksptype"/>		
		
		<xsl:variable name="doctypeid" select="$eksptype" />
		<xsl:call-template name="document_header">
			<xsl:with-param name="text" select="'PÅTEGNING'" />
			<xsl:with-param name="proevetinglysning" select="$node//anm:AnmeldelseInformation/anm:Procesinstruktion/anm:ProeveTinglysningIndikator" />
		</xsl:call-template>

		<xsl:variable name="doc_id" select="$node/model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
		<xsl:call-template name="dokument_som_paategnes">
			<xsl:with-param name="doc_id" select="$doc_id" />
		</xsl:call-template>

		<xsl:call-template name="document_subheader">
			<xsl:with-param name="text" select="$opslag//Ekspeditionstype[@id = $doctypeid]" />
		</xsl:call-template>
		<!-- Respekt af underpant -->
		<xsl:apply-templates select="$node/msg:UnderpantRespektSamling"/>
		<xsl:apply-templates select="$node/msgbil:UnderpantRespektSamling"/>
		<xsl:apply-templates select="$node/msgandel:UnderpantRespektSamling"/>
		<xsl:apply-templates select="$node/msgperson:UnderpantRespektSamling"/>
		<xsl:if test="$node/anm:AnmeldelseInformation/anm:AndenTekst">  <!-- bagudkompatibel -->
			<xsl:call-template name="VisAndenTekst">
				<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekst" />
				<xsl:with-param name="overskrift" select="'TEKST'" />
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="$node/anm:AnmeldelseInformation/anm:AndenTekstSamling">
			<xsl:call-template name="VisAndenTekstSamling">
				<xsl:with-param name="node" select="$node/anm:AnmeldelseInformation/anm:AndenTekstSamling" />
				<xsl:with-param name="overskrift" select="'ØVRIGT'" />
			</xsl:call-template>
		</xsl:if>
		<!-- Erklæringer -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:ErklaeringSamling"/>
		<!-- Bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:BilagReferenceSamling" />
		<!-- Rollesamlingen skal stå til sidst efter en skillelinie -->
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="dividerlong"/>
		<xsl:call-template name="linefeed" />
		<xsl:call-template name="linefeed" />
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:RolleSamling"/>
		<!-- Anmelder incl. bilag -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/anm:AnmelderInformation"/>
		<!-- Tinglysningsafgift -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift"/>
		<!-- Beregningsgrundlaget er et andet -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:AfvigelsesaarsagTekst"/>
		<!-- Erklæring vedr. tinglysningsafgift: -->
		<xsl:apply-templates select="$node/anm:AnmeldelseInformation/model:TinglysningAfgift/model:ErklaeringSamling">
			<xsl:with-param name="heading" select="'ERKLÆRINGER VEDR. TINGLYSNINGSAFGIFT'"/>
		</xsl:apply-templates>
	</xsl:template>



	<!-- *********************************  UnderpantRespektSamling  ******************************** -->
	<xsl:template match="model:UnderpantRespektSamling | msg:UnderpantRespektSamling | msgbil:UnderpantRespektSamling | msgandel:UnderpantRespektSamling | msgperson:UnderpantRespektSamling">
		<xsl:variable name="rettigheder">
			<xsl:for-each select="*">
				<xsl:variable name="rettighedIdentifikator" select="."/>
				<xsl:for-each select="//snapshot:SnapshotSamling/snapshot:RettighedIdentifikatorSamling/snapshot:RettighedIdentifikatorStruktur[model:Rettighed/model:Pantrettighed]">
					<xsl:sort select="model:Rettighed/model:Pantrettighed/model:PrioritetNummer" />
		
					<!-- Hvis hæftelsen hører til dette dokument, så udskriv den -->
					<xsl:variable name="snapshotRettighedIdentifikator" select="model:Rettighed/model:Pantrettighed/model:RettighedIdentifikator" />
					<!-- Hæftelsen findes i RespektSamling -->
					<xsl:variable name="dokumentIdentifikator" select="model:DokumentRevisionIdentifikator/model:DokumentIdentifikator" />
					<xsl:variable name="revisionNummer" select="model:DokumentRevisionIdentifikator/model:RevisionNummer" />
					<xsl:variable name="Struktur" select="//snapshot:SnapshotSamling/snapshot:DokumentSamling/snapshot:DokumentStruktur[model:DokumentRevisionIdentifikator/model:DokumentIdentifikator = $dokumentIdentifikator and (string-length($revisionNummer)=0 or model:DokumentRevisionIdentifikator/model:RevisionNummer = $revisionNummer)]"/>
					<xsl:if test="$snapshotRettighedIdentifikator = $rettighedIdentifikator and $Struktur">
						<!-- Vis den dokumentstruktur, som matcher -->
						<xsl:call-template name="DokumentStruktur_Haeftelse">
							<xsl:with-param name="dokumentStruktur" select="$Struktur" />
							<xsl:with-param name="doc_id" select="$dokumentIdentifikator" />
						</xsl:call-template>
					</xsl:if>
				
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:if test="string-length($rettigheder) > 1">
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'FØLGENDE UNDERPANT RESPEKTERES'"/>
			</xsl:call-template>
			<xsl:copy-of select="$rettigheder"/>
		</xsl:if>
		<xsl:call-template name="linefeed" />
	</xsl:template>
	
	
	<!-- ***********************************   UnderpantIndikator   ********************************** -->
	<xsl:template match="model:UnderpantIndikator">
		<xsl:if test=".='true'">
			<xsl:variable name="HaeftelseBeloeb" select="../model:HaeftelseBeloeb/model:BeloebValuta"/>
			<xsl:call-template name="heading">
				<xsl:with-param name="text" select="'UNDERPANT'"/>
			</xsl:call-template>
			<xsl:call-template name="two_columns">
				<xsl:with-param name="prompt" select="'Underpantets beløb'"/>
				<xsl:with-param name="text" select="format-number(floor($HaeftelseBeloeb/model:BeloebVaerdi), '###.###.###.###.##0', 'currency-format')"/>
				<xsl:with-param name="text2" select="$HaeftelseBeloeb/model:ValutaKode"/>
			</xsl:call-template>
			<xsl:call-template name="linefeed" />
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
